@@ -207,13 +207,13 @@ namespace
                                alphamask_accessorselector_type,
                                Masks>                                      alphamask_bitmap_type;
 
-        // -------------------------------------------------------
+
 
         typedef AccessorTraits< raw_accessor_type >                        raw_accessor_traits;
         typedef typename uInt32Converter<
             typename raw_accessor_type::value_type>::to                    to_uint32_functor;
 
-        // -------------------------------------------------------
+
 
         typedef typename raw_accessor_traits::xor_accessor                 raw_xor_accessor_type;
         typedef AccessorTraits<raw_xor_accessor_type>                      raw_xor_accessor_traits;
@@ -221,7 +221,7 @@ namespace
             raw_xor_accessor_type >::type                                  xor_accessor_type;
         typedef AccessorTraits<xor_accessor_type>                          xor_accessor_traits;
 
-        // -------------------------------------------------------
+
 
         typedef typename raw_accessor_traits::template masked_accessor<
             mask_rawaccessor_type,
@@ -235,7 +235,7 @@ namespace
         typedef typename accessor_selector::template wrap_accessor<
             raw_maskedxor_accessor_type >::type                            masked_xoraccessor_type;
 
-        // -------------------------------------------------------
+
 
         // ((iter,mask),mask) special case (e.g. for clipped
         // drawMaskedColor())
@@ -250,7 +250,7 @@ namespace
             composite_iterator_type,
             mask_iterator_type>                                            composite_composite_mask_iterator_type;
 
-        // -------------------------------------------------------
+
 
         typedef ConstantColorBlendSetterAccessorAdapter<
             dest_accessor_type,
@@ -263,7 +263,7 @@ namespace
             mask_iterator_type,
             Masks::clipmask_polarity>::type                                masked_colorblend_accessor_type;
 
-        // -------------------------------------------------------
+
 
         typedef ConstantColorBlendSetterAccessorAdapter<
             dest_accessor_type,
@@ -276,14 +276,14 @@ namespace
             mask_iterator_type,
             Masks::clipmask_polarity>::type                                masked_colorblend_generic_accessor_type;
 
-        // -------------------------------------------------------
+
 
         typedef JoinImageAccessorAdapter< dest_accessor_type,
                                           mask_rawaccessor_type >          joined_image_accessor_type;
         typedef JoinImageAccessorAdapter< GenericColorImageAccessor,
                                           GenericColorImageAccessor >      joined_generic_image_accessor_type;
 
-        // -------------------------------------------------------
+
 
         dest_iterator_type                      maBegin;
         typename accessor_traits::color_lookup  maColorLookup;
@@ -304,7 +304,7 @@ namespace
         raw_maskedmask_accessor_type            maRawMaskedMaskAccessor;
 
 
-        // -------------------------------------------------------
+
 
         BitmapRenderer( const basegfx::B2IBox&                     rBounds,
                         const basegfx::B2IVector&                  rBufferSize,
@@ -377,7 +377,7 @@ namespace
             return boost::dynamic_pointer_cast< BitmapRenderer >( bmp );
         }
 
-        virtual bool isCompatibleBitmap( const BitmapDeviceSharedPtr& bmp ) const
+        virtual bool isCompatibleBitmap( const BitmapDeviceSharedPtr& bmp ) const SAL_OVERRIDE
         {
             // TODO(P1): dynamic_cast usually called twice for
             // compatible formats
@@ -397,7 +397,7 @@ namespace
             return pMask;
         }
 
-        virtual bool isCompatibleClipMask( const BitmapDeviceSharedPtr& bmp ) const
+        virtual bool isCompatibleClipMask( const BitmapDeviceSharedPtr& bmp ) const SAL_OVERRIDE
         {
             // TODO(P1): dynamic_cast usually called twice for
             // compatible formats
@@ -409,7 +409,7 @@ namespace
             return boost::dynamic_pointer_cast<alphamask_bitmap_type>( bmp );
         }
 
-        virtual bool isCompatibleAlphaMask( const BitmapDeviceSharedPtr& bmp ) const
+        virtual bool isCompatibleAlphaMask( const BitmapDeviceSharedPtr& bmp ) const SAL_OVERRIDE
         {
             // TODO(P1): dynamic_cast usually called twice for
             // compatible formats
@@ -417,7 +417,7 @@ namespace
         }
 
         virtual void clear_i( Color                   fillColor,
-                              const basegfx::B2IBox&  rBounds )
+                              const basegfx::B2IBox&  rBounds ) SAL_OVERRIDE
         {
             fillImage(destIterRange(maBegin,
                                     maRawAccessor,
@@ -430,7 +430,7 @@ namespace
 
         virtual void setPixel_i( const basegfx::B2IPoint& rPt,
                                  Color                    pixelColor,
-                                 DrawMode                 drawMode )
+                                 DrawMode                 drawMode ) SAL_OVERRIDE
         {
             const DestIterator pixel( maBegin +
                                       vigra::Diff2D(rPt.getX(),
@@ -447,7 +447,7 @@ namespace
         virtual void setPixel_i( const basegfx::B2IPoint&     rPt,
                                  Color                        pixelColor,
                                  DrawMode                     drawMode,
-                                 const BitmapDeviceSharedPtr& rClip )
+                                 const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
         {
             boost::shared_ptr<mask_bitmap_type> pMask( getCompatibleClipMask(rClip) );
             OSL_ASSERT( pMask );
@@ -468,7 +468,7 @@ namespace
             damagedPixel(rPt);
         }
 
-        virtual Color getPixel_i(const basegfx::B2IPoint& rPt )
+        virtual Color getPixel_i(const basegfx::B2IPoint& rPt ) SAL_OVERRIDE
         {
             const DestIterator pixel( maBegin +
                                       vigra::Diff2D(rPt.getX(),
@@ -476,7 +476,7 @@ namespace
             return maAccessor(pixel);
         }
 
-        virtual sal_uInt32 getPixelData_i( const basegfx::B2IPoint& rPt )
+        virtual sal_uInt32 getPixelData_i( const basegfx::B2IPoint& rPt ) SAL_OVERRIDE
         {
             const DestIterator pixel( maBegin +
                                       vigra::Diff2D(rPt.getX(),
@@ -541,7 +541,7 @@ namespace
                                 const basegfx::B2IPoint& rPt2,
                                 const basegfx::B2IBox&   rBounds,
                                 Color                    lineColor,
-                                DrawMode                 drawMode )
+                                DrawMode                 drawMode ) SAL_OVERRIDE
         {
             implDrawLine(rPt1,rPt2,rBounds,lineColor,
                          maBegin,
@@ -562,7 +562,7 @@ namespace
                                 const basegfx::B2IBox&       rBounds,
                                 Color                        lineColor,
                                 DrawMode                     drawMode,
-                                const BitmapDeviceSharedPtr& rClip )
+                                const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
         {
             implDrawLine(rPt1,rPt2,rBounds,lineColor,
                          getMaskedIter(rClip),
@@ -605,7 +605,7 @@ namespace
         virtual void drawPolygon_i(const basegfx::B2DPolygon& rPoly,
                                    const basegfx::B2IBox&     rBounds,
                                    Color                      lineColor,
-                                   DrawMode                   drawMode )
+                                   DrawMode                   drawMode ) SAL_OVERRIDE
         {
             if( drawMode == DrawMode_XOR )
                 implDrawPolygon( rPoly, rBounds, lineColor,
@@ -621,7 +621,7 @@ namespace
                                    const basegfx::B2IBox&       rBounds,
                                    Color                        lineColor,
                                    DrawMode                     drawMode,
-                                   const BitmapDeviceSharedPtr& rClip )
+                                   const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
         {
             if( drawMode == DrawMode_XOR )
                 implDrawPolygon( rPoly, rBounds, lineColor,
@@ -662,7 +662,7 @@ namespace
         virtual void fillPolyPolygon_i(const basegfx::B2DPolyPolygon& rPoly,
                                        Color                          fillColor,
                                        DrawMode                       drawMode,
-                                       const basegfx::B2IBox&         rBounds )
+                                       const basegfx::B2IBox&         rBounds ) SAL_OVERRIDE
         {
             if( drawMode == DrawMode_XOR )
                 implFillPolyPolygon( rPoly, fillColor,
@@ -680,7 +680,7 @@ namespace
                                        Color                          fillColor,
                                        DrawMode                       drawMode,
                                        const basegfx::B2IBox&         rBounds,
-                                       const BitmapDeviceSharedPtr&   rClip )
+                                       const BitmapDeviceSharedPtr&   rClip ) SAL_OVERRIDE
         {
             if( drawMode == DrawMode_XOR )
                 implFillPolyPolygon( rPoly, fillColor,
@@ -788,7 +788,7 @@ namespace
         virtual void drawBitmap_i(const BitmapDeviceSharedPtr& rSrcBitmap,
                                   const basegfx::B2IBox&       rSrcRect,
                                   const basegfx::B2IBox&       rDstRect,
-                                  DrawMode                     drawMode )
+                                  DrawMode                     drawMode ) SAL_OVERRIDE
         {
             if( isCompatibleBitmap( rSrcBitmap ) )
             {
@@ -823,7 +823,7 @@ namespace
                                   const basegfx::B2IBox&       rSrcRect,
                                   const basegfx::B2IBox&       rDstRect,
                                   DrawMode                     drawMode,
-                                  const BitmapDeviceSharedPtr& rClip )
+                                  const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
         {
             if( isCompatibleBitmap( rSrcBitmap ) )
             {
@@ -853,7 +853,7 @@ namespace
         virtual void drawMaskedColor_i(Color                        aSrcColor,
                                        const BitmapDeviceSharedPtr& rAlphaMask,
                                        const basegfx::B2IBox&       rSrcRect,
-                                       const basegfx::B2IPoint&     rDstPoint )
+                                       const basegfx::B2IPoint&     rDstPoint ) SAL_OVERRIDE
         {
             boost::shared_ptr<mask_bitmap_type>      pMask( getCompatibleClipMask(rAlphaMask) );
             boost::shared_ptr<alphamask_bitmap_type> pAlpha( getCompatibleAlphaMask(rAlphaMask) );
@@ -903,7 +903,7 @@ namespace
                                        const BitmapDeviceSharedPtr& rAlphaMask,
                                        const basegfx::B2IBox&       rSrcRect,
                                        const basegfx::B2IPoint&     rDstPoint,
-                                       const BitmapDeviceSharedPtr& rClip )
+                                       const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
         {
             boost::shared_ptr<mask_bitmap_type>      pMask( getCompatibleClipMask(rAlphaMask) );
             boost::shared_ptr<alphamask_bitmap_type> pAlpha( getCompatibleAlphaMask(rAlphaMask) );
@@ -1031,7 +1031,7 @@ namespace
                                         const BitmapDeviceSharedPtr& rMask,
                                         const basegfx::B2IBox&       rSrcRect,
                                         const basegfx::B2IBox&       rDstRect,
-                                        DrawMode                     drawMode )
+                                        DrawMode                     drawMode ) SAL_OVERRIDE
         {
             if( isCompatibleClipMask(rMask) &&
                 isCompatibleBitmap(rSrcBitmap) )
@@ -1068,7 +1068,7 @@ namespace
                                         const basegfx::B2IBox&       rSrcRect,
                                         const basegfx::B2IBox&       rDstRect,
                                         DrawMode                     drawMode,
-                                        const BitmapDeviceSharedPtr& rClip )
+                                        const BitmapDeviceSharedPtr& rClip ) SAL_OVERRIDE
         {
             if( isCompatibleClipMask(rMask) &&
                 isCompatibleBitmap(rSrcBitmap) )
@@ -1100,11 +1100,11 @@ namespace
             damaged( rDstRect );
         }
 
-        IBitmapDeviceDamageTrackerSharedPtr getDamageTracker_i() const
+        IBitmapDeviceDamageTrackerSharedPtr getDamageTracker_i() const SAL_OVERRIDE
         {
             return mpDamage;
         }
-        void setDamageTracker_i( const IBitmapDeviceDamageTrackerSharedPtr& rDamage )
+        void setDamageTracker_i( const IBitmapDeviceDamageTrackerSharedPtr& rDamage ) SAL_OVERRIDE
         {
             mpDamage = rDamage;
         }
@@ -1462,8 +1462,16 @@ namespace
                        const ::basegfx::B2IBox& rSourceBounds )
     {
         // extract inherent scale
-        const double nScaleX( io_rDestArea.getWidth() / (double)io_rSourceArea.getWidth() );
-        const double nScaleY( io_rDestArea.getHeight() / (double)io_rSourceArea.getHeight() );
+        double fWidth = io_rSourceArea.getWidth();
+        if (fWidth == 0.0)
+            return false;
+
+        double fHeight = io_rSourceArea.getHeight();
+        if (fHeight == 0.0)
+            return false;
+
+        const double nScaleX( io_rDestArea.getWidth() / fWidth );
+        const double nScaleY( io_rDestArea.getHeight() / fHeight );
 
         // extract range origins
         const basegfx::B2IPoint   aDestTopLeft(
@@ -1601,15 +1609,14 @@ void BitmapDevice::drawMaskedColor( Color                        aSrcColor,
         if( isSharedBuffer(rAlphaMask) )
         {
             // src == dest, copy rAlphaMask beforehand
-            // ---------------------------------------------------
+
 
             const basegfx::B2ITuple aSize( aSrcRange.getWidth(),
                                            aSrcRange.getHeight() );
             BitmapDeviceSharedPtr pAlphaCopy(
                 cloneBitmapDevice( aSize,
                                    shared_from_this()) );
-            basegfx::B2ITuple aGcc3WorkaroundTemporary;
-            const basegfx::B2IBox aAlphaRange( aGcc3WorkaroundTemporary,
+            const basegfx::B2IBox aAlphaRange( basegfx::B2ITuple(),
                                                aSize );
             pAlphaCopy->drawBitmap(rAlphaMask,
                                    aSrcRange,
@@ -1654,15 +1661,14 @@ void BitmapDevice::drawMaskedColor( Color                        aSrcColor,
             if( isSharedBuffer(rAlphaMask) )
             {
                 // src == dest, copy rAlphaMask beforehand
-                // ---------------------------------------------------
+
 
                 const basegfx::B2ITuple aSize( aSrcRange.getWidth(),
                                                aSrcRange.getHeight() );
                 BitmapDeviceSharedPtr pAlphaCopy(
                     cloneBitmapDevice( aSize,
                                        shared_from_this()) );
-                basegfx::B2ITuple aGcc3WorkaroundTemporary;
-                const basegfx::B2IBox aAlphaRange( aGcc3WorkaroundTemporary,
+                const basegfx::B2IBox aAlphaRange( basegfx::B2ITuple(),
                                                    aSize );
                 pAlphaCopy->drawBitmap(rAlphaMask,
                                        aSrcRange,
@@ -1997,7 +2003,7 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
 
     switch( nScanlineFormat )
     {
-        // ----------------------------------------------------------------------
+
         // one bit formats
 
         case FORMAT_ONE_BIT_MSB_GREY:
@@ -2023,7 +2029,7 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
                 bitsPerPixel[nScanlineFormat], rDamage );
 
 
-        // ----------------------------------------------------------------------
+
         // four bit formats
 
         case FORMAT_FOUR_BIT_MSB_GREY:
@@ -2049,7 +2055,7 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
                 bitsPerPixel[nScanlineFormat], rDamage );
 
 
-        // ----------------------------------------------------------------------
+
         // eight bit formats
 
         case FORMAT_EIGHT_BIT_GREY:
@@ -2064,7 +2070,7 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
                 bitsPerPixel[nScanlineFormat], rDamage );
 
 
-        // ----------------------------------------------------------------------
+
         // sixteen bit formats
 
         case FORMAT_SIXTEEN_BIT_LSB_TC_MASK:
@@ -2078,7 +2084,7 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
                 pFirstScanline, pMem, pPal, rDamage );
 
 
-        // ----------------------------------------------------------------------
+
         // twentyfour bit formats
         case FORMAT_TWENTYFOUR_BIT_TC_MASK:
             return createRenderer<PixelFormatTraits_BGR24,StdMasks>(
@@ -2086,7 +2092,7 @@ BitmapDeviceSharedPtr createBitmapDeviceImplInner( const basegfx::B2IVector&
                 pFirstScanline, pMem, pPal, rDamage );
 
 
-        // ----------------------------------------------------------------------
+
         // thirtytwo bit formats
 
         case FORMAT_THIRTYTWO_BIT_TC_MASK_BGRA:
