@@ -18,7 +18,6 @@
  */
 
 #include <vcl/waitobj.hxx>
-#include <cppuhelper/interfacecontainer.hxx>
 #include <com/sun/star/util/URL.hpp>
 #include <vcl/msgbox.hxx>
 #include <tools/debug.hxx>
@@ -46,6 +45,8 @@
 #include <com/sun/star/sdb/RowChangeAction.hpp>
 #include <com/sun/star/frame/CommandGroup.hpp>
 #include <com/sun/star/datatransfer/clipboard/XClipboard.hpp>
+#include <cppuhelper/interfacecontainer.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <sot/exchange.hxx>
 #include <sot/formats.hxx>
 #include <vcl/edit.hxx>
@@ -65,44 +66,44 @@ struct DispatchInfo
 {
     const char*   pCommand;
     sal_Int16     nGroupId;
-    sal_Bool      bActiveConnection;
+    bool      bActiveConnection;
 };
 
 struct CacheDispatchInfo
 {
     sal_Int16     nGroupId;
-    sal_Bool      bActiveConnection;
+    bool      bActiveConnection;
 };
 
 // Attention: commands must be sorted by command groups. Implementation is dependent
 // on this!!
 static const DispatchInfo SupportedCommandsArray[] =
 {
-    { ".uno:Undo"               ,   frame::CommandGroup::EDIT       , sal_False },
-    { ".uno:Cut"                ,   frame::CommandGroup::EDIT       , sal_False },
-    { ".uno:Copy"               ,   frame::CommandGroup::EDIT       , sal_False },
-    { ".uno:Paste"              ,   frame::CommandGroup::EDIT       , sal_False },
-    { ".uno:SelectAll"          ,   frame::CommandGroup::EDIT       , sal_False },
-    { ".uno:CloseDoc"           ,   frame::CommandGroup::DOCUMENT   , sal_False },
-    { ".uno:StatusBarVisible"   ,   frame::CommandGroup::VIEW       , sal_False },
-    { ".uno:AvailableToolbars"  ,   frame::CommandGroup::VIEW       , sal_False },
-    { ".uno:Bib/standardFilter" ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/DeleteRecord"   ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/InsertRecord"   ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/query"          ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/autoFilter"     ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/source"         ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/removeFilter"   ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/sdbsource"      ,   frame::CommandGroup::DATA       , sal_True  },
-    { ".uno:Bib/Mapping"        ,   frame::CommandGroup::DATA       , sal_True  },
-    { 0                         ,   0                               , sal_False }
+    { ".uno:Undo"               ,   frame::CommandGroup::EDIT       , false },
+    { ".uno:Cut"                ,   frame::CommandGroup::EDIT       , false },
+    { ".uno:Copy"               ,   frame::CommandGroup::EDIT       , false },
+    { ".uno:Paste"              ,   frame::CommandGroup::EDIT       , false },
+    { ".uno:SelectAll"          ,   frame::CommandGroup::EDIT       , false },
+    { ".uno:CloseDoc"           ,   frame::CommandGroup::DOCUMENT   , false },
+    { ".uno:StatusBarVisible"   ,   frame::CommandGroup::VIEW       , false },
+    { ".uno:AvailableToolbars"  ,   frame::CommandGroup::VIEW       , false },
+    { ".uno:Bib/standardFilter" ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/DeleteRecord"   ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/InsertRecord"   ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/query"          ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/autoFilter"     ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/source"         ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/removeFilter"   ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/sdbsource"      ,   frame::CommandGroup::DATA       , true  },
+    { ".uno:Bib/Mapping"        ,   frame::CommandGroup::DATA       , true  },
+    { 0                         ,   0                               , false }
 };
 
 typedef ::boost::unordered_map< OUString, CacheDispatchInfo, OUStringHash, ::std::equal_to< OUString > > CmdToInfoCache;
 
 const CmdToInfoCache& GetCommandToInfoCache()
 {
-    static sal_Bool       bCacheInitialized = sal_False;
+    static bool       bCacheInitialized = false;
     static CmdToInfoCache aCmdToInfoCache;
 
     if ( !bCacheInitialized )
@@ -121,7 +122,7 @@ const CmdToInfoCache& GetCommandToInfoCache()
                 aCmdToInfoCache.insert( CmdToInfoCache::value_type( aCommand, aDispatchInfo ));
                 ++i;
             }
-            bCacheInitialized = sal_True;
+            bCacheInitialized = true;
         }
     }
 
@@ -142,10 +143,10 @@ public:
                                             , pController(0)
                                         {}
 
-                                        ~BibFrameCtrl_Impl();
+                                        virtual ~BibFrameCtrl_Impl();
 
-    virtual void                        SAL_CALL frameAction(const FrameActionEvent& aEvent) throw( RuntimeException );
-    virtual void                        SAL_CALL disposing( const lang::EventObject& Source ) throw (::com::sun::star::uno::RuntimeException);
+    virtual void                        SAL_CALL frameAction(const FrameActionEvent& aEvent) throw( RuntimeException, std::exception ) SAL_OVERRIDE;
+    virtual void                        SAL_CALL disposing( const lang::EventObject& Source ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
 };
 
 
@@ -153,7 +154,7 @@ BibFrameCtrl_Impl::~BibFrameCtrl_Impl()
 {
 }
 
-void BibFrameCtrl_Impl::frameAction(const FrameActionEvent& aEvent) throw( uno::RuntimeException )
+void BibFrameCtrl_Impl::frameAction(const FrameActionEvent& aEvent) throw( uno::RuntimeException, std::exception )
 {
     if ( pController && aEvent.Frame == pController->getFrame())
     {
@@ -169,7 +170,7 @@ void BibFrameCtrl_Impl::frameAction(const FrameActionEvent& aEvent) throw( uno::
 }
 
 void BibFrameCtrl_Impl::disposing( const lang::EventObject& /*Source*/ )
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ::SolarMutexGuard aGuard;
     if ( pController )
@@ -185,8 +186,8 @@ BibFrameController_Impl::BibFrameController_Impl( const uno::Reference< awt::XWi
 {
     Window* pParent = VCLUnoHelper::GetWindow( xWindow );
     pParent->SetUniqueId(UID_BIB_FRAME_WINDOW);
-    bDisposing=sal_False;
-    bHierarchical=sal_True;
+    bDisposing=false;
+    bHierarchical=true;
     pImp = new BibFrameCtrl_Impl;
     pImp->pController = this;
     pImp->acquire();
@@ -201,17 +202,17 @@ BibFrameController_Impl::~BibFrameController_Impl()
         CloseBibModul(pBibMod);
 }
 
-OUString SAL_CALL BibFrameController_Impl::getImplementationName() throw (::com::sun::star::uno::RuntimeException)
+OUString SAL_CALL BibFrameController_Impl::getImplementationName() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return OUString("com.sun.star.comp.extensions.Bibliography");
 }
 
-sal_Bool SAL_CALL BibFrameController_Impl::supportsService( const OUString& sServiceName ) throw (::com::sun::star::uno::RuntimeException)
+sal_Bool SAL_CALL BibFrameController_Impl::supportsService( const OUString& sServiceName ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
-    return ( sServiceName == "com.sun.star.frame.Bibliography" || sServiceName == "com.sun.star.frame.Controller" );
+    return cppu::supportsService( this, sServiceName );
 }
 
-::com::sun::star::uno::Sequence< OUString > SAL_CALL BibFrameController_Impl::getSupportedServiceNames() throw (::com::sun::star::uno::RuntimeException)
+::com::sun::star::uno::Sequence< OUString > SAL_CALL BibFrameController_Impl::getSupportedServiceNames() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     // return only top level services ...
     // base services are included there and should be asked by uno-rtti.
@@ -220,18 +221,18 @@ sal_Bool SAL_CALL BibFrameController_Impl::supportsService( const OUString& sSer
     return lNames;
 }
 
-void BibFrameController_Impl::attachFrame( const uno::Reference< XFrame > & xArg ) throw (::com::sun::star::uno::RuntimeException)
+void BibFrameController_Impl::attachFrame( const uno::Reference< XFrame > & xArg ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     xFrame = xArg;
     xFrame->addFrameActionListener( pImp );
 }
 
-sal_Bool BibFrameController_Impl::attachModel( const uno::Reference< XModel > & /*xModel*/ ) throw (::com::sun::star::uno::RuntimeException)
+sal_Bool BibFrameController_Impl::attachModel( const uno::Reference< XModel > & /*xModel*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return sal_False;
 }
 
-sal_Bool BibFrameController_Impl::suspend( sal_Bool bSuspend ) throw (::com::sun::star::uno::RuntimeException)
+sal_Bool BibFrameController_Impl::suspend( sal_Bool bSuspend ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     if ( bSuspend )
         getFrame()->removeFrameActionListener( pImp );
@@ -240,28 +241,28 @@ sal_Bool BibFrameController_Impl::suspend( sal_Bool bSuspend ) throw (::com::sun
     return sal_True;
 }
 
-uno::Any BibFrameController_Impl::getViewData() throw (::com::sun::star::uno::RuntimeException)
+uno::Any BibFrameController_Impl::getViewData() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return uno::Any();
 }
 
-void BibFrameController_Impl::restoreViewData( const uno::Any& /*Value*/ ) throw (::com::sun::star::uno::RuntimeException)
+void BibFrameController_Impl::restoreViewData( const uno::Any& /*Value*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
 }
 
-uno::Reference< XFrame >  BibFrameController_Impl::getFrame() throw (::com::sun::star::uno::RuntimeException)
+uno::Reference< XFrame >  BibFrameController_Impl::getFrame() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return xFrame;
 }
 
-uno::Reference< XModel >  BibFrameController_Impl::getModel() throw (::com::sun::star::uno::RuntimeException)
+uno::Reference< XModel >  BibFrameController_Impl::getModel() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return uno::Reference< XModel > ();
 }
 
-void BibFrameController_Impl::dispose() throw (::com::sun::star::uno::RuntimeException)
+void BibFrameController_Impl::dispose() throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
-    bDisposing = sal_True;
+    bDisposing = true;
     lang::EventObject aObject;
     aObject.Source = (XController*)this;
     pImp->aLC.disposeAndClear(aObject);
@@ -270,17 +271,17 @@ void BibFrameController_Impl::dispose() throw (::com::sun::star::uno::RuntimeExc
     aStatusListeners.clear();
  }
 
-void BibFrameController_Impl::addEventListener( const uno::Reference< lang::XEventListener > & aListener ) throw (::com::sun::star::uno::RuntimeException)
+void BibFrameController_Impl::addEventListener( const uno::Reference< lang::XEventListener > & aListener ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     pImp->aLC.addInterface( ::getCppuType((const Reference< lang::XEventListener >*)0), aListener );
 }
 
-void BibFrameController_Impl::removeEventListener( const uno::Reference< lang::XEventListener > & aListener ) throw (::com::sun::star::uno::RuntimeException)
+void BibFrameController_Impl::removeEventListener( const uno::Reference< lang::XEventListener > & aListener ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     pImp->aLC.removeInterface( ::getCppuType((const Reference< lang::XEventListener >*)0), aListener );
 }
 
-uno::Reference< frame::XDispatch >  BibFrameController_Impl::queryDispatch( const util::URL& aURL, const OUString& /*aTarget*/, sal_Int32 /*nSearchFlags*/ ) throw (::com::sun::star::uno::RuntimeException)
+uno::Reference< frame::XDispatch >  BibFrameController_Impl::queryDispatch( const util::URL& aURL, const OUString& /*aTarget*/, sal_Int32 /*nSearchFlags*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     if ( !bDisposing )
     {
@@ -297,7 +298,7 @@ uno::Reference< frame::XDispatch >  BibFrameController_Impl::queryDispatch( cons
     return uno::Reference< frame::XDispatch > ();
 }
 
-uno::Sequence<uno::Reference< XDispatch > > BibFrameController_Impl::queryDispatches( const uno::Sequence<DispatchDescriptor>& aDescripts ) throw (::com::sun::star::uno::RuntimeException)
+uno::Sequence<uno::Reference< XDispatch > > BibFrameController_Impl::queryDispatches( const uno::Sequence<DispatchDescriptor>& aDescripts ) throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     uno::Sequence< uno::Reference< XDispatch > > aDispatches( aDescripts.getLength() );
     for ( sal_Int32 i=0; i<aDescripts.getLength(); ++i )
@@ -306,7 +307,7 @@ uno::Sequence<uno::Reference< XDispatch > > BibFrameController_Impl::queryDispat
 }
 
 uno::Sequence< ::sal_Int16 > SAL_CALL BibFrameController_Impl::getSupportedCommandGroups()
-throw (::com::sun::star::uno::RuntimeException)
+throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     uno::Sequence< ::sal_Int16 > aDispatchInfo( 4 );
 
@@ -319,11 +320,11 @@ throw (::com::sun::star::uno::RuntimeException)
 }
 
 uno::Sequence< frame::DispatchInformation > SAL_CALL BibFrameController_Impl::getConfigurableDispatchInformation( ::sal_Int16 nCommandGroup )
-throw (::com::sun::star::uno::RuntimeException)
+throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     const CmdToInfoCache& rCmdCache = GetCommandToInfoCache();
 
-    sal_Bool                                    bGroupFound( sal_False );
+    bool                                    bGroupFound( false );
     frame::DispatchInformation                  aDispatchInfo;
     std::list< frame::DispatchInformation >     aDispatchInfoList;
 
@@ -337,7 +338,7 @@ throw (::com::sun::star::uno::RuntimeException)
         {
             if ( pIter->second.nGroupId == nCommandGroup )
             {
-                bGroupFound = sal_True;
+                bGroupFound = true;
                 aDispatchInfo.Command = pIter->first;
                 aDispatchInfo.GroupId = pIter->second.nGroupId;
                 aDispatchInfoList.push_back( aDispatchInfo );
@@ -355,31 +356,31 @@ throw (::com::sun::star::uno::RuntimeException)
     return aSeq;
 }
 
-sal_Bool canInsertRecords(const Reference< beans::XPropertySet>& _rxCursorSet)
+bool canInsertRecords(const Reference< beans::XPropertySet>& _rxCursorSet)
 {
     sal_Int32 nPriv = 0;
     _rxCursorSet->getPropertyValue("Privileges") >>= nPriv;
     return ((_rxCursorSet.is() && (nPriv & sdbcx::Privilege::INSERT) != 0));
 }
 
-sal_Bool BibFrameController_Impl::SaveModified(const Reference< form::runtime::XFormController>& xController)
+bool BibFrameController_Impl::SaveModified(const Reference< form::runtime::XFormController>& xController)
 {
     if (!xController.is())
-        return sal_False;
+        return false;
 
     Reference< XResultSetUpdate> _xCursor = Reference< XResultSetUpdate>(xController->getModel(), UNO_QUERY);
 
     if (!_xCursor.is())
-        return sal_False;
+        return false;
 
     Reference< beans::XPropertySet> _xSet = Reference< beans::XPropertySet>(_xCursor, UNO_QUERY);
     if (!_xSet.is())
-        return sal_False;
+        return false;
 
     // need to save?
-    sal_Bool  bIsNew        = ::comphelper::getBOOL(_xSet->getPropertyValue("IsNew"));
-    sal_Bool  bIsModified   = ::comphelper::getBOOL(_xSet->getPropertyValue("IsModified"));
-    sal_Bool bResult = !bIsModified;
+    bool  bIsNew        = ::comphelper::getBOOL(_xSet->getPropertyValue("IsNew"));
+    bool  bIsModified   = ::comphelper::getBOOL(_xSet->getPropertyValue("IsModified"));
+    bool bResult = !bIsModified;
     if (bIsModified)
     {
         try
@@ -388,7 +389,7 @@ sal_Bool BibFrameController_Impl::SaveModified(const Reference< form::runtime::X
                 _xCursor->insertRow();
             else
                 _xCursor->updateRow();
-            bResult = sal_True;
+            bResult = true;
         }
         catch(const Exception&)
         {
@@ -414,7 +415,9 @@ static Window* lcl_GetFocusChild( Window* pParent )
 }
 
 //class XDispatch
-void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequence< beans::PropertyValue >& aArgs) throw (::com::sun::star::uno::RuntimeException)
+void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequence< beans::PropertyValue >& aArgs)
+    throw (::com::sun::star::uno::RuntimeException,
+           std::exception)
 {
     if ( !bDisposing )
     {
@@ -552,15 +555,15 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
             Reference< ::com::sun::star::sdbc::XResultSet >  xCursor(pDatMan->getForm(), UNO_QUERY);
             Reference< XResultSetUpdate >  xUpdateCursor(xCursor, UNO_QUERY);
             Reference< beans::XPropertySet >  xSet(pDatMan->getForm(), UNO_QUERY);
-            sal_Bool  bIsNew  = ::comphelper::getBOOL(xSet->getPropertyValue("IsNew"));
+            bool  bIsNew  = ::comphelper::getBOOL(xSet->getPropertyValue("IsNew"));
             if(!bIsNew)
             {
                 sal_uInt32 nCount = 0;
                 xSet->getPropertyValue("RowCount") >>= nCount;
-                // naechste position festellen
-                sal_Bool bSuccess = sal_False;
-                sal_Bool bLeft = sal_False;
-                sal_Bool bRight = sal_False;
+                // determine next position
+                bool bSuccess = false;
+                bool bLeft = false;
+                bool bRight = false;
                 try
                 {
                     bLeft = xCursor->isLast() && nCount > 1;
@@ -577,13 +580,13 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
                         bSuccess = xConfirm->confirmDelete(aEvent);
                     }
 
-                    // das Ding loeschen
+                    // delete it
                     if (bSuccess)
                         xUpdateCursor->deleteRow();
                 }
                 catch(const Exception&)
                 {
-                    bSuccess = sal_False;
+                    bSuccess = false;
                 }
                 if (bSuccess)
                 {
@@ -591,19 +594,19 @@ void BibFrameController_Impl::dispatch(const util::URL& _rURL, const uno::Sequen
                         xCursor->relative(bRight ? 1 : -1);
                     else
                     {
-                        sal_Bool bCanInsert = canInsertRecords(xSet);
-                        // kann noch ein Datensatz eingefuegt weden
+                        bool bCanInsert = canInsertRecords(xSet);
+                        // can another entry be inserted?
                         try
                         {
                             if (bCanInsert)
                                 xUpdateCursor->moveToInsertRow();
                             else
-                                // Datensatz bewegen um Stati neu zu setzen
+                                // move data entry to reset state
                                 xCursor->first();
                         }
                         catch(const Exception&)
                         {
-                            OSL_FAIL("DeleteRecord : exception caught !");
+                            OSL_FAIL("DeleteRecord: exception caught!");
                         }
                     }
                 }
@@ -644,17 +647,17 @@ IMPL_STATIC_LINK( BibFrameController_Impl, DisposeHdl, void*, EMPTYARG )
     return 0;
 };
 
-//-----------------------------------------------------------------------------
 void BibFrameController_Impl::addStatusListener(
     const uno::Reference< frame::XStatusListener > & aListener,
     const util::URL& aURL)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException,
+           std::exception)
 {
     BibConfig* pConfig = BibModul::GetConfig();
     // create a new Reference and insert into listener array
     aStatusListeners.push_back( new BibStatusDispatch( aURL, aListener ) );
 
-    // den ersten Status synchron zusenden
+    // send first status synchronously
     FeatureStateEvent aEvent;
     aEvent.FeatureURL = aURL;
     aEvent.Requery    = sal_False;
@@ -662,7 +665,7 @@ void BibFrameController_Impl::addStatusListener(
     if ( aURL.Path == "StatusBarVisible" )
     {
         aEvent.IsEnabled  = sal_False;
-        aEvent.State <<= sal_Bool( sal_False );
+        aEvent.State <<= false;
     }
     else if ( aURL.Path == "Bib/hierarchical" )
     {
@@ -762,7 +765,7 @@ void BibFrameController_Impl::addStatusListener(
         Reference< ::com::sun::star::sdbc::XResultSet >  xCursor(pDatMan->getForm(), UNO_QUERY);
         Reference< XResultSetUpdate >  xUpdateCursor(xCursor, UNO_QUERY);
         Reference< beans::XPropertySet >  xSet(pDatMan->getForm(), UNO_QUERY);
-        sal_Bool  bIsNew  = ::comphelper::getBOOL(xSet->getPropertyValue("IsNew"));
+        bool  bIsNew  = ::comphelper::getBOOL(xSet->getPropertyValue("IsNew"));
         if(!bIsNew)
         {
             sal_uInt32 nCount = 0;
@@ -777,10 +780,10 @@ void BibFrameController_Impl::addStatusListener(
     }
     aListener->statusChanged( aEvent );
 }
-//-----------------------------------------------------------------------------
+
 void BibFrameController_Impl::removeStatusListener(
     const uno::Reference< frame::XStatusListener > & aObject, const util::URL& aURL)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     // search listener array for given listener
     // for checking equality always "cast" to XInterface
@@ -790,7 +793,7 @@ void BibFrameController_Impl::removeStatusListener(
         for ( sal_uInt16 n=0; n<nCount; n++ )
         {
             BibStatusDispatch *pObj = &aStatusListeners[n];
-            sal_Bool bFlag=pObj->xListener.is();
+            bool bFlag=pObj->xListener.is();
             if (!bFlag || (pObj->xListener == aObject &&
                 ( aURL.Complete.isEmpty() || pObj->aURL.Path == aURL.Path  )))
             {
@@ -800,7 +803,7 @@ void BibFrameController_Impl::removeStatusListener(
         }
     }
 }
-//-----------------------------------------------------------------------------
+
 void BibFrameController_Impl::RemoveFilter()
 {
     OUString aQuery;
@@ -808,8 +811,8 @@ void BibFrameController_Impl::RemoveFilter()
 
     sal_uInt16 nCount = aStatusListeners.size();
 
-    sal_Bool bRemoveFilter=sal_False;
-    sal_Bool bQueryText=sal_False;
+    bool bRemoveFilter=false;
+    bool bQueryText=false;
 
     for ( sal_uInt16 n=0; n<nCount; n++ )
     {
@@ -822,7 +825,7 @@ void BibFrameController_Impl::RemoveFilter()
             aEvent.Requery    = sal_False;
             aEvent.Source     = (XDispatch *) this;
             pObj->xListener->statusChanged( aEvent );
-            bRemoveFilter=sal_True;
+            bRemoveFilter=true;
         }
         else if(pObj->aURL.Path == "Bib/query")
         {
@@ -833,7 +836,7 @@ void BibFrameController_Impl::RemoveFilter()
             aEvent.Source     = (XDispatch *) this;
             aEvent.State <<= aQuery;
             pObj->xListener->statusChanged( aEvent );
-            bQueryText=sal_True;
+            bQueryText=true;
         }
 
         if(bRemoveFilter && bQueryText)
@@ -841,7 +844,7 @@ void BibFrameController_Impl::RemoveFilter()
 
     }
 }
-//-----------------------------------------------------------------------------
+
 void BibFrameController_Impl::ChangeDataSource(const uno::Sequence< beans::PropertyValue >& aArgs)
 {
     const beans::PropertyValue* pPropertyValue = aArgs.getConstArray();
@@ -869,8 +872,8 @@ void BibFrameController_Impl::ChangeDataSource(const uno::Sequence< beans::Prope
 
     sal_uInt16 nCount = aStatusListeners.size();
 
-    sal_Bool bMenuFilter=sal_False;
-    sal_Bool bQueryText=sal_False;
+    bool bMenuFilter=false;
+    bool bQueryText=false;
     for ( sal_uInt16 n=0; n<nCount; n++ )
     {
         BibStatusDispatch *pObj = &aStatusListeners[n];
@@ -887,7 +890,7 @@ void BibFrameController_Impl::ChangeDataSource(const uno::Sequence< beans::Prope
             aEvent.State  = makeAny( aStringSeq );
 
             pObj->xListener->statusChanged( aEvent );
-            bMenuFilter=sal_True;
+            bMenuFilter=true;
         }
         else if (pObj->aURL.Path == "Bib/query")
         {
@@ -899,7 +902,7 @@ void BibFrameController_Impl::ChangeDataSource(const uno::Sequence< beans::Prope
             BibConfig* pConfig = BibModul::GetConfig();
             aEvent.State <<= pConfig->getQueryText();
             pObj->xListener->statusChanged( aEvent );
-            bQueryText=sal_True;
+            bQueryText=true;
         }
 
         if (bMenuFilter && bQueryText)
