@@ -19,8 +19,6 @@
 
 #include <accelerators/storageholder.hxx>
 
-#include <threadhelp/readguard.hxx>
-#include <threadhelp/writeguard.hxx>
 #include <services.h>
 
 #include <com/sun/star/container/NoSuchElementException.hpp>
@@ -39,37 +37,29 @@
 
 #include <com/sun/star/io/XSeekable.hpp>
 
-
 #define PATH_SEPARATOR_ASCII        "/"
 #define PATH_SEPARATOR_UNICODE      ((sal_Unicode)'/')
 #define PATH_SEPARATOR              OUString(PATH_SEPARATOR_ASCII)
 
-
 namespace framework
 {
 
-//-----------------------------------------------
 StorageHolder::StorageHolder()
-    : ThreadHelpBase(                                        )
 {
 }
 
-//-----------------------------------------------
 StorageHolder::~StorageHolder()
 {
     // TODO implement me
     // dispose/clear etcpp.
 }
 
-//-----------------------------------------------
 void StorageHolder::forgetCachedStorages()
 {
-    // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
-
+    osl::MutexGuard g(m_mutex);
     TPath2StorageInfo::iterator pIt;
     for (  pIt  = m_lStorages.begin();
-           pIt != m_lStorages.end()  ;
+           pIt != m_lStorages.end();
          ++pIt                       )
     {
         TStorageInfo& rInfo = pIt->second;
@@ -77,31 +67,20 @@ void StorageHolder::forgetCachedStorages()
         rInfo.Storage.clear();
     }
     m_lStorages.clear();
-
-    aWriteLock.unlock();
-    // <- SAFE ----------------------------------
 }
 
-//-----------------------------------------------
 void StorageHolder::setRootStorage(const css::uno::Reference< css::embed::XStorage >& xRoot)
 {
-    // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
     m_xRoot = xRoot;
-    aWriteLock.unlock();
-    // <- SAFE ----------------------------------
 }
 
-//-----------------------------------------------
 css::uno::Reference< css::embed::XStorage > StorageHolder::getRootStorage() const
 {
-    // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
     return m_xRoot;
-    // <- SAFE ----------------------------------
 }
 
-//-----------------------------------------------
 css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUString& sPath    ,
                                                                           sal_Int32        nOpenMode)
 {
@@ -109,17 +88,17 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
     OUStringList    lFolders    = StorageHolder::impl_st_parsePath(sNormedPath);
 
     // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ResettableMutexGuard aReadLock(m_mutex);
     css::uno::Reference< css::embed::XStorage > xParent = m_xRoot;
-    aReadLock.unlock();
+    aReadLock.clear();
     // <- SAFE ----------------------------------
 
-    css::uno::Reference< css::embed::XStorage > xChild  ;
+    css::uno::Reference< css::embed::XStorage > xChild;
     OUString                             sRelPath;
-    OUStringList::const_iterator                pIt     ;
+    OUStringList::const_iterator                pIt;
 
     for (  pIt  = lFolders.begin();
-           pIt != lFolders.end()  ;
+           pIt != lFolders.end();
          ++pIt                    )
     {
         const OUString& sChild     = *pIt;
@@ -128,7 +107,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
                                sCheckPath += PATH_SEPARATOR;
 
         // SAFE -> ------------------------------
-        aReadLock.lock();
+        aReadLock.reset();
 
         // If we found an already open storage ... we must increase
         // its use count. Otherwhise it will may be closed to early :-)
@@ -139,15 +118,18 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
             pInfo = &(pCheck->second);
             ++(pInfo->UseCount);
             xChild = pInfo->Storage;
+
+            aReadLock.clear();
+            // <- SAFE ------------------------------
         }
         else
         {
-            aReadLock.unlock();
+            aReadLock.clear();
             // <- SAFE ------------------------------
 
             try
             {
-                xChild = StorageHolder::openSubStorageWithFallback(xParent, sChild, nOpenMode, sal_True); // TODO think about delegating fallback decision to our own calli!
+                xChild = StorageHolder::openSubStorageWithFallback(xParent, sChild, nOpenMode, true); // TODO think about delegating fallback decision to our own calli!
             }
             catch(const css::uno::RuntimeException&)
                 { throw; }
@@ -156,7 +138,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
                     /* TODO URGENT!
                         in case we found some "already existing storages" on the path before and increased its UseCount ...
                         and now we will get an exception on creating a new sub storage ...
-                        we must decrease all UseCounts, which was touched before. Otherwise these storages cant be closed!
+                        we must decrease all UseCounts, which was touched before. Otherwise these storages can't be closed!
 
                         Idea: Using of another structure member "PossibleUseCount" as vector of unique numbers.
                         Every thread use another unique number to identify all "owned candidates".
@@ -166,13 +148,10 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
                     throw;
                 }
 
-            // SAFE -> ------------------------------
-            WriteGuard aWriteLock(m_aLock);
+            osl::MutexGuard g(m_mutex);
             pInfo = &(m_lStorages[sCheckPath]);
             pInfo->Storage  = xChild;
             pInfo->UseCount = 1;
-            aWriteLock.unlock();
-            // <- SAFE ------------------------------
         }
 
         xParent   = xChild;
@@ -186,21 +165,19 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openPath(const OUStri
     return xChild;
 }
 
-//-----------------------------------------------
 StorageHolder::TStorageList StorageHolder::getAllPathStorages(const OUString& sPath)
 {
     OUString sNormedPath = StorageHolder::impl_st_normPath(sPath);
     OUStringList    lFolders    = StorageHolder::impl_st_parsePath(sNormedPath);
 
     StorageHolder::TStorageList  lStoragesOfPath;
-    OUString              sRelPath       ;
-    OUStringList::const_iterator pIt            ;
+    OUString              sRelPath;
+    OUStringList::const_iterator pIt;
 
-    // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
 
     for (  pIt  = lFolders.begin();
-           pIt != lFolders.end()  ;
+           pIt != lFolders.end();
          ++pIt                    )
     {
         const OUString& sChild     = *pIt;
@@ -212,7 +189,7 @@ StorageHolder::TStorageList StorageHolder::getAllPathStorages(const OUString& sP
         if (pCheck == m_lStorages.end())
         {
             // at least one path element was not found
-            // Seems that this path isnt open ...
+            // Seems that this path isn't open ...
             lStoragesOfPath.clear();
             return lStoragesOfPath;
         }
@@ -224,13 +201,9 @@ StorageHolder::TStorageList StorageHolder::getAllPathStorages(const OUString& sP
         sRelPath += PATH_SEPARATOR;
     }
 
-    aReadLock.unlock();
-    // <- SAFE ----------------------------------
-
     return lStoragesOfPath;
 }
 
-//-----------------------------------------------
 void StorageHolder::commitPath(const OUString& sPath)
 {
     StorageHolder::TStorageList lStorages = getAllPathStorages(sPath);
@@ -238,7 +211,7 @@ void StorageHolder::commitPath(const OUString& sPath)
     css::uno::Reference< css::embed::XTransactedObject > xCommit;
     StorageHolder::TStorageList::reverse_iterator pIt;
     for (  pIt  = lStorages.rbegin(); // order of commit is important ... otherwise changes are not recognized!
-           pIt != lStorages.rend()  ;
+           pIt != lStorages.rend();
          ++pIt                      )
     {
         xCommit = css::uno::Reference< css::embed::XTransactedObject >(*pIt, css::uno::UNO_QUERY);
@@ -248,16 +221,15 @@ void StorageHolder::commitPath(const OUString& sPath)
     }
 
     // SAFE -> ------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
     xCommit = css::uno::Reference< css::embed::XTransactedObject >(m_xRoot, css::uno::UNO_QUERY);
-    aReadLock.unlock();
+    aReadLock.clear();
     // <- SAFE ------------------------------
 
     if (xCommit.is())
         xCommit->commit();
 }
 
-//-----------------------------------------------
 void StorageHolder::closePath(const OUString& rPath)
 {
     OUString sNormedPath = StorageHolder::impl_st_normPath(rPath);
@@ -268,10 +240,10 @@ void StorageHolder::closePath(const OUString& rPath)
         [1] = "path_2" => "path_1/path_2"
         [2] = "path_3" => "path_1/path_2/path_3"
     */
-    OUStringList::iterator pIt1       ;
+    OUStringList::iterator pIt1;
     OUString        sParentPath;
     for (  pIt1  = lFolders.begin();
-           pIt1 != lFolders.end()  ;
+           pIt1 != lFolders.end();
          ++pIt1                    )
     {
         OUString sCurrentRelPath  = sParentPath;
@@ -281,12 +253,11 @@ void StorageHolder::closePath(const OUString& rPath)
         sParentPath = sCurrentRelPath;
     }
 
-    // SAFE -> ------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
 
     OUStringList::reverse_iterator pIt2;
     for (  pIt2  = lFolders.rbegin();
-           pIt2 != lFolders.rend()  ;
+           pIt2 != lFolders.rend();
          ++pIt2                     )
     {
         OUString             sPath = *pIt2;
@@ -302,18 +273,13 @@ void StorageHolder::closePath(const OUString& rPath)
             m_lStorages.erase(pPath);
         }
     }
-
-    aReadLock.unlock();
-    // <- SAFE ------------------------------
 }
 
-//-----------------------------------------------
 void StorageHolder::notifyPath(const OUString& sPath)
 {
     OUString sNormedPath = StorageHolder::impl_st_normPath(sPath);
 
-    // SAFE -> ------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
 
     TPath2StorageInfo::iterator pIt1 = m_lStorages.find(sNormedPath);
     if (pIt1 == m_lStorages.end())
@@ -322,26 +288,21 @@ void StorageHolder::notifyPath(const OUString& sPath)
     TStorageInfo& rInfo = pIt1->second;
     TStorageListenerList::iterator pIt2;
     for (  pIt2  = rInfo.Listener.begin();
-           pIt2 != rInfo.Listener.end()  ;
+           pIt2 != rInfo.Listener.end();
          ++pIt2                          )
     {
         IStorageListener* pListener = *pIt2;
         if (pListener)
             pListener->changesOccurred(sNormedPath);
     }
-
-    aReadLock.unlock();
-    // <- SAFE ------------------------------
 }
 
-//-----------------------------------------------
 void StorageHolder::addStorageListener(      IStorageListener* pListener,
                                        const OUString&  sPath    )
 {
     OUString sNormedPath = StorageHolder::impl_st_normPath(sPath);
 
-    // SAFE -> ------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
 
     TPath2StorageInfo::iterator pIt1 = m_lStorages.find(sNormedPath);
     if (pIt1 == m_lStorages.end())
@@ -351,19 +312,14 @@ void StorageHolder::addStorageListener(      IStorageListener* pListener,
     TStorageListenerList::iterator pIt2 = ::std::find(rInfo.Listener.begin(), rInfo.Listener.end(), pListener);
     if (pIt2 == rInfo.Listener.end())
         rInfo.Listener.push_back(pListener);
-
-    aReadLock.unlock();
-    // <- SAFE ------------------------------
 }
 
-//-----------------------------------------------
 void StorageHolder::removeStorageListener(      IStorageListener* pListener,
                                           const OUString&  sPath    )
 {
     OUString sNormedPath = StorageHolder::impl_st_normPath(sPath);
 
-    // SAFE -> ------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
 
     TPath2StorageInfo::iterator pIt1 = m_lStorages.find(sNormedPath);
     if (pIt1 == m_lStorages.end())
@@ -373,20 +329,15 @@ void StorageHolder::removeStorageListener(      IStorageListener* pListener,
     TStorageListenerList::iterator pIt2 = ::std::find(rInfo.Listener.begin(), rInfo.Listener.end(), pListener);
     if (pIt2 != rInfo.Listener.end())
         rInfo.Listener.erase(pIt2);
-
-    aReadLock.unlock();
-    // <- SAFE ------------------------------
 }
 
-//-----------------------------------------------
 OUString StorageHolder::getPathOfStorage(const css::uno::Reference< css::embed::XStorage >& xStorage)
 {
-    // SAFE -> ------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
 
     TPath2StorageInfo::const_iterator pIt;
     for (  pIt  = m_lStorages.begin();
-           pIt != m_lStorages.end()  ;
+           pIt != m_lStorages.end();
          ++pIt                       )
     {
         const TStorageInfo& rInfo = pIt->second;
@@ -398,18 +349,14 @@ OUString StorageHolder::getPathOfStorage(const css::uno::Reference< css::embed::
         return OUString();
 
     return pIt->first;
-
-    // <- SAFE ------------------------------
 }
 
-//-----------------------------------------------
 css::uno::Reference< css::embed::XStorage > StorageHolder::getParentStorage(const css::uno::Reference< css::embed::XStorage >& xChild)
 {
     OUString sChildPath = getPathOfStorage(xChild);
     return getParentStorage(sChildPath);
 }
 
-//-----------------------------------------------
 css::uno::Reference< css::embed::XStorage > StorageHolder::getParentStorage(const OUString& sChildPath)
 {
     // normed path = "a/b/c/" ... we search for "a/b/"
@@ -426,7 +373,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::getParentStorage(cons
         return css::uno::Reference< css::embed::XStorage >();
 
     // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
 
     // b)
     if (c < 2)
@@ -445,7 +392,7 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::getParentStorage(cons
     if (pParent != m_lStorages.end())
         return pParent->second.Storage;
 
-    aReadLock.unlock();
+    aReadLock.clear();
     // <- SAFE ----------------------------------
 
     // ?
@@ -453,24 +400,17 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::getParentStorage(cons
     return css::uno::Reference< css::embed::XStorage >();
 }
 
-//-----------------------------------------------
 void StorageHolder::operator=(const StorageHolder& rCopy)
 {
-    // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
-
+    osl::MutexGuard g(m_mutex);
     m_xRoot     = rCopy.m_xRoot;
     m_lStorages = rCopy.m_lStorages;
-
-    aWriteLock.unlock();
-    // <- SAFE ----------------------------------
 }
 
-//-----------------------------------------------
 css::uno::Reference< css::embed::XStorage > StorageHolder::openSubStorageWithFallback(const css::uno::Reference< css::embed::XStorage >& xBaseStorage  ,
                                                                                       const OUString&                             sSubStorage   ,
                                                                                             sal_Int32                                    eOpenMode     ,
-                                                                                            sal_Bool                                     bAllowFallback)
+                                                                                            bool                                     bAllowFallback)
 {
     // a) try it first with user specified open mode
     //    ignore errors ... but save it for later use!
@@ -506,11 +446,10 @@ css::uno::Reference< css::embed::XStorage > StorageHolder::openSubStorageWithFal
     return css::uno::Reference< css::embed::XStorage >();
 }
 
-//-----------------------------------------------
 css::uno::Reference< css::io::XStream > StorageHolder::openSubStreamWithFallback(const css::uno::Reference< css::embed::XStorage >& xBaseStorage  ,
                                                                                  const OUString&                             sSubStream    ,
                                                                                        sal_Int32                                    eOpenMode     ,
-                                                                                       sal_Bool                                     bAllowFallback)
+                                                                                       bool                                     bAllowFallback)
 {
     // a) try it first with user specified open mode
     //    ignore errors ... but save it for later use!
@@ -546,7 +485,6 @@ css::uno::Reference< css::io::XStream > StorageHolder::openSubStreamWithFallback
     return css::uno::Reference< css::io::XStream >();
 }
 
-//-----------------------------------------------
 OUString StorageHolder::impl_st_normPath(const OUString& sPath)
 {
     // path must start without "/" but end with "/"!
@@ -568,7 +506,6 @@ OUString StorageHolder::impl_st_normPath(const OUString& sPath)
     return sNormedPath;
 }
 
-//-----------------------------------------------
 OUStringList StorageHolder::impl_st_parsePath(const OUString& sPath)
 {
     OUStringList lToken;
@@ -583,7 +520,6 @@ OUStringList StorageHolder::impl_st_parsePath(const OUString& sPath)
     return lToken;
 }
 
-//===============================================
 } // namespace framework
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
