@@ -42,13 +42,13 @@ namespace oox {
 namespace drawingml {
 namespace chart {
 
-// ============================================================================
+
 
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::chart2;
 using namespace ::com::sun::star::uno;
 
-// ============================================================================
+
 
 namespace {
 
@@ -129,7 +129,7 @@ bool isPercent( const RefVector<TypeGroupConverter>& rTypeGroups )
 
 } // namespace
 
-// ============================================================================
+
 
 AxisConverter::AxisConverter( const ConverterRoot& rParent, AxisModel& rModel ) :
     ConverterBase< AxisModel >( rParent, rModel )
@@ -341,7 +341,7 @@ void AxisConverter::convertFromModel(
         {
             case XML_min:       eAxisPos = cssc::ChartAxisPosition_START;   break;
             case XML_max:       eAxisPos = cssc::ChartAxisPosition_END;     break;
-            case XML_autoZero:  eAxisPos = cssc::ChartAxisPosition_VALUE;   break;
+            case XML_autoZero:  eAxisPos = cssc::ChartAxisPosition_ZERO;   break;
         }
         if( !mrModel.mbAuto )
             aAxisProp.setProperty( PROP_CrossoverPosition, eAxisPos );
@@ -360,6 +360,10 @@ void AxisConverter::convertFromModel(
             TitleConverter aTitleConv( *this, *mrModel.mxTitle );
             aTitleConv.convertFromModel( xTitled, "Axis Title", OBJECTTYPE_AXISTITLE, nAxesSetIdx, nAxisIdx );
         }
+
+        // axis data unit label -----------------------------------------------
+        AxisDispUnitsConverter axisDispUnitsConverter (*this, mrModel.mxDispUnits.getOrCreate());
+        axisDispUnitsConverter.convertFromModel(xAxis);
     }
     catch( Exception& )
     {
@@ -376,7 +380,27 @@ void AxisConverter::convertFromModel(
     }
 }
 
-// ============================================================================
+
+
+AxisDispUnitsConverter::AxisDispUnitsConverter( const ConverterRoot& rParent, AxisDispUnitsModel& rModel ) :
+    ConverterBase< AxisDispUnitsModel >( rParent, rModel )
+{
+}
+
+AxisDispUnitsConverter::~AxisDispUnitsConverter()
+{
+}
+
+void AxisDispUnitsConverter::convertFromModel( const Reference< XAxis >& rxAxis )
+{
+    PropertySet aPropSet( rxAxis );
+    if (!(mrModel.mnBuiltInUnit).isEmpty() )
+    {
+        aPropSet.setProperty(PROP_DisplayUnits, true);
+        aPropSet.setProperty( PROP_BuiltInUnit, mrModel.mnBuiltInUnit );
+    }
+}
+
 
 } // namespace chart
 } // namespace drawingml
