@@ -16,6 +16,10 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
+
+#include <sal/config.h>
+
+#include <boost/noncopyable.hpp>
 #include <com/sun/star/packages/zip/ZipIOException.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/beans/NamedValue.hpp>
@@ -41,7 +45,6 @@
 #include <comphelper/processfactory.hxx>
 #include <comphelper/genericpropertyset.hxx>
 #include <unotools/mediadescriptor.hxx>
-#include <cppuhelper/supportsservice.hxx>
 #include <xmloff/ProgressBarHelper.hxx>
 #include <sfx2/docfile.hxx>
 #include <com/sun/star/io/XInputStream.hpp>
@@ -59,9 +62,6 @@
 #include <xmloff/txtprmap.hxx>
 #include "ReportDefinition.hxx"
 
-
-#define MAP_LEN(x) x, sizeof(x) - 1
-//--------------------------------------------------------------------------
 namespace rptxml
 {
 using namespace ::com::sun::star::uno;
@@ -81,25 +81,24 @@ using namespace xmloff;
 
     using namespace ::com::sun::star::util;
 
-class RptMLMasterStylesContext_Impl : public XMLTextMasterStylesContext
+class RptMLMasterStylesContext_Impl:
+    public XMLTextMasterStylesContext, private boost::noncopyable
 {
     ORptFilter& m_rImport;
-    RptMLMasterStylesContext_Impl(const RptMLMasterStylesContext_Impl&);
-    void operator =(const RptMLMasterStylesContext_Impl&);
+
 public:
 
-    TYPEINFO();
+    TYPEINFO_OVERRIDE();
 
     RptMLMasterStylesContext_Impl(
             ORptFilter& rImport, sal_uInt16 nPrfx,
             const OUString& rLName ,
             const uno::Reference< xml::sax::XAttributeList > & xAttrList );
     virtual ~RptMLMasterStylesContext_Impl();
-    virtual void EndElement();
+    virtual void EndElement() SAL_OVERRIDE;
 };
 
 TYPEINIT1( RptMLMasterStylesContext_Impl, XMLTextMasterStylesContext );
-DBG_NAME(rpt_RptMLMasterStylesContext_Impl)
 RptMLMasterStylesContext_Impl::RptMLMasterStylesContext_Impl(
         ORptFilter& rImport, sal_uInt16 nPrfx,
         const OUString& rLName ,
@@ -107,19 +106,18 @@ RptMLMasterStylesContext_Impl::RptMLMasterStylesContext_Impl(
     XMLTextMasterStylesContext( rImport, nPrfx, rLName, xAttrList )
     ,m_rImport(rImport)
 {
-    DBG_CTOR(rpt_RptMLMasterStylesContext_Impl,NULL);
 }
 
 RptMLMasterStylesContext_Impl::~RptMLMasterStylesContext_Impl()
 {
-    DBG_DTOR(rpt_RptMLMasterStylesContext_Impl,NULL);
 }
 
 void RptMLMasterStylesContext_Impl::EndElement()
 {
-    FinishStyles( sal_True );
+    FinishStyles( true );
     m_rImport.FinishStyles();
 }
+
     /// read a component (file + filter version)
 sal_Int32 ReadThroughComponent(
     const uno::Reference<XInputStream>& xInputStream,
@@ -127,7 +125,7 @@ sal_Int32 ReadThroughComponent(
     const sal_Char* /*pStreamName*/,
     const uno::Reference<XComponentContext> & rContext,
     const uno::Reference< XDocumentHandler >& _xFilter,
-    sal_Bool /*bEncrypted*/ )
+    bool /*bEncrypted*/ )
 {
     OSL_ENSURE(xInputStream.is(), "input stream missing");
     OSL_ENSURE(xModelComponent.is(), "document missing");
@@ -211,7 +209,7 @@ sal_Int32 ReadThroughComponent(
     if ( xStorage.is() )
     {
         uno::Reference< io::XStream > xDocStream;
-        sal_Bool bEncrypted = sal_False;
+        bool bEncrypted = false;
 
         try
         {
@@ -282,35 +280,35 @@ sal_Int32 ReadThroughComponent(
     return 1;
 }
 
-//---------------------------------------------------------------------
+
 uno::Reference< uno::XInterface > ORptImportHelper::create(uno::Reference< uno::XComponentContext > const & xContext)
 {
     return static_cast< XServiceInfo* >(new ORptFilter(xContext, IMPORT_SETTINGS ));
 }
-//---------------------------------------------------------------------
+
 OUString ORptImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
 {
     return OUString(SERVICE_SETTINGSIMPORTER);
 }
-//---------------------------------------------------------------------
+
 Sequence< OUString > ORptImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
     Sequence< OUString > aSupported(1);
     aSupported[0] = SERVICE_IMPORTFILTER;
     return aSupported;
 }
-//---------------------------------------------------------------------
+
 Reference< XInterface > ORptContentImportHelper::create(const Reference< XComponentContext > & xContext)
 {
     return static_cast< XServiceInfo* >(new ORptFilter(xContext,IMPORT_AUTOSTYLES |   IMPORT_CONTENT | IMPORT_SCRIPTS |
         IMPORT_FONTDECLS ));
 }
-//---------------------------------------------------------------------
+
 OUString ORptContentImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
 {
     return OUString(SERVICE_CONTENTIMPORTER);
 }
-//---------------------------------------------------------------------
+
 Sequence< OUString > ORptContentImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
     Sequence< OUString > aSupported(1);
@@ -318,19 +316,19 @@ Sequence< OUString > ORptContentImportHelper::getSupportedServiceNames_Static(
     return aSupported;
 }
 
-//---------------------------------------------------------------------
+
 Reference< XInterface > ORptStylesImportHelper::create(Reference< XComponentContext > const & xContext)
 {
     return static_cast< XServiceInfo* >(new ORptFilter(xContext,
         IMPORT_STYLES | IMPORT_MASTERSTYLES | IMPORT_AUTOSTYLES |
         IMPORT_FONTDECLS ));
 }
-//---------------------------------------------------------------------
+
 OUString ORptStylesImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
 {
     return OUString(SERVICE_STYLESIMPORTER);
 }
-//---------------------------------------------------------------------
+
 Sequence< OUString > ORptStylesImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
     Sequence< OUString > aSupported(1);
@@ -338,18 +336,18 @@ Sequence< OUString > ORptStylesImportHelper::getSupportedServiceNames_Static(  )
     return aSupported;
 }
 
-//---------------------------------------------------------------------
+
 Reference< XInterface > ORptMetaImportHelper::create(Reference< XComponentContext > const & xContext)
 {
     return static_cast< XServiceInfo* >(new ORptFilter(xContext,
         IMPORT_META));
 }
-//---------------------------------------------------------------------
+
 OUString ORptMetaImportHelper::getImplementationName_Static(  ) throw (RuntimeException)
 {
     return OUString(SERVICE_METAIMPORTER);
 }
-//---------------------------------------------------------------------
+
 Sequence< OUString > ORptMetaImportHelper::getSupportedServiceNames_Static(  ) throw(RuntimeException)
 {
     Sequence< OUString > aSupported(1);
@@ -357,14 +355,12 @@ Sequence< OUString > ORptMetaImportHelper::getSupportedServiceNames_Static(  ) t
     return aSupported;
 }
 
-// -------------
+
 // - ORptFilter -
-// -------------
-DBG_NAME(rpt_ORptFilter)
+
 ORptFilter::ORptFilter( const uno::Reference< XComponentContext >& _rxContext,sal_uInt16 nImportFlags )
-    :SvXMLImport(_rxContext,nImportFlags)
+    :SvXMLImport(_rxContext, getImplementationName_Static(), nImportFlags)
 {
-    DBG_CTOR(rpt_ORptFilter,NULL);
     GetMM100UnitConverter().SetCoreMeasureUnit(util::MeasureUnit::MM_100TH);
     GetMM100UnitConverter().SetXMLMeasureUnit(util::MeasureUnit::CM);
     GetNamespaceMap().Add( OUString( sXML_np__rpt ),
@@ -382,30 +378,23 @@ ORptFilter::ORptFilter( const uno::Reference< XComponentContext >& _rxContext,sa
     m_xTableStylesPropertySetMapper = new XMLTextPropertySetMapper( TEXT_PROP_MAP_TABLE_DEFAULTS, false );
 }
 
-// -----------------------------------------------------------------------------
+
 
 ORptFilter::~ORptFilter() throw()
 {
-    DBG_DTOR(rpt_ORptFilter,NULL);
 }
-//------------------------------------------------------------------------------
+
 uno::Reference< XInterface > ORptFilter::create(uno::Reference< XComponentContext > const & xContext)
 {
     return *(new ORptFilter(xContext));
 }
 
-// -----------------------------------------------------------------------------
+
 OUString ORptFilter::getImplementationName_Static(  ) throw(uno::RuntimeException)
 {
     return OUString("com.sun.star.comp.report.OReportFilter");
 }
 
-//--------------------------------------------------------------------------
-OUString SAL_CALL ORptFilter::getImplementationName(  ) throw(uno::RuntimeException)
-{
-    return getImplementationName_Static();
-}
-//--------------------------------------------------------------------------
 uno::Sequence< OUString > ORptFilter::getSupportedServiceNames_Static(  ) throw(uno::RuntimeException)
 {
     uno::Sequence< OUString > aServices(1);
@@ -414,22 +403,11 @@ uno::Sequence< OUString > ORptFilter::getSupportedServiceNames_Static(  ) throw(
     return aServices;
 }
 
-//--------------------------------------------------------------------------
-uno::Sequence< OUString > SAL_CALL ORptFilter::getSupportedServiceNames(  ) throw(uno::RuntimeException)
-{
-    return getSupportedServiceNames_Static();
-}
-//------------------------------------------------------------------------------
-sal_Bool SAL_CALL ORptFilter::supportsService(const OUString& ServiceName) throw( uno::RuntimeException )
-{
-    return cppu::supportsService(this, ServiceName);
-}
-// -----------------------------------------------------------------------------
 sal_Bool SAL_CALL ORptFilter::filter( const Sequence< PropertyValue >& rDescriptor )
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     Window*     pFocusWindow = Application::GetFocusWindow();
-    sal_Bool    bRet = sal_False;
+    bool    bRet = false;
 
     if( pFocusWindow )
         pFocusWindow->EnterWait();
@@ -442,8 +420,8 @@ sal_Bool SAL_CALL ORptFilter::filter( const Sequence< PropertyValue >& rDescript
 
     return bRet;
 }
-// -----------------------------------------------------------------------------
-sal_Bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
+
+bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
     throw (RuntimeException)
 {
     OUString                     sFileName;
@@ -494,13 +472,13 @@ sal_Bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
             }
         }
     }
-    sal_Bool bRet = xStorage.is();
+    bool bRet = xStorage.is();
     if ( bRet )
     {
         m_xReportDefinition.set(GetModel(),UNO_QUERY_THROW);
         OSL_ENSURE(m_xReportDefinition.is(),"ReportDefinition is NULL!");
         if ( !m_xReportDefinition.is() )
-            return sal_False;
+            return false;
 
 #if OSL_DEBUG_LEVEL > 1
         uno::Reference < container::XNameAccess > xAccess( xStorage, uno::UNO_QUERY );
@@ -528,14 +506,14 @@ sal_Bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
         xEmbeddedObjectResolver.set( xReportServiceFactory->createInstanceWithArguments(OUString("com.sun.star.document.ImportEmbeddedObjectResolver"),aArgs) , uno::UNO_QUERY);
 
         static const OUString s_sOld("OldFormat");
-        static comphelper::PropertyMapEntry pMap[] =
+        static comphelper::PropertyMapEntry const pMap[] =
         {
-            { MAP_LEN( "OldFormat" ), 1,    &::getCppuType((const sal_Bool*)0),                 beans::PropertyAttribute::BOUND,     0 },
-            { MAP_LEN( "StreamName"), 0,    &::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
-            { MAP_LEN("PrivateData"), 0,    &::getCppuType( (uno::Reference<XInterface> *)0 ),  beans::PropertyAttribute::MAYBEVOID, 0 },
-            { MAP_LEN( "BaseURI"),    0,    &::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
-            { MAP_LEN( "StreamRelPath"), 0, &::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
-            { NULL, 0, 0, NULL, 0, 0 }
+            { OUString("OldFormat") , 1,    ::getCppuType((const sal_Bool*)0),                 beans::PropertyAttribute::BOUND,     0 },
+            { OUString("StreamName"), 0,    ::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("PrivateData"),0,    ::getCppuType( (uno::Reference<XInterface> *)0 ),  beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("BaseURI"),    0,    ::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("StreamRelPath"), 0, ::getCppuType( (OUString *)0 ),             beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString(), 0, css::uno::Type(), 0, 0 }
         };
         utl::MediaDescriptor aDescriptor(rDescriptor);
         uno::Reference<beans::XPropertySet> xProp = comphelper::GenericPropertySet_CreateInstance(new comphelper::PropertySetInfo(pMap));
@@ -635,7 +613,7 @@ sal_Bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
                         // TODO/LATER: this is completely wrong! Filter code should never call ErrorHandler directly! But for now this is the only way!
                         ErrorHandler::HandleError( nRet );
                         if( nRet & ERRCODE_WARNING_MASK )
-                            bRet = sal_True;
+                            bRet = true;
                     }
             }
         }
@@ -643,7 +621,7 @@ sal_Bool ORptFilter::implImport( const Sequence< PropertyValue >& rDescriptor )
 
     return bRet;
 }
-// -----------------------------------------------------------------------------
+
 SvXMLImportContext* ORptFilter::CreateContext( sal_uInt16 nPrefix,
                                       const OUString& rLocalName,
                                       const uno::Reference< xml::sax::XAttributeList >& xAttrList )
@@ -674,13 +652,13 @@ SvXMLImportContext* ORptFilter::CreateContext( sal_uInt16 nPrefix,
             break;
         case XML_TOK_DOC_STYLES:
             GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-            pContext = CreateStylesContext( rLocalName, xAttrList, sal_False);
+            pContext = CreateStylesContext( rLocalName, xAttrList, false);
             break;
         case XML_TOK_DOC_AUTOSTYLES:
             // don't use the autostyles from the styles-document for the progress
             if ( ! IsXMLToken( rLocalName, XML_DOCUMENT_STYLES ) )
                 GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-            pContext = CreateStylesContext( rLocalName, xAttrList, sal_True);
+            pContext = CreateStylesContext( rLocalName, xAttrList, true);
             break;
         case XML_TOK_DOC_FONTDECLS:
             GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
@@ -706,7 +684,7 @@ SvXMLImportContext* ORptFilter::CreateContext( sal_uInt16 nPrefix,
 
     return pContext;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetDocElemTokenMap() const
 {
     if ( !m_pDocElemTokenMap.get() )
@@ -727,21 +705,21 @@ const SvXMLTokenMap& ORptFilter::GetDocElemTokenMap() const
     }
     return *m_pDocElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetReportElemTokenMap() const
 {
     if ( !m_pReportElemTokenMap.get() )
         m_pReportElemTokenMap.reset(OXMLHelper::GetReportElemTokenMap());
     return *m_pReportElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetSubDocumentElemTokenMap() const
 {
     if ( !m_pSubDocumentElemTokenMap.get() )
         m_pSubDocumentElemTokenMap.reset(OXMLHelper::GetSubDocumentElemTokenMap());
     return *m_pSubDocumentElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetFunctionElemTokenMap() const
 {
     if ( !m_pFunctionElemTokenMap.get() )
@@ -759,7 +737,7 @@ const SvXMLTokenMap& ORptFilter::GetFunctionElemTokenMap() const
     }
     return *m_pFunctionElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetFormatElemTokenMap() const
 {
     if ( !m_pFormatElemTokenMap.get() )
@@ -775,7 +753,7 @@ const SvXMLTokenMap& ORptFilter::GetFormatElemTokenMap() const
     }
     return *m_pFormatElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetGroupElemTokenMap() const
 {
     if ( !m_pGroupElemTokenMap.get() )
@@ -801,7 +779,7 @@ const SvXMLTokenMap& ORptFilter::GetGroupElemTokenMap() const
     }
     return *m_pGroupElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetReportElementElemTokenMap() const
 {
     if ( !m_pElemTokenMap.get() )
@@ -819,7 +797,7 @@ const SvXMLTokenMap& ORptFilter::GetReportElementElemTokenMap() const
     }
     return *m_pElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetControlElemTokenMap() const
 {
     if ( !m_pControlElemTokenMap.get() )
@@ -841,7 +819,7 @@ const SvXMLTokenMap& ORptFilter::GetControlElemTokenMap() const
     }
     return *m_pControlElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetControlPropertyElemTokenMap() const
 {
     if ( !m_pControlElemTokenMap.get() )
@@ -863,7 +841,7 @@ const SvXMLTokenMap& ORptFilter::GetControlPropertyElemTokenMap() const
     }
     return *m_pControlElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetComponentElemTokenMap() const
 {
     if ( !m_pComponentElemTokenMap.get() )
@@ -879,7 +857,7 @@ const SvXMLTokenMap& ORptFilter::GetComponentElemTokenMap() const
     }
     return *m_pComponentElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetColumnTokenMap() const
 {
     if ( !m_pColumnTokenMap.get() )
@@ -903,7 +881,7 @@ const SvXMLTokenMap& ORptFilter::GetColumnTokenMap() const
     }
     return *m_pColumnTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetSectionElemTokenMap() const
 {
     if ( !m_pSectionElemTokenMap.get() )
@@ -926,7 +904,7 @@ const SvXMLTokenMap& ORptFilter::GetSectionElemTokenMap() const
     }
     return *m_pSectionElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 const SvXMLTokenMap& ORptFilter::GetCellElemTokenMap() const
 {
     if ( !m_pCellElemTokenMap.get() )
@@ -951,9 +929,9 @@ const SvXMLTokenMap& ORptFilter::GetCellElemTokenMap() const
     }
     return *m_pCellElemTokenMap;
 }
-// -----------------------------------------------------------------------------
+
 SvXMLImportContext* ORptFilter::CreateStylesContext(const OUString& rLocalName,
-                                     const uno::Reference< XAttributeList>& xAttrList, sal_Bool bIsAutoStyle )
+                                     const uno::Reference< XAttributeList>& xAttrList, bool bIsAutoStyle )
 {
     SvXMLImportContext* pContext = bIsAutoStyle ? GetAutoStyles() : GetStyles();
     if ( !pContext )
@@ -966,20 +944,20 @@ SvXMLImportContext* ORptFilter::CreateStylesContext(const OUString& rLocalName,
     }
     return pContext;
 }
-// -----------------------------------------------------------------------------
+
 SvXMLImport&         ORptFilter::getGlobalContext()
 {
     return *this;
 }
-// -----------------------------------------------------------------------------
+
 void ORptFilter::enterEventContext()
 {
 }
-// -----------------------------------------------------------------------------
+
 void ORptFilter::leaveEventContext()
 {
 }
-// -----------------------------------------------------------------------------
+
 SvXMLImportContext *ORptFilter::CreateFontDeclsContext(
         const OUString& rLocalName,
         const uno::Reference< xml::sax::XAttributeList > & xAttrList )
@@ -991,25 +969,25 @@ SvXMLImportContext *ORptFilter::CreateFontDeclsContext(
     SetFontDecls( pFSContext );
     return pFSContext;
 }
-// -----------------------------------------------------------------------------
+
 XMLShapeImportHelper* ORptFilter::CreateShapeImport()
 {
     return new XMLShapeImportHelper( *this,GetModel() );
 }
-// -----------------------------------------------------------------------------
+
 void ORptFilter::FinishStyles()
 {
     if( GetStyles() )
-        GetStyles()->FinishStyles( sal_True );
+        GetStyles()->FinishStyles( true );
 }
-// -----------------------------------------------------------------------------
+
 OUString ORptFilter::convertFormula(const OUString& _sFormula)
 {
     return _sFormula;
 }
-// -----------------------------------------------------------------------------
+
 void SAL_CALL ORptFilter::startDocument( void )
-    throw( xml::sax::SAXException, uno::RuntimeException )
+    throw( xml::sax::SAXException, uno::RuntimeException, std::exception )
 {
     m_xReportDefinition.set(GetModel(),UNO_QUERY_THROW);
     OSL_ENSURE(m_xReportDefinition.is(),"ReportDefinition is NULL!");
@@ -1021,9 +999,9 @@ void SAL_CALL ORptFilter::startDocument( void )
         SvXMLImport::startDocument();
     }
 }
-// -----------------------------------------------------------------------------
+
 void ORptFilter::endDocument( void )
-    throw( xml::sax::SAXException, uno::RuntimeException )
+    throw( xml::sax::SAXException, uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( GetModel().is(), "model missing; maybe startDocument wasn't called?" );
     if( !GetModel().is() )
@@ -1040,17 +1018,17 @@ void ORptFilter::endDocument( void )
     // delegate to parent: takes care of error handling
     SvXMLImport::endDocument();
 }
-// -----------------------------------------------------------------------------
+
 void ORptFilter::removeFunction(const OUString& _sFunctionName)
 {
     m_aFunctions.erase(_sFunctionName);
 }
-// -----------------------------------------------------------------------------
+
 void ORptFilter::insertFunction(const ::com::sun::star::uno::Reference< ::com::sun::star::report::XFunction > & _xFunction)
 {
     m_aFunctions.insert(TGroupFunctionMap::value_type(_xFunction->getName(),_xFunction));
 }
-// -----------------------------------------------------------------------------
+
 SvXMLImportContext* ORptFilter::CreateMetaContext(const OUString& rLocalName,const uno::Reference<xml::sax::XAttributeList>&)
 {
     SvXMLImportContext* pContext = NULL;
@@ -1062,10 +1040,10 @@ SvXMLImportContext* ORptFilter::CreateMetaContext(const OUString& rLocalName,con
     }
     return pContext;
 }
-// -----------------------------------------------------------------------------
-sal_Bool ORptFilter::isOldFormat() const
+
+bool ORptFilter::isOldFormat() const
 {
-    sal_Bool bOldFormat = sal_True;
+    bool bOldFormat = true;
     uno::Reference<beans::XPropertySet> xProp = getImportInfo();
     if ( xProp.is() )
     {
@@ -1078,8 +1056,8 @@ sal_Bool ORptFilter::isOldFormat() const
     return bOldFormat;
 }
 
-// -----------------------------------------------------------------------------
+
 }// rptxml
-// -----------------------------------------------------------------------------
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
