@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <cstdlib>
+
 #include "scitems.hxx"
 #include <comphelper/string.hxx>
 #include <editeng/eeitem.hxx>
@@ -33,6 +37,7 @@
 #include <svl/whiter.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/help.hxx>
+#include <vcl/settings.hxx>
 #include <tools/urlobj.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/printer.hxx>
@@ -73,19 +78,21 @@
 
 using namespace com::sun::star;
 
-// -----------------------------------------------------------------------
-
 #define ScPreviewShell
 #include "scslots.hxx"
 
+#include <boost/scoped_ptr.hpp>
+
 TYPEINIT1( ScPreviewShell, SfxViewShell );
 
-SFX_IMPL_INTERFACE( ScPreviewShell, SfxViewShell, ScResId(SCSTR_PREVIEWSHELL) )
+SFX_IMPL_INTERFACE(ScPreviewShell, SfxViewShell, ScResId(SCSTR_PREVIEWSHELL))
+
+void ScPreviewShell::InitInterface_Impl()
 {
-    SFX_OBJECTBAR_REGISTRATION(SFX_OBJECTBAR_OBJECT|SFX_VISIBILITY_STANDARD|
-                                SFX_VISIBILITY_SERVER|SFX_VISIBILITY_READONLYDOC,
-                                ScResId(RID_OBJECTBAR_PREVIEW));
-    SFX_POPUPMENU_REGISTRATION(ScResId(RID_POPUP_PREVIEW));
+    GetStaticInterface()->RegisterObjectBar(SFX_OBJECTBAR_OBJECT|SFX_VISIBILITY_STANDARD|SFX_VISIBILITY_SERVER|SFX_VISIBILITY_READONLYDOC,
+                                            ScResId(RID_OBJECTBAR_PREVIEW));
+
+    GetStaticInterface()->RegisterPopupMenu(ScResId(RID_POPUP_PREVIEW));
 }
 
 SFX_IMPL_NAMED_VIEWFACTORY( ScPreviewShell, "PrintPreview" )
@@ -93,8 +100,6 @@ SFX_IMPL_NAMED_VIEWFACTORY( ScPreviewShell, "PrintPreview" )
     SFX_VIEW_REGISTRATION(ScDocShell);
 }
 
-//------------------------------------------------------------------
-
 void ScPreviewShell::Construct( Window* pParent )
 {
     // Find the top-most window, and set the close window handler to intercept
@@ -129,8 +134,8 @@ void ScPreviewShell::Construct( Window* pParent )
 
     SetPool( &SC_MOD()->GetPool() );
     SetWindow( pPreview );
-    StartListening(*pDocShell,sal_True);
-    StartListening(*SFX_APP(),sal_True);        // #i62045# #i62046# application is needed for Calc's own hints
+    StartListening(*pDocShell,true);
+    StartListening(*SFX_APP(),true);        // #i62045# #i62046# application is needed for Calc's own hints
     SfxBroadcaster* pDrawBC = pDocShell->GetDocument()->GetDrawBroadcaster();
     if (pDrawBC)
         StartListening(*pDrawBC);
@@ -148,6 +153,7 @@ ScPreviewShell::ScPreviewShell( SfxViewFrame* pViewFrame,
     pDocShell( (ScDocShell*)pViewFrame->GetObjectShell() ),
     mpFrameWindow(NULL),
     nSourceDesignMode( SC_FORCEMODE_NONE ),
+    nMaxVertPos(0),
     pAccessibilityBroadcaster( NULL )
 {
     Construct( &pViewFrame->GetWindow() );
@@ -204,8 +210,6 @@ void ScPreviewShell::InitStartTable(SCTAB nTab)
     pPreview->SetPageNo( pPreview->GetFirstPage(nTab) );
 }
 
-//------------------------------------------------------------------
-
 OUString ScPreviewShell::GetDescription() const
 {
     return OUString(" ** Test ** ");
@@ -268,8 +272,8 @@ void ScPreviewShell::UpdateNeededScrollBars( bool bFromZoom )
         return;
 
     //  for centering, page size without the shadow is used
-    bool bVert = pVerScroll ? pVerScroll->IsVisible() : false;
-    bool bHori = pHorScroll ? pHorScroll->IsVisible() : false;
+    bool bVert = pVerScroll->IsVisible();
+    bool bHori = pHorScroll->IsVisible();
     Size aWindowSize = pPreview->GetOutputSize();
     Point aPos = pPreview->GetPosPixel();
     Size aWindowPixelSize = pPreview->GetOutputSizePixel();
@@ -418,7 +422,7 @@ IMPL_LINK (ScPreviewShell,ScrollHandler, ScrollBar* ,pScroll )
     long nTotalPages    = pPreview->GetTotalPages();
     long nPageNo        = 0;
     long nPerPageLength = 0;
-    sal_Bool bIsDivide      = sal_True;
+    bool bIsDivide      = true;
 
     if( nTotalPages )
         nPerPageLength = nMaxRange / nTotalPages;
@@ -433,7 +437,7 @@ IMPL_LINK (ScPreviewShell,ScrollHandler, ScrollBar* ,pScroll )
         }
     }
 
-    sal_Bool bHoriz = ( pScroll == pHorScroll );
+    bool bHoriz = ( pScroll == pHorScroll );
 
     if( bHoriz )
         pPreview->SetXOffset( nPos );
@@ -462,7 +466,7 @@ IMPL_LINK (ScPreviewShell,ScrollHandler, ScrollBar* ,pScroll )
             }
             else if( nDelta > 0 )
             {
-                sal_Bool bAllTested = pPreview->AllTested();
+                bool bAllTested = pPreview->AllTested();
                 if ( nTotalPages && ( nPageNo < nTotalPages || !bAllTested ) )
                     pPreview->SetPageNo( nPageNo );
 
@@ -474,7 +478,7 @@ IMPL_LINK (ScPreviewShell,ScrollHandler, ScrollBar* ,pScroll )
             aRect.Left()    = aPos.X() - 8;
             aRect.Top()     = aMousePos.Y();
             aRect.Right()   = aRect.Left();
-            aRect.Top()     = aRect.Top();
+            aRect.Bottom()  = aRect.Top();
             nAlign          = QUICKHELP_BOTTOM|QUICKHELP_CENTER;
             Help::ShowQuickHelp( pScroll->GetParent(), aRect, aHelpStr, nAlign );
         }
@@ -489,9 +493,9 @@ IMPL_LINK (ScPreviewShell, CloseHdl, SystemWindow*, EMPTYARG)
     return 0;
 }
 
-sal_Bool ScPreviewShell::ScrollCommand( const CommandEvent& rCEvt )
+bool ScPreviewShell::ScrollCommand( const CommandEvent& rCEvt )
 {
-    sal_Bool bDone = false;
+    bool bDone = false;
     const CommandWheelData* pData = rCEvt.GetWheelData();
     if ( pData && pData->GetMode() == COMMAND_WHEEL_ZOOM )
     {
@@ -508,7 +512,7 @@ sal_Bool ScPreviewShell::ScrollCommand( const CommandEvent& rCEvt )
             pPreview->SetZoom( (sal_uInt16)nNew );
         }
 
-        bDone = sal_True;
+        bDone = true;
     }
     else
     {
@@ -518,7 +522,7 @@ sal_Bool ScPreviewShell::ScrollCommand( const CommandEvent& rCEvt )
     return bDone;
 }
 
-SfxPrinter* ScPreviewShell::GetPrinter( sal_Bool bCreate )
+SfxPrinter* ScPreviewShell::GetPrinter( bool bCreate )
 {
     return pDocShell->GetPrinter(bCreate);
 }
@@ -543,7 +547,7 @@ SfxTabPage* ScPreviewShell::CreatePrintOptionsPage( Window *pParent, const SfxIt
     return 0;
 }
 
-void ScPreviewShell::Activate(sal_Bool bMDI)
+void ScPreviewShell::Activate(bool bMDI)
 {
     SfxViewShell::Activate(bMDI);
 
@@ -558,7 +562,7 @@ void ScPreviewShell::Activate(sal_Bool bMDI)
     }
 }
 
-void ScPreviewShell::Deactivate(sal_Bool bMDI)
+void ScPreviewShell::Deactivate(bool bMDI)
 {
     SfxViewShell::Deactivate(bMDI);
 
@@ -567,8 +571,6 @@ void ScPreviewShell::Deactivate(sal_Bool bMDI)
     }
 }
 
-//------------------------------------------------------------------------
-
 void ScPreviewShell::Execute( SfxRequest& rReq )
 {
     sal_uInt16 nSlot = rReq.GetSlot();
@@ -597,7 +599,7 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
         case SID_NEXT_TABLE: // Accelerator
         case SID_PREVIEW_NEXT:
             {
-                sal_Bool bAllTested = pPreview->AllTested();
+                bool bAllTested = pPreview->AllTested();
                 long nPage = pPreview->GetPageNo();
                 long nTotal = pPreview->GetTotalPages();
                 if (nTotal && (nPage+1 < nTotal || !bAllTested))
@@ -629,7 +631,7 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
         case FID_SCALE:
             {
                 sal_uInt16      nZoom       = 100;
-                sal_Bool        bCancel     = false;
+                bool        bCancel     = false;
 
                 eZoom = SVX_ZOOM_PERCENT;
 
@@ -651,7 +653,7 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
                     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
                     if(pFact)
                     {
-                        AbstractSvxZoomDialog* pDlg = pFact->CreateSvxZoomDialog(NULL, aSet);
+                        boost::scoped_ptr<AbstractSvxZoomDialog> pDlg(pFact->CreateSvxZoomDialog(NULL, aSet));
                         OSL_ENSURE(pDlg, "Dialogdiet fail!");
                         pDlg->SetLimits( 20, 400 );
                         pDlg->HideButton( ZOOMBTN_OPTIMAL );
@@ -666,8 +668,6 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
                             eZoom = rZoomItem.GetType();
                             nZoom = rZoomItem.GetValue();
                         }
-
-                        delete pDlg;
                     }
                 }
 
@@ -680,7 +680,7 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
                             nZoom = pPreview->GetOptimalZoom(false);
                             break;
                         case SVX_ZOOM_PAGEWIDTH:
-                            nZoom = pPreview->GetOptimalZoom(sal_True);
+                            nZoom = pPreview->GetOptimalZoom(true);
                             break;
                         default:
                         {
@@ -713,7 +713,7 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
             break;
         case SID_PREVIEW_MARGIN:
             {
-                sal_Bool bMargin = pPreview->GetPageMargins();
+                bool bMargin = pPreview->GetPageMargins();
                 pPreview->SetPageMargins( !bMargin );
                 pPreview->Invalidate();
                 rReq.Done();
@@ -723,7 +723,7 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
             {
                 const SfxPoolItem* pItem;
                 eZoom = SVX_ZOOM_PERCENT;
-                if( pReqArgs && SFX_ITEM_SET == pReqArgs->GetItemState( SID_ATTR_ZOOMSLIDER, sal_True, &pItem ) )
+                if( pReqArgs && SFX_ITEM_SET == pReqArgs->GetItemState( SID_ATTR_ZOOMSLIDER, true, &pItem ) )
                 {
                     const sal_uInt16 nCurrentZoom = ((const SvxZoomSliderItem*)pItem)->GetValue();
                     if( nCurrentZoom )
@@ -743,7 +743,7 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
                 SfxStyleSheetBase* pStyleSheet  = pStylePool->Find( aOldName, SFX_STYLE_FAMILY_PAGE );
                 OSL_ENSURE( pStyleSheet, "PageStyle not found! :-/" );
 
-                if ( pReqArgs && pStyleSheet && SFX_ITEM_SET == pReqArgs->GetItemState( SID_PREVIEW_SCALINGFACTOR, sal_True, &pItem ) )
+                if ( pReqArgs && pStyleSheet && SFX_ITEM_SET == pReqArgs->GetItemState( SID_PREVIEW_SCALINGFACTOR, true, &pItem ) )
                 {
                     const sal_uInt16 nCurrentZoom   = ((const SvxZoomSliderItem *)pItem)->GetValue();
                     SfxItemSet& rSet            = pStyleSheet->GetItemSet();
@@ -785,13 +785,13 @@ void ScPreviewShell::Execute( SfxRequest& rReq )
 
 void ScPreviewShell::GetState( SfxItemSet& rSet )
 {
-    pPreview->SetInGetState(sal_True);
+    pPreview->SetInGetState(true);
 
     SCTAB nTab      = pPreview->GetTab();
     long nPage      = pPreview->GetPageNo();
     long nTotal     = pPreview->GetTotalPages();
     sal_uInt16 nZoom    = pPreview->GetZoom();
-    sal_Bool bAllTested = pPreview->AllTested();
+    bool bAllTested = pPreview->AllTested();
 
     SfxWhichIter aIter(rSet);
     sal_uInt16 nWhich = aIter.FirstWhich();
@@ -877,7 +877,7 @@ void ScPreviewShell::GetState( SfxItemSet& rSet )
                 rSet.Put( SfxStringItem( nWhich, pPreview->GetPosString() ) );
                 break;
             case SID_PRINTPREVIEW:
-                rSet.Put( SfxBoolItem( nWhich, sal_True ) );
+                rSet.Put( SfxBoolItem( nWhich, true ) );
                 break;
             case SID_FORMATPAGE:
             case SID_PREVIEW_MARGIN:
@@ -913,7 +913,7 @@ void ScPreviewShell::FillFieldData( ScHeaderFieldData& rData )
         rData.aShortDocName = rData.aLongDocName = rData.aTitle;
     rData.nPageNo       = pPreview->GetPageNo() + 1;
 
-    sal_Bool bAllTested = pPreview->AllTested();
+    bool bAllTested = pPreview->AllTested();
     if (bAllTested)
         rData.nTotalPages = pPreview->GetTotalPages();
     else
@@ -943,7 +943,7 @@ void ScPreviewShell::ReadUserData(const OUString& rData, bool /* bBrowse */)
     }
 }
 
-void ScPreviewShell::WriteUserDataSequence(uno::Sequence < beans::PropertyValue >& rSeq, sal_Bool /* bBrowse */)
+void ScPreviewShell::WriteUserDataSequence(uno::Sequence < beans::PropertyValue >& rSeq, bool /* bBrowse */)
 {
     rSeq.realloc(3);
     beans::PropertyValue* pSeq = rSeq.getArray();
@@ -951,7 +951,7 @@ void ScPreviewShell::WriteUserDataSequence(uno::Sequence < beans::PropertyValue
     {
         sal_uInt16 nViewID(GetViewFrame()->GetCurViewId());
         pSeq[0].Name = OUString(SC_VIEWID);
-        OUStringBuffer sBuffer(OUString(SC_VIEW));
+        OUStringBuffer sBuffer(SC_VIEW);
         ::sax::Converter::convertNumber(sBuffer,
                 static_cast<sal_Int32>(nViewID));
         pSeq[0].Value <<= sBuffer.makeStringAndClear();
@@ -962,7 +962,7 @@ void ScPreviewShell::WriteUserDataSequence(uno::Sequence < beans::PropertyValue
     }
 }
 
-void ScPreviewShell::ReadUserDataSequence(const uno::Sequence < beans::PropertyValue >& rSeq, sal_Bool /* bBrowse */)
+void ScPreviewShell::ReadUserDataSequence(const uno::Sequence < beans::PropertyValue >& rSeq, bool /* bBrowse */)
 {
     sal_Int32 nCount(rSeq.getLength());
     if (nCount)
@@ -1071,7 +1071,7 @@ void ScPreviewShell::DoScroll( sal_uInt16 nMode )
                 aCurPos.Y() -= nVPage;
             break;
         case SID_CURSORPAGEDOWN:
-            if( (abs(nVPage+nThumbPos-nRangeMax)<10) || nMaxVertPos<0 )
+            if( (std::abs(nVPage+nThumbPos-nRangeMax)<10) || nMaxVertPos<0 )
             {
                 long nPage = pPreview->GetPageNo();
                 long nTotal = pPreview->GetTotalPages();
@@ -1190,7 +1190,7 @@ void ScPreviewShell::BroadcastAccessibility( const SfxHint &rHint )
         pAccessibilityBroadcaster->Broadcast( rHint );
 }
 
-sal_Bool ScPreviewShell::HasAccessibilityObjects()
+bool ScPreviewShell::HasAccessibilityObjects()
 {
     return pAccessibilityBroadcaster && pAccessibilityBroadcaster->HasListeners();
 }
