@@ -66,11 +66,7 @@
 #include <comphelper/string.hxx>
 #include "scabstdlg.hxx"
 
-#include <memory>
-
-using ::std::auto_ptr;
-
-//------------------------------------------------------------------
+#include <boost/scoped_ptr.hpp>
 
 /** Try to parse the given range using Calc-style syntax first, then
     Excel-style if that fails. */
@@ -111,22 +107,22 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
             {
                 const SfxPoolItem* pItem;
                 if ( pReqArgs &&
-                     pReqArgs->GetItemState(FID_INSERT_FILE,sal_True,&pItem) == SFX_ITEM_SET )
+                     pReqArgs->GetItemState(FID_INSERT_FILE,true,&pItem) == SFX_ITEM_SET )
                 {
                     OUString aFileName = ((const SfxStringItem*)pItem)->GetValue();
 
                         // Einfuege-Position
 
                     Point aInsertPos;
-                    if ( pReqArgs->GetItemState(FN_PARAM_1,sal_True,&pItem) == SFX_ITEM_SET )
+                    if ( pReqArgs->GetItemState(FN_PARAM_1,true,&pItem) == SFX_ITEM_SET )
                         aInsertPos = ((const SfxPointItem*)pItem)->GetValue();
                     else
                         aInsertPos = GetInsertPos();
 
                         //  als Link?
 
-                    sal_Bool bAsLink = false;
-                    if ( pReqArgs->GetItemState(FN_PARAM_2,sal_True,&pItem) == SFX_ITEM_SET )
+                    bool bAsLink = false;
+                    if ( pReqArgs->GetItemState(FN_PARAM_2,true,&pItem) == SFX_ITEM_SET )
                         bAsLink = ((const SfxBoolItem*)pItem)->GetValue();
 
                         // ausfuehren
@@ -152,15 +148,15 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                     OUString aPrintStr;
                     OUString aRowStr;
                     OUString aColStr;
-                    sal_Bool bEntire = false;
+                    bool bEntire = false;
                     const SfxPoolItem* pItem;
-                    if ( pReqArgs->GetItemState( SID_CHANGE_PRINTAREA, sal_True, &pItem ) == SFX_ITEM_SET )
+                    if ( pReqArgs->GetItemState( SID_CHANGE_PRINTAREA, true, &pItem ) == SFX_ITEM_SET )
                         aPrintStr = static_cast<const SfxStringItem*>(pItem)->GetValue();
-                    if ( pReqArgs->GetItemState( FN_PARAM_2, sal_True, &pItem ) == SFX_ITEM_SET )
+                    if ( pReqArgs->GetItemState( FN_PARAM_2, true, &pItem ) == SFX_ITEM_SET )
                         aRowStr = static_cast<const SfxStringItem*>(pItem)->GetValue();
-                    if ( pReqArgs->GetItemState( FN_PARAM_3, sal_True, &pItem ) == SFX_ITEM_SET )
+                    if ( pReqArgs->GetItemState( FN_PARAM_3, true, &pItem ) == SFX_ITEM_SET )
                         aColStr = static_cast<const SfxStringItem*>(pItem)->GetValue();
-                    if ( pReqArgs->GetItemState( FN_PARAM_4, sal_True, &pItem ) == SFX_ITEM_SET )
+                    if ( pReqArgs->GetItemState( FN_PARAM_4, true, &pItem ) == SFX_ITEM_SET )
                         bEntire = static_cast<const SfxBoolItem*>(pItem)->GetValue();
 
                     SetPrintRanges( bEntire, &aPrintStr, &aColStr, &aRowStr, false );
@@ -173,12 +169,12 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
         case SID_ADD_PRINTAREA:
         case SID_DEFINE_PRINTAREA:      // Menue oder Basic
             {
-                sal_Bool bAdd = ( nSlot == SID_ADD_PRINTAREA );
+                bool bAdd = ( nSlot == SID_ADD_PRINTAREA );
                 if ( pReqArgs )
                 {
                     OUString aPrintStr;
                     const SfxPoolItem* pItem;
-                    if ( pReqArgs->GetItemState( SID_DEFINE_PRINTAREA, sal_True, &pItem ) == SFX_ITEM_SET )
+                    if ( pReqArgs->GetItemState( SID_DEFINE_PRINTAREA, true, &pItem ) == SFX_ITEM_SET )
                         aPrintStr = static_cast<const SfxStringItem*>(pItem)->GetValue();
                     SetPrintRanges( false, &aPrintStr, NULL, NULL, bAdd );
                 }
@@ -192,8 +188,10 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
 
         case SID_DELETE_PRINTAREA:
             {
+                // Clear currently defined print range if any, and reset it to
+                // print entire sheet which is the default.
                 OUString aEmpty;
-                SetPrintRanges( false, &aEmpty, NULL, NULL, false );        // Druckbereich loeschen
+                SetPrintRanges(true, &aEmpty, NULL, NULL, false);
                 rReq.Done();
             }
             break;
@@ -226,18 +224,18 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
             {
                 OUString aAddress;
                 const SfxPoolItem* pItem;
-                if ( pReqArgs->GetItemState( nSlot, sal_True, &pItem ) == SFX_ITEM_SET )
+                if ( pReqArgs->GetItemState( nSlot, true, &pItem ) == SFX_ITEM_SET )
                     aAddress = ((const SfxStringItem*)pItem)->GetValue();
                 else if ( nSlot == SID_JUMPTOMARK && pReqArgs->GetItemState(
-                                            SID_JUMPTOMARK, sal_True, &pItem ) == SFX_ITEM_SET )
+                                            SID_JUMPTOMARK, true, &pItem ) == SFX_ITEM_SET )
                     aAddress = ((const SfxStringItem*)pItem)->GetValue();
 
                 //  #i14927# SID_CURRENTCELL with a single cell must unmark if FN_PARAM_1
                 //  isn't set (for recorded macros, because IsAPI is no longer available).
                 //  ScGridWindow::MouseButtonUp no longer executes the slot for a single
                 //  cell if there is a multi selection.
-                sal_Bool bUnmark = ( nSlot == SID_CURRENTCELL );
-                if ( pReqArgs->GetItemState( FN_PARAM_1, sal_True, &pItem ) == SFX_ITEM_SET )
+                bool bUnmark = ( nSlot == SID_CURRENTCELL );
+                if ( pReqArgs->GetItemState( FN_PARAM_1, true, &pItem ) == SFX_ITEM_SET )
                     bUnmark = ((const SfxBoolItem*)pItem)->GetValue();
 
                 bool bAlignToCursor = true;
@@ -247,12 +245,12 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 if ( nSlot == SID_JUMPTOMARK )
                 {
                     //  URL has to be decoded for escaped characters (%20)
-                    aAddress = INetURLObject::decode( aAddress, INET_HEX_ESCAPE,
+                    aAddress = INetURLObject::decode( aAddress, '%',
                                                INetURLObject::DECODE_WITH_CHARSET,
                                             RTL_TEXTENCODING_UTF8 );
                 }
 
-                sal_Bool bFound = false;
+                bool bFound = false;
                 ScViewData* pViewData = GetViewData();
                 ScDocument* pDoc      = pViewData->GetDocument();
                 ScMarkData& rMark     = pViewData->GetMarkData();
@@ -260,7 +258,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 ScAddress   aScAddress;
                 sal_uInt16      nResult = lcl_ParseRange(aScRange, aAddress, pDoc, nSlot);
                 SCTAB       nTab = pViewData->GetTabNo();
-                sal_Bool        bMark = sal_True;
+                bool        bMark = true;
 
                 // Is this a range ?
                 if( nResult & SCA_VALID )
@@ -327,10 +325,10 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 // wir haben was gefunden
                 if( nResult & SCA_VALID )
                 {
-                    bFound = sal_True;
+                    bFound = true;
                     SCCOL nCol = aScRange.aStart.Col();
                     SCROW nRow = aScRange.aStart.Row();
-                    sal_Bool bNothing = ( pViewData->GetCurX()==nCol && pViewData->GetCurY()==nRow );
+                    bool bNothing = ( pViewData->GetCurX()==nCol && pViewData->GetCurY()==nRow );
 
                     // markieren
                     if( bMark )
@@ -402,7 +400,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                     SCTAB nNameTab;
                     if ( pDoc->GetTable( aAddress, nNameTab ) )
                     {
-                        bFound = sal_True;
+                        bFound = true;
                         if ( nNameTab != nTab )
                             SetTabNo( nNameTab );
                     }
@@ -454,7 +452,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
 
                 SfxViewFrame*   pViewFrame = NULL;
                 ScDocShell*     pDocSh = (ScDocShell*)SfxObjectShell::GetFirst();
-                sal_Bool            bFound = false;
+                bool            bFound = false;
 
                 // zu aktivierenden ViewFrame suchen
 
@@ -523,9 +521,9 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
 
                 // check whether there is an explicit argument, use it
                 const SfxPoolItem* pItem;
-                if ( pReqArgs && pReqArgs->GetItemState(nSlot, sal_True, &pItem) == SFX_ITEM_SET )
+                if ( pReqArgs && pReqArgs->GetItemState(nSlot, true, &pItem) == SFX_ITEM_SET )
                 {
-                    sal_Bool bItemValue = ((const SfxBoolItem*)pItem)->GetValue();
+                    bool bItemValue = ((const SfxBoolItem*)pItem)->GetValue();
                     bWantPageBreak = (nSlot == FID_PAGEBREAKMODE) == bItemValue;
                 }
 
@@ -533,12 +531,12 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 {
                     SetPagebreakMode( bWantPageBreak );
                     UpdatePageBreakData();
-                    SetCurSubShell( GetCurObjectSelectionType(), sal_True );
+                    SetCurSubShell( GetCurObjectSelectionType(), true );
                     PaintGrid();
                     PaintTop();
                     PaintLeft();
                     rBindings.Invalidate( nSlot );
-                    rReq.AppendItem( SfxBoolItem( nSlot, sal_True ) );
+                    rReq.AppendItem( SfxBoolItem( nSlot, true ) );
                     rReq.Done();
                 }
             }
@@ -563,9 +561,9 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
 
         case FID_TOGGLESYNTAX:
             {
-                sal_Bool bSet = !GetViewData()->IsSyntaxMode();
+                bool bSet = !GetViewData()->IsSyntaxMode();
                 const SfxPoolItem* pItem;
-                if ( pReqArgs && pReqArgs->GetItemState(nSlot, sal_True, &pItem) == SFX_ITEM_SET )
+                if ( pReqArgs && pReqArgs->GetItemState(nSlot, true, &pItem) == SFX_ITEM_SET )
                     bSet = ((const SfxBoolItem*)pItem)->GetValue();
                 GetViewData()->SetSyntaxMode( bSet );
                 PaintGrid();
@@ -576,9 +574,9 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
             break;
         case FID_TOGGLEHEADERS:
             {
-                sal_Bool bSet = !GetViewData()->IsHeaderMode();
+                bool bSet = !GetViewData()->IsHeaderMode();
                 const SfxPoolItem* pItem;
-                if ( pReqArgs && pReqArgs->GetItemState(nSlot, sal_True, &pItem) == SFX_ITEM_SET )
+                if ( pReqArgs && pReqArgs->GetItemState(nSlot, true, &pItem) == SFX_ITEM_SET )
                     bSet = ((const SfxBoolItem*)pItem)->GetValue();
                 GetViewData()->SetHeaderMode( bSet );
                 RepeatResize();
@@ -592,9 +590,9 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
             {
                 ScViewData* pViewData = GetViewData();
                 const ScViewOptions& rOpts = pViewData->GetOptions();
-                sal_Bool bFormulaMode = !rOpts.GetOption( VOPT_FORMULAS );
+                bool bFormulaMode = !rOpts.GetOption( VOPT_FORMULAS );
                 const SfxPoolItem *pItem;
-                if( pReqArgs && pReqArgs->GetItemState(nSlot, sal_True, &pItem) == SFX_ITEM_SET )
+                if( pReqArgs && pReqArgs->GetItemState(nSlot, true, &pItem) == SFX_ITEM_SET )
                     bFormulaMode = ((const SfxBoolItem *)pItem)->GetValue();
 
                 ScViewOptions rSetOpts = ScViewOptions( rOpts );
@@ -613,9 +611,9 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
             {
                 sal_uInt16          nId  = ScInputWindowWrapper::GetChildWindowId();
                 SfxChildWindow* pWnd = pThisFrame->GetChildWindow( nId );
-                sal_Bool bSet = ( pWnd == NULL );
+                bool bSet = ( pWnd == NULL );
                 const SfxPoolItem* pItem;
-                if ( pReqArgs && pReqArgs->GetItemState(nSlot, sal_True, &pItem) == SFX_ITEM_SET )
+                if ( pReqArgs && pReqArgs->GetItemState(nSlot, true, &pItem) == SFX_ITEM_SET )
                     bSet = ((const SfxBoolItem*)pItem)->GetValue();
 
                 pThisFrame->SetChildWindow( nId, bSet );
@@ -628,14 +626,14 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
         case SID_ATTR_ZOOM: // Statuszeile
         case FID_SCALE:
             {
-                sal_Bool bSyncZoom = SC_MOD()->GetAppOptions().GetSynchronizeZoom();
+                bool bSyncZoom = SC_MOD()->GetAppOptions().GetSynchronizeZoom();
                 SvxZoomType eOldZoomType = GetZoomType();
                 SvxZoomType eNewZoomType = eOldZoomType;
                 const Fraction& rOldY = GetViewData()->GetZoomY();  // Y wird angezeigt
                 sal_uInt16 nOldZoom = (sal_uInt16)(( rOldY.GetNumerator() * 100 )
                                             / rOldY.GetDenominator());
                 sal_uInt16 nZoom = nOldZoom;
-                sal_Bool bCancel = false;
+                bool bCancel = false;
 
                 if ( pReqArgs )
                 {
@@ -649,7 +647,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 {
                     SfxItemSet      aSet     ( GetPool(), SID_ATTR_ZOOM, SID_ATTR_ZOOM );
                     SvxZoomItem     aZoomItem( eOldZoomType, nOldZoom, SID_ATTR_ZOOM );
-                    AbstractSvxZoomDialog* pDlg = NULL;
+                    boost::scoped_ptr<AbstractSvxZoomDialog> pDlg;
                     ScMarkData&     rMark = GetViewData()->GetMarkData();
                     sal_uInt16          nBtnFlags =   SVX_ZOOM_ENABLE_50
                                                 | SVX_ZOOM_ENABLE_75
@@ -667,28 +665,27 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
                     if(pFact)
                     {
-                        pDlg = pFact->CreateSvxZoomDialog(GetDialogParent(), aSet );
+                        pDlg.reset(pFact->CreateSvxZoomDialog(GetDialogParent(), aSet ));
                         OSL_ENSURE(pDlg, "Dialogdiet fail!");
                     }
                     if (pDlg)
                     {
-                       pDlg->SetLimits( MINZOOM, MAXZOOM );
+                        pDlg->SetLimits( MINZOOM, MAXZOOM );
 
-                       bCancel = ( RET_CANCEL == pDlg->Execute() );
+                        bCancel = ( RET_CANCEL == pDlg->Execute() );
+
+                        // bCancel is True only if we were in the previous if block,
+                        // so no need to check again pDlg
+                        if ( !bCancel )
+                        {
+                            const SvxZoomItem&  rZoomItem = (const SvxZoomItem&)
+                                                    pDlg->GetOutputItemSet()->
+                                                        Get( SID_ATTR_ZOOM );
+
+                            eNewZoomType = rZoomItem.GetType();
+                            nZoom     = rZoomItem.GetValue();
+                        }
                     }
-                    // bCancel is True only if we were in the previous if block,
-                    // so no need to check again pDlg
-                    if ( !bCancel )
-                    {
-                        const SvxZoomItem&  rZoomItem = (const SvxZoomItem&)
-                                                pDlg->GetOutputItemSet()->
-                                                    Get( SID_ATTR_ZOOM );
-
-                        eNewZoomType = rZoomItem.GetType();
-                        nZoom     = rZoomItem.GetValue();
-                    }
-
-                    delete pDlg;
                 }
 
                 if ( !bCancel )
@@ -740,8 +737,8 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
         case SID_ATTR_ZOOMSLIDER:
             {
                 const SfxPoolItem* pItem = NULL;
-                sal_Bool bSyncZoom = SC_MOD()->GetAppOptions().GetSynchronizeZoom();
-                if ( pReqArgs && pReqArgs->GetItemState(SID_ATTR_ZOOMSLIDER, sal_True, &pItem) == SFX_ITEM_SET )
+                bool bSyncZoom = SC_MOD()->GetAppOptions().GetSynchronizeZoom();
+                if ( pReqArgs && pReqArgs->GetItemState(SID_ATTR_ZOOMSLIDER, true, &pItem) == SFX_ITEM_SET )
                 {
                     const sal_uInt16 nCurrentZoom = ((const SvxZoomSliderItem *)pItem)->GetValue();
                     if( nCurrentZoom )
@@ -766,8 +763,6 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
             }
             break;
 
-        //----------------------------------------------------------------
-
         case FID_TAB_SELECTALL:
             SelectAllTables();
             rReq.Done();
@@ -795,7 +790,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                 OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                AbstractScShowTabDlg* pDlg = pFact->CreateScShowTabDlg( GetDialogParent(), RID_SCDLG_SHOW_TAB);
+                boost::scoped_ptr<AbstractScShowTabDlg> pDlg(pFact->CreateScShowTabDlg(GetDialogParent()));
                 OSL_ENSURE(pDlg, "Dialog create fail!");
                 pDlg->SetDescription(
                     OUString( ScResId( STR_DLG_SELECTTABLES_TITLE ) ),
@@ -816,7 +811,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                     sal_uInt16 nSelIx;
                     for( nSelIx = 0; nSelIx < nSelCount; ++nSelIx )
                         aIndexList.insert( aIndexList.begin()+nSelIx, pDlg->GetSelectEntryPos( nSelIx ) );
-                    delete pDlg;
+                    pDlg.reset();
                     rReq.AppendItem( SfxIntegerListItem( SID_SELECT_TABLES, aIndexList ) );
                 }
                 else
@@ -830,7 +825,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 SCTAB nFirstVisTab = 0;
 
                 // special case: only hidden tables selected -> do nothing
-                sal_Bool bVisSelected = false;
+                bool bVisSelected = false;
                 for( nSelIx = 0; !bVisSelected && (nSelIx < nSelCount); ++nSelIx )
                     bVisSelected = rDoc.IsVisible( nFirstVisTab = static_cast<SCTAB>(aIndexList[nSelIx]) );
                 if( !bVisSelected )
@@ -843,12 +838,12 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                         rMark.SelectTable( nTab, false );
 
                     for( nSelIx = 0; nSelIx < nSelCount; ++nSelIx )
-                        rMark.SelectTable( static_cast<SCTAB>(aIndexList[nSelIx]), sal_True );
+                        rMark.SelectTable( static_cast<SCTAB>(aIndexList[nSelIx]), true );
 
                     // activate another table, if current is deselected
                     if( !rMark.GetTableSelect( rViewData.GetTabNo() ) )
                     {
-                        rMark.SelectTable( nFirstVisTab, sal_True );
+                        rMark.SelectTable( nFirstVisTab, true );
                         SetTabNo( nFirstVisTab );
                     }
 
@@ -898,15 +893,13 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 if ( eHSplit == SC_SPLIT_FIX || eVSplit == SC_SPLIT_FIX )           // aufheben
                     RemoveSplit();
                 else
-                    FreezeSplitters( sal_True );        // erzeugen oder fixieren
+                    FreezeSplitters( true );        // erzeugen oder fixieren
                 rReq.Done();
 
                 InvalidateSplit();
             }
             break;
 
-        //  ----------------------------------------------------------------
-
         case FID_CHG_SHOW:
             {
                 sal_uInt16          nId  = ScHighlightChgDlgWrapper::GetChildWindowId();
@@ -942,7 +935,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 {
                     const SfxPoolItem* pItem;
                     if ( pReqArgs &&
-                         pReqArgs->GetItemState( nSlot, sal_True, &pItem ) == SFX_ITEM_SET &&
+                         pReqArgs->GetItemState( nSlot, true, &pItem ) == SFX_ITEM_SET &&
                          pItem->ISA( SfxStringItem ) )
                     {
                         OUString aComment = ((const SfxStringItem*)pItem)->GetValue();
@@ -971,13 +964,12 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
         case FID_PROTECT_DOC:
             {
                 ScDocument*         pDoc = GetViewData()->GetDocument();
-                SfxPasswordDialog*  pDlg;
 
                 if( pReqArgs )
                 {
                     const SfxPoolItem* pItem;
                     if( pReqArgs->HasItem( FID_PROTECT_DOC, &pItem ) &&
-                        ((const SfxBoolItem*)pItem)->GetValue() == static_cast<sal_Bool>(pDoc->IsDocProtected()) )
+                        ((const SfxBoolItem*)pItem)->GetValue() == pDoc->IsDocProtected() )
                     {
                         rReq.Ignore();
                         break;
@@ -987,14 +979,14 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 ScDocProtection* pProtect = pDoc->GetDocProtection();
                 if (pProtect && pProtect->isProtected())
                 {
-                    sal_Bool bCancel = false;
+                    bool bCancel = false;
                     OUString aPassword;
 
                     if (pProtect->isProtectedWithPass())
                     {
                         OUString aText(ScResId(SCSTR_PASSWORD));
 
-                        pDlg = new SfxPasswordDialog(GetDialogParent(), &aText);
+                        boost::scoped_ptr<SfxPasswordDialog> pDlg(new SfxPasswordDialog(GetDialogParent(), &aText));
                         pDlg->SetText( ScResId(SCSTR_UNPROTECTDOC) );
                         pDlg->SetMinLen( 0 );
                         pDlg->SetHelpId( GetStaticInterface()->GetSlot(FID_PROTECT_DOC)->GetCommand() );
@@ -1003,8 +995,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                         if (pDlg->Execute() == RET_OK)
                             aPassword = pDlg->GetPassword();
                         else
-                            bCancel = sal_True;
-                        delete pDlg;
+                            bCancel = true;
                     }
                     if (!bCancel)
                     {
@@ -1017,7 +1008,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 {
                     OUString aText(ScResId(SCSTR_PASSWORDOPT));
 
-                    pDlg = new SfxPasswordDialog(   GetDialogParent(), &aText );
+                    boost::scoped_ptr<SfxPasswordDialog> pDlg(new SfxPasswordDialog(GetDialogParent(), &aText));
                     pDlg->SetText( ScResId(SCSTR_PROTECTDOC) );
                     pDlg->SetMinLen( 0 );
                     pDlg->SetHelpId( GetStaticInterface()->GetSlot(FID_PROTECT_DOC)->GetCommand() );
@@ -1028,11 +1019,9 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                     {
                         OUString aPassword = pDlg->GetPassword();
                         Protect( TABLEID_DOC, aPassword );
-                        rReq.AppendItem( SfxBoolItem( FID_PROTECT_DOC, sal_True ) );
+                        rReq.AppendItem( SfxBoolItem( FID_PROTECT_DOC, true ) );
                         rReq.Done();
                     }
-
-                    delete pDlg;
                 }
                 rBindings.Invalidate( FID_PROTECT_DOC );
             }
@@ -1066,7 +1055,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
                 if (pProtect && pProtect->isProtectedWithPass())
                 {
                     OUString aText( ScResId(SCSTR_PASSWORDOPT) );
-                    auto_ptr<SfxPasswordDialog> pDlg(new SfxPasswordDialog(GetDialogParent(), &aText));
+                    boost::scoped_ptr<SfxPasswordDialog> pDlg(new SfxPasswordDialog(GetDialogParent(), &aText));
                     pDlg->SetText( ScResId(SCSTR_UNPROTECTTAB) );
                     pDlg->SetMinLen( 0 );
                     pDlg->SetHelpId( GetStaticInterface()->GetSlot(FID_PROTECT_TABLE)->GetCommand() );
@@ -1092,7 +1081,7 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
             {
                 // Protect a current sheet.
 
-                auto_ptr<ScTableProtectionDlg> pDlg(new ScTableProtectionDlg(GetDialogParent()));
+                boost::scoped_ptr<ScTableProtectionDlg> pDlg(new ScTableProtectionDlg(GetDialogParent()));
 
                 ScTableProtection* pProtect = pDoc->GetTabProtection(nTab);
                 if (pProtect)
@@ -1131,6 +1120,4 @@ void ScTabViewShell::Execute( SfxRequest& rReq )
     }
 }
 
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
