@@ -94,6 +94,7 @@
 #include "../ui/inc/FrameView.hxx"
 
 #include <tools/tenccvt.hxx>
+#include <vcl/settings.hxx>
 
 using namespace ::sd;
 using namespace ::com::sun::star;
@@ -147,6 +148,7 @@ PresentationSettings::PresentationSettings( const PresentationSettings& r )
 
 SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 : FmFormModel( SvtPathOptions().GetPalettePath(), NULL, pDrDocSh )
+, bReadOnly(false)
 , mpOutliner(NULL)
 , mpInternalOutliner(NULL)
 , mpWorkStartupTimer(NULL)
@@ -182,7 +184,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 
     if (mpDocSh)
     {
-        SetSwapGraphics(sal_True);
+        SetSwapGraphics(true);
     }
 
     // Set measuring unit (of the application) and scale (of SdMod)
@@ -246,7 +248,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
     // for korean and japanese languages we have a different default for apply spacing between asian, latin and ctl text
     if (MsLangId::isKorean(eRealCTLLanguage) || (LANGUAGE_JAPANESE == eRealCTLLanguage))
     {
-        GetPool().GetSecondaryPool()->SetPoolDefaultItem( SvxScriptSpaceItem( sal_False, EE_PARA_ASIANCJKSPACING ) );
+        GetPool().GetSecondaryPool()->SetPoolDefaultItem( SvxScriptSpaceItem( false, EE_PARA_ASIANCJKSPACING ) );
     }
 
     // Set DefTab and SpellOptions for the SD module
@@ -288,7 +290,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 
     nCntrl &= ~ EE_CNTRL_ULSPACESUMMATION;
     if ( meDocType != DOCUMENT_TYPE_IMPRESS )
-        SetSummationOfParagraphs( sal_False );
+        SetSummationOfParagraphs( false );
     else
     {
         SetSummationOfParagraphs( pOptions->IsSummationOfParagraphs() );
@@ -388,7 +390,7 @@ SdDrawDocument::~SdDrawDocument()
     CloseBookmarkDoc();
     SetAllocDocSh(false);
 
-    ClearModel(sal_True);
+    ClearModel(true);
 
     if (pLinkManager)
     {
@@ -448,10 +450,10 @@ SdrModel* SdDrawDocument::AllocModel() const
 
         if( meDocType == DOCUMENT_TYPE_IMPRESS )
             mpCreatingTransferable->SetDocShell( new ::sd::DrawDocShell(
-                SFX_CREATE_MODE_EMBEDDED, sal_True, meDocType ) );
+                SFX_CREATE_MODE_EMBEDDED, true, meDocType ) );
         else
             mpCreatingTransferable->SetDocShell( new ::sd::GraphicDocShell(
-                SFX_CREATE_MODE_EMBEDDED, sal_True, meDocType ) );
+                SFX_CREATE_MODE_EMBEDDED, true, meDocType ) );
 
         pNewDocSh = static_cast< ::sd::DrawDocShell*>( pObj = mpCreatingTransferable->GetDocShell() );
         pNewDocSh->DoInitNew( NULL );
@@ -484,7 +486,7 @@ SdrModel* SdDrawDocument::AllocModel() const
         SdDrawDocument* pDoc = (SdDrawDocument*) this;
         pDoc->SetAllocDocSh(false);
         pDoc->mxAllocedDocShRef = new ::sd::DrawDocShell(
-            SFX_CREATE_MODE_EMBEDDED, sal_True, meDocType);
+            SFX_CREATE_MODE_EMBEDDED, true, meDocType);
         pDoc->mxAllocedDocShRef->DoInitNew(NULL);
         pNewModel = pDoc->mxAllocedDocShRef->GetDoc();
     }
@@ -501,11 +503,11 @@ SdrModel* SdDrawDocument::AllocModel() const
 // not know, as they are _derivatives_ of SdrPage) when loading.
 SdrPage* SdDrawDocument::AllocPage(bool bMasterPage)
 {
-    return new SdPage(*this, NULL, bMasterPage);
+    return new SdPage(*this, bMasterPage);
 }
 
 // When the model has changed
-void SdDrawDocument::SetChanged(sal_Bool bFlag)
+void SdDrawDocument::SetChanged(bool bFlag)
 {
     if (mpDocSh)
     {
@@ -526,7 +528,7 @@ void SdDrawDocument::SetChanged(sal_Bool bFlag)
 }
 
 // The model changed, don't call anything else
-void SdDrawDocument::NbcSetChanged(sal_Bool bFlag)
+void SdDrawDocument::NbcSetChanged(bool bFlag)
 {
     // forward to baseclass
     FmFormModel::SetChanged(bFlag);
@@ -553,7 +555,7 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
         CheckMasterPages();
 
         if ( GetMasterSdPageCount(PK_STANDARD) > 1 )
-            RemoveUnnecessaryMasterPages( NULL, sal_True, sal_False );
+            RemoveUnnecessaryMasterPages( NULL, true, false );
 
         for ( sal_uInt16 i = 0; i < GetPageCount(); i++ )
         {
@@ -638,7 +640,7 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
         for (nPage = 0; nPage < nPageCount; nPage++)
         {
             SdPage* pPage = GetMasterSdPage(nPage, PK_STANDARD);
-            pSPool->CreateLayoutStyleSheets( pPage->GetName(), sal_True );
+            pSPool->CreateLayoutStyleSheets( pPage->GetName(), true );
         }
 
         // Default and notes pages:
@@ -675,7 +677,7 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
 
     UpdateAllLinks();
 
-    SetChanged( sal_False );
+    SetChanged( false );
 }
 
 /** updates all links, only links in this document should by resolved */
@@ -692,7 +694,7 @@ void SdDrawDocument::UpdateAllLinks()
     }
 }
 
-/** this loops over the presentation objectes of a page and repairs some new settings
+/** this loops over the presentation objects of a page and repairs some new settings
     from old binary files and resets all default strings for empty presentation objects.
 */
 void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool )
@@ -728,7 +730,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 
                     // sal_True: don't delete "hard" attributes when doing this.
                     if (pTitleSheet)
-                        pObj->SetStyleSheet(pTitleSheet, sal_True);
+                        pObj->SetStyleSheet(pTitleSheet, true);
                 }
                 else if (nId == OBJ_OUTLINETEXT)
                 {
@@ -746,21 +748,21 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 
                             if( iter == aOutlineList.begin())
                                 // text frame listens to stylesheet of layer 1
-                                pObj->NbcSetStyleSheet(pSheet, sal_True);
+                                pObj->NbcSetStyleSheet(pSheet, true);
                         }
                     }
                 }
 
-                if (pObj->ISA(SdrTextObj) && pObj->IsEmptyPresObj() && pPage)
+                if (pObj->ISA(SdrTextObj) && pObj->IsEmptyPresObj())
                 {
                     PresObjKind ePresObjKind = pPage->GetPresObjKind(pObj);
                     OUString aString( pPage->GetPresObjText(ePresObjKind) );
 
                     if (!aString.isEmpty())
                     {
-                        sd::Outliner* pInternalOutl = GetInternalOutliner(sal_True);
+                        sd::Outliner* pInternalOutl = GetInternalOutliner(true);
                         pPage->SetObjText( (SdrTextObj*) pObj, pInternalOutl, ePresObjKind, aString );
-                        pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( ePresObjKind ), sal_True );
+                        pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( ePresObjKind ), true );
                         pInternalOutl->Clear();
                     }
                 }
@@ -771,7 +773,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 
 // Local outliner that is used for outline mode. In this outliner, OutlinerViews
 // may be inserted.
-::sd::Outliner* SdDrawDocument::GetOutliner(sal_Bool bCreateOutliner)
+::sd::Outliner* SdDrawDocument::GetOutliner(bool bCreateOutliner)
 {
     if (!mpOutliner && bCreateOutliner)
     {
@@ -789,7 +791,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 
 // Internal outliner that is used to create text objects. We don't insert any
 // OutlinerViews into this outliner!
-::sd::Outliner* SdDrawDocument::GetInternalOutliner(sal_Bool bCreateOutliner)
+::sd::Outliner* SdDrawDocument::GetInternalOutliner(bool bCreateOutliner)
 {
     if ( !mpInternalOutliner && bCreateOutliner )
     {
@@ -798,8 +800,8 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
         // This outliner is only used to create special text objects. As no
         // information about portions is saved in this outliner, the update mode
         // can/should always remain sal_False.
-        mpInternalOutliner->SetUpdateMode( sal_False );
-        mpInternalOutliner->EnableUndo( sal_False );
+        mpInternalOutliner->SetUpdateMode( false );
+        mpInternalOutliner->EnableUndo( false );
 
         if (mpDocSh)
             mpInternalOutliner->SetRefDevice( SD_MOD()->GetRefDevice( *mpDocSh ) );
@@ -808,8 +810,8 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
         mpInternalOutliner->SetStyleSheetPool((SfxStyleSheetPool*)GetStyleSheetPool());
     }
 
-    DBG_ASSERT( !mpInternalOutliner || ( mpInternalOutliner->GetUpdateMode() == sal_False ) , "InternalOutliner: UpdateMode = sal_True !" );
-    DBG_ASSERT( !mpInternalOutliner || ( mpInternalOutliner->IsUndoEnabled() == sal_False ), "InternalOutliner: Undo = sal_True !" );
+    DBG_ASSERT( !mpInternalOutliner || ( ! mpInternalOutliner->GetUpdateMode() ) , "InternalOutliner: UpdateMode = sal_True !" );
+    DBG_ASSERT( !mpInternalOutliner || ( ! mpInternalOutliner->IsUndoEnabled() ), "InternalOutliner: Undo = sal_True !" );
 
     // If you add stuff here, always clear it out.
     // Advantages:
@@ -821,7 +823,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 }
 
 // OnlineSpelling on/off
-void SdDrawDocument::SetOnlineSpell(sal_Bool bIn)
+void SdDrawDocument::SetOnlineSpell(bool bIn)
 {
     mbOnlineSpell = bIn;
     sal_uLong nCntrl = 0;
