@@ -30,8 +30,9 @@
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <rtl/ustring.h>
-#include<sfx2/viewfrm.hxx>
-
+#include <sfx2/viewfrm.hxx>
+#include <com/sun/star/accessibility/AccessibleStateType.hpp>
+#include <sfx2/objsh.hxx>
 #include <svx/AccessibleShape.hxx>
 
 #include <svx/svdobj.hxx>
@@ -40,11 +41,14 @@
 #include <toolkit/helper/vclunohelper.hxx>
 #include "Window.hxx"
 #include <vcl/svapp.hxx>
+#include "OutlineViewShell.hxx"
 
-
+#include <svx/svdlayer.hxx>
+#include <editeng/editobj.hxx>
+#include "LayerTabBar.hxx"
+#include <svtools/colorcfg.hxx>
 #include "ViewShell.hxx"
 #include "View.hxx"
-#include <memory>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::accessibility;
@@ -58,7 +62,10 @@ AccessibleDocumentViewBase::AccessibleDocumentViewBase (
     ::sd::ViewShell* pViewShell,
     const uno::Reference<frame::XController>& rxController,
     const uno::Reference<XAccessible>& rxParent)
-    : AccessibleContextBase (rxParent, AccessibleRole::DOCUMENT),
+    : AccessibleContextBase (rxParent,
+                             pViewShell->GetDoc()->GetDocumentType() == DOCUMENT_TYPE_IMPRESS ?
+                                     AccessibleRole::DOCUMENT_PRESENTATION :
+                                     AccessibleRole::DOCUMENT),
       mpWindow (pSdWindow),
       mxController (rxController),
       mxModel (NULL),
@@ -79,6 +86,7 @@ AccessibleDocumentViewBase::AccessibleDocumentViewBase (
     maShapeTreeInfo.SetViewForwarder (&maViewForwarder);
 
     mxWindow = ::VCLUnoHelper::GetInterface (pSdWindow);
+    mpViewShell = pViewShell;
 }
 
 
@@ -150,6 +158,9 @@ void AccessibleDocumentViewBase::Init (void)
             }
         }
     }
+    SfxObjectShell* pObjShell = mpViewShell->GetViewFrame()->GetObjectShell();
+    if(!pObjShell->IsReadOnly())
+        SetState(AccessibleStateType::EDITABLE);
 }
 
 
@@ -231,7 +242,7 @@ void AccessibleDocumentViewBase::ViewForwarderChanged(ChangeType, const IAccessi
 
 Reference<XAccessible> SAL_CALL
        AccessibleDocumentViewBase::getAccessibleParent (void)
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -242,7 +253,7 @@ Reference<XAccessible> SAL_CALL
 
 sal_Int32 SAL_CALL
     AccessibleDocumentViewBase::getAccessibleChildCount (void)
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -257,7 +268,7 @@ sal_Int32 SAL_CALL
 
 Reference<XAccessible> SAL_CALL
     AccessibleDocumentViewBase::getAccessibleChild (sal_Int32 nIndex)
-    throw (uno::RuntimeException, lang::IndexOutOfBoundsException)
+    throw (uno::RuntimeException, lang::IndexOutOfBoundsException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -281,7 +292,7 @@ Reference<XAccessible> SAL_CALL
 uno::Reference<XAccessible > SAL_CALL
     AccessibleDocumentViewBase::getAccessibleAtPoint (
         const awt::Point& aPoint)
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -321,7 +332,7 @@ uno::Reference<XAccessible > SAL_CALL
 
 awt::Rectangle SAL_CALL
     AccessibleDocumentViewBase::getBounds (void)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -360,7 +371,7 @@ awt::Rectangle SAL_CALL
 
 awt::Point SAL_CALL
     AccessibleDocumentViewBase::getLocation (void)
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     awt::Rectangle aBoundingBox (getBounds());
@@ -372,7 +383,7 @@ awt::Point SAL_CALL
 
 awt::Point SAL_CALL
     AccessibleDocumentViewBase::getLocationOnScreen (void)
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     ::Point aLogicalPoint (maShapeTreeInfo.GetViewForwarder()->GetVisibleArea().TopLeft());
@@ -385,7 +396,7 @@ awt::Point SAL_CALL
 
 awt::Size SAL_CALL
     AccessibleDocumentViewBase::getSize (void)
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -410,7 +421,7 @@ awt::Size SAL_CALL
 
 uno::Any SAL_CALL
     AccessibleDocumentViewBase::queryInterface (const uno::Type & rType)
-    throw (uno::RuntimeException)
+    throw (uno::RuntimeException, std::exception)
 {
     uno::Any aReturn = AccessibleContextBase::queryInterface (rType);
     if ( ! aReturn.hasValue())
@@ -422,6 +433,8 @@ uno::Any SAL_CALL
             static_cast<beans::XPropertyChangeListener*>(this),
             static_cast<awt::XWindowListener*>(this),
             static_cast<awt::XFocusListener*>(this)
+           ,static_cast<XAccessibleExtendedAttributes*>(this)
+           ,static_cast<XAccessibleGetAccFlowTo*>(this)
             );
     return aReturn;
 }
@@ -453,7 +466,7 @@ void SAL_CALL
 
 OUString SAL_CALL
     AccessibleDocumentViewBase::getImplementationName (void)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return OUString("AccessibleDocumentViewBase");
 }
@@ -463,7 +476,7 @@ OUString SAL_CALL
 
 ::com::sun::star::uno::Sequence< OUString> SAL_CALL
     AccessibleDocumentViewBase::getSupportedServiceNames (void)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     return AccessibleContextBase::getSupportedServiceNames ();
@@ -477,7 +490,7 @@ OUString SAL_CALL
 
 ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type> SAL_CALL
     AccessibleDocumentViewBase::getTypes (void)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -489,15 +502,15 @@ OUString SAL_CALL
 
     // ...and add the additional type for the component, ...
     const uno::Type aLangEventListenerType =
-         ::getCppuType((const uno::Reference<lang::XEventListener>*)0);
+         cppu::UnoType<lang::XEventListener>::get();
     const uno::Type aPropertyChangeListenerType =
-         ::getCppuType((const uno::Reference<beans::XPropertyChangeListener>*)0);
+         cppu::UnoType<beans::XPropertyChangeListener>::get();
     const uno::Type aWindowListenerType =
-         ::getCppuType((const uno::Reference<awt::XWindowListener>*)0);
+         cppu::UnoType<awt::XWindowListener>::get();
     const uno::Type aFocusListenerType =
-         ::getCppuType((const uno::Reference<awt::XFocusListener>*)0);
+         cppu::UnoType<awt::XFocusListener>::get();
     const uno::Type aEventBroadcaster =
-         ::getCppuType((const uno::Reference<XAccessibleEventBroadcaster>*)0);
+         cppu::UnoType<XAccessibleEventBroadcaster>::get();
 
     // ... and merge them all into one list.
     sal_Int32 nTypeCount (aTypeList.getLength()),
@@ -578,7 +591,7 @@ void AccessibleDocumentViewBase::impl_dispose()
 
 void SAL_CALL
     AccessibleDocumentViewBase::disposing (const lang::EventObject& rEventObject)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -598,7 +611,7 @@ void SAL_CALL
 //=====  XPropertyChangeListener  =============================================
 
 void SAL_CALL AccessibleDocumentViewBase::propertyChange (const beans::PropertyChangeEvent& )
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     // Empty
 }
@@ -610,7 +623,7 @@ void SAL_CALL AccessibleDocumentViewBase::propertyChange (const beans::PropertyC
 
 void SAL_CALL
     AccessibleDocumentViewBase::windowResized (const ::com::sun::star::awt::WindowEvent& )
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     if( IsDisposed() )
         return;
@@ -625,7 +638,7 @@ void SAL_CALL
 
 void SAL_CALL
     AccessibleDocumentViewBase::windowMoved (const ::com::sun::star::awt::WindowEvent& )
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     if( IsDisposed() )
         return;
@@ -640,7 +653,7 @@ void SAL_CALL
 
 void SAL_CALL
     AccessibleDocumentViewBase::windowShown (const ::com::sun::star::lang::EventObject& )
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     if( IsDisposed() )
         return;
@@ -655,7 +668,7 @@ void SAL_CALL
 
 void SAL_CALL
     AccessibleDocumentViewBase::windowHidden (const ::com::sun::star::lang::EventObject& )
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     if( IsDisposed() )
         return;
@@ -671,7 +684,7 @@ void SAL_CALL
 //=====  XFocusListener  ==================================================
 
 void AccessibleDocumentViewBase::focusGained (const ::com::sun::star::awt::FocusEvent& e)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     if (e.Source == mxWindow)
@@ -679,7 +692,7 @@ void AccessibleDocumentViewBase::focusGained (const ::com::sun::star::awt::Focus
 }
 
 void AccessibleDocumentViewBase::focusLost (const ::com::sun::star::awt::FocusEvent& e)
-    throw (::com::sun::star::uno::RuntimeException)
+    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
     if (e.Source == mxWindow)
@@ -804,11 +817,11 @@ uno::Reference< XAccessibleContext >
 }
 
 // return sal_False in default case
-sal_Bool
+bool
     AccessibleDocumentViewBase::implIsSelected( sal_Int32 )
     throw (uno::RuntimeException)
 {
-    return( sal_False );
+    return( false );
 }
 
 // return nothing in default case
@@ -818,6 +831,154 @@ void
 {
 }
 
+uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
+    throw (::com::sun::star::lang::IndexOutOfBoundsException,
+           ::com::sun::star::uno::RuntimeException,
+           std::exception)
+{
+    ::osl::MutexGuard aGuard (maMutex);
+
+    uno::Any anyAtrribute;
+    OUString sValue;
+    if (mpViewShell && mpViewShell->ISA(::sd::DrawViewShell))
+    {
+        ::sd::DrawViewShell* pDrViewSh = (::sd::DrawViewShell*) mpViewShell;
+        OUString sDisplay;
+        OUString sName = "page-name:";
+        // MT IA2: Not used...
+        // SdPage*  pCurrPge = pDrViewSh->getCurrentPage();
+        SdDrawDocument* pDoc = pDrViewSh->GetDoc();
+        sDisplay = pDrViewSh->getCurrentPage()->GetName();
+        sDisplay = sDisplay.replaceFirst( "\\", "\\\\" );
+        sDisplay = sDisplay.replaceFirst( "=", "\\=" );
+        sDisplay = sDisplay.replaceFirst( ";", "\\;" );
+        sDisplay = sDisplay.replaceFirst( ",", "\\," );
+        sDisplay = sDisplay.replaceFirst( ":", "\\:" );
+        sValue = sName + sDisplay ;
+        sName = ";page-number:";
+        sValue += sName;
+        sValue += OUString::number((sal_Int16)((sal_uInt16)((pDrViewSh->getCurrentPage()->GetPageNum()-1)>>1) + 1)) ;
+        sName = ";total-pages:";
+        sValue += sName;
+        sValue += OUString::number(pDrViewSh->GetPageTabControl()->GetPageCount()) ;
+        sValue += ";";
+        if(pDrViewSh->IsLayerModeActive() && pDrViewSh->GetLayerTabControl()) // #i87182#
+        {
+            sName = "page-name:";
+            sValue = sName;
+            sDisplay = pDrViewSh->GetLayerTabControl()->GetPageText(pDrViewSh->GetLayerTabControl()->GetCurPageId());
+            if( pDoc )
+            {
+                SdrLayerAdmin& rLayerAdmin = pDoc->GetLayerAdmin();
+                SdrLayer* aSdrLayer = rLayerAdmin.GetLayer(sDisplay, false);
+                if( aSdrLayer )
+                {
+                    OUString layerAltText = aSdrLayer->GetTitle();
+                    if (!layerAltText.isEmpty())
+                    {
+                        sName = " ";
+                        sDisplay = sDisplay + sName;
+                        sDisplay += layerAltText;
+                    }
+                }
+            }
+            sDisplay = sDisplay.replaceFirst( "\\", "\\\\" );
+            sDisplay = sDisplay.replaceFirst( "=", "\\=" );
+            sDisplay = sDisplay.replaceFirst( ";", "\\;" );
+            sDisplay = sDisplay.replaceFirst( ",", "\\," );
+            sDisplay = sDisplay.replaceFirst( ":", "\\:" );
+            sValue +=  sDisplay;
+            sName = ";page-number:";
+            sValue += sName;
+            sValue += OUString::number(pDrViewSh->GetActiveTabLayerIndex()+1) ;
+            sName = ";total-pages:";
+            sValue += sName;
+            sValue += OUString::number(pDrViewSh->GetLayerTabControl()->GetPageCount()) ;
+            sValue += ";";
+        }
+    }
+    if (mpViewShell && mpViewShell->ISA(::sd::PresentationViewShell))
+    {
+        ::sd::PresentationViewShell* pPresViewSh = (::sd::PresentationViewShell*) mpViewShell;
+        SdPage* pCurrPge = pPresViewSh->getCurrentPage();
+        SdDrawDocument* pDoc = pPresViewSh->GetDoc();
+        SdPage* pNotesPge = (SdPage*)pDoc->GetSdPage((pCurrPge->GetPageNum()-1)>>1, PK_NOTES);
+        if (pNotesPge)
+        {
+            SdrObject* pNotesObj = pNotesPge->GetPresObj(PRESOBJ_NOTES);
+            if (pNotesObj)
+            {
+                OutlinerParaObject* pPara = pNotesObj->GetOutlinerParaObject();
+                if (pPara)
+                {
+                    sValue += "note:";
+                    const EditTextObject& rEdit = pPara->GetTextObject();
+                    for (sal_uInt16 i=0;i<rEdit.GetParagraphCount();i++)
+                    {
+                        OUString strNote = rEdit.GetText(i);
+                        strNote = strNote.replaceFirst( "\\", "\\\\" );
+                        strNote = strNote.replaceFirst( "=", "\\=" );
+                        strNote = strNote.replaceFirst( ";", "\\;" );
+                        strNote = strNote.replaceFirst( ",", "\\," );
+                        strNote = strNote.replaceFirst( ":", "\\:" );
+                        sValue += strNote;
+                        sValue += ";";//to divide each paragraph
+                    }
+                }
+            }
+        }
+    }
+    if (mpViewShell && mpViewShell->ISA(::sd::OutlineViewShell) )
+    {
+        OUString sName;
+        OUString sDisplay;
+        SdPage* pCurrPge = mpViewShell->GetActualPage();
+        SdDrawDocument* pDoc = mpViewShell->GetDoc();
+        if(pCurrPge && pDoc)
+        {
+            sName = "page-name:";
+            sDisplay = pCurrPge->GetName();
+            sDisplay = sDisplay.replaceFirst( "=", "\\=" );
+            sDisplay = sDisplay.replaceFirst( ";", "\\;" );
+            sDisplay = sDisplay.replaceFirst( ",", "\\," );
+            sDisplay = sDisplay.replaceFirst( ":", "\\:" );
+            sValue = sName + sDisplay ;
+            sName = ";page-number:";
+            sValue += sName;
+            sValue += OUString::number((sal_Int16)((sal_uInt16)((pCurrPge->GetPageNum()-1)>>1) + 1)) ;
+            sName = ";total-pages:";
+            sValue += sName;
+            sValue += OUString::number(pDoc->GetSdPageCount(PK_STANDARD)) ;
+            sValue += ";";
+        }
+    }
+    if (sValue.getLength())
+        anyAtrribute <<= sValue;
+    return anyAtrribute;
+}
+
+::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >
+        SAL_CALL AccessibleDocumentViewBase::getAccFlowTo(const ::com::sun::star::uno::Any&, sal_Int32 )
+        throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+{
+    ::com::sun::star::uno::Sequence< uno::Any> aRet;
+
+    return aRet;
+}
+
+sal_Int32 SAL_CALL AccessibleDocumentViewBase::getForeground(  )
+        throw (uno::RuntimeException, std::exception)
+{
+    return COL_BLACK;
+}
+
+sal_Int32 SAL_CALL AccessibleDocumentViewBase::getBackground(  )
+        throw (uno::RuntimeException, std::exception)
+{
+     ThrowIfDisposed ();
+    ::osl::MutexGuard aGuard (maMutex);
+    return mpViewShell->GetView()->getColorConfig().GetColorValue( ::svtools::DOCCOLOR ).nColor;
+}
 } // end of namespace accessibility
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
