@@ -107,7 +107,7 @@ public:
         GapMembership eGapMembership = GM_NONE) const;
 
     /** Calculate the column that the point with the given horizontal
-        coordinate is over.  The verical component is ignored.
+        coordinate is over.  The vertical component is ignored.
         @param nXPosition
             Horizontal position in model coordinates.
         @param bIncludeBordersAndGaps
@@ -227,23 +227,20 @@ protected:
 class VerticalImplementation : public Layouter::Implementation
 {
 public:
-    VerticalImplementation (
-        const SharedSdWindow& rpWindow,
-        const ::boost::shared_ptr<view::Theme>& rpTheme);
     VerticalImplementation (const Implementation& rImplementation);
 
-    virtual Layouter::Orientation GetOrientation (void) const;
+    virtual Layouter::Orientation GetOrientation (void) const SAL_OVERRIDE;
 
     void CalculateLogicalInsertPosition (
         const Point& rModelPosition,
-        InsertPosition& rPosition) const;
+        InsertPosition& rPosition) const SAL_OVERRIDE;
 
 protected:
-    virtual void CalculateRowAndColumnCount (const Size& rWindowSize);
-    virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize);
+    virtual void CalculateRowAndColumnCount (const Size& rWindowSize) SAL_OVERRIDE;
+    virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize) SAL_OVERRIDE;
     virtual Size CalculateTargetSize (
         const Size& rWindowSize,
-        const Size& rPreviewModelSize) const;
+        const Size& rPreviewModelSize) const SAL_OVERRIDE;
 };
 
 
@@ -255,18 +252,18 @@ class HorizontalImplementation : public Layouter::Implementation
 public:
     HorizontalImplementation (const Implementation& rImplementation);
 
-    virtual Layouter::Orientation GetOrientation (void) const;
+    virtual Layouter::Orientation GetOrientation (void) const SAL_OVERRIDE;
 
     void CalculateLogicalInsertPosition (
         const Point& rModelPosition,
-        InsertPosition& rPosition) const;
+        InsertPosition& rPosition) const SAL_OVERRIDE;
 
 protected:
-    virtual void CalculateRowAndColumnCount (const Size& rWindowSize);
-    virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize);
+    virtual void CalculateRowAndColumnCount (const Size& rWindowSize) SAL_OVERRIDE;
+    virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize) SAL_OVERRIDE;
     virtual Size CalculateTargetSize (
         const Size& rWindowSize,
-        const Size& rPreviewModelSize) const;
+        const Size& rPreviewModelSize) const SAL_OVERRIDE;
 };
 
 
@@ -282,18 +279,18 @@ public:
         const ::boost::shared_ptr<view::Theme>& rpTheme);
     GridImplementation (const Implementation& rImplementation);
 
-    virtual Layouter::Orientation GetOrientation (void) const;
+    virtual Layouter::Orientation GetOrientation (void) const SAL_OVERRIDE;
 
     void CalculateLogicalInsertPosition (
         const Point& rModelPosition,
-        InsertPosition& rPosition) const;
+        InsertPosition& rPosition) const SAL_OVERRIDE;
 
 protected:
-    virtual void CalculateRowAndColumnCount (const Size& rWindowSize);
-    virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize);
+    virtual void CalculateRowAndColumnCount (const Size& rWindowSize) SAL_OVERRIDE;
+    virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize) SAL_OVERRIDE;
     virtual Size CalculateTargetSize (
         const Size& rWindowSize,
-        const Size& rPreviewModelSize) const;
+        const Size& rPreviewModelSize) const SAL_OVERRIDE;
 };
 
 
