@@ -99,12 +99,11 @@
 #include "fltlst.hxx"
 #include <sfx2/request.hxx>
 #include "arrdecl.hxx"
-#include <sfx2/appuno.hxx>
 
 #include <boost/ptr_container/ptr_vector.hpp>
 #include <functional>
 
-#if defined(DBG_UTIL) && defined(WNT)
+#if defined(DBG_UTIL)
 unsigned SfxStack::nLevel = 0;
 #endif
 
@@ -113,25 +112,41 @@ using namespace com::sun::star;
 namespace
 {
     class theSfxFilterListener : public rtl::Static<SfxFilterListener, theSfxFilterListener> {};
-    class theSfxFilterArray : public rtl::Static<SfxFilterList_Impl, theSfxFilterArray > {};
+    class SfxFilterArray
+    {
+        SfxFilterList_Impl aList;
+    public:
+        ~SfxFilterArray()
+        {
+            SfxFilterList_Impl::iterator aEnd = aList.end();
+            for (SfxFilterList_Impl::iterator aI = aList.begin(); aI != aEnd; ++aI)
+            {
+                SfxFilter *pFilter = *aI;
+                delete pFilter;
+            }
+        }
+        SfxFilterList_Impl *getList()
+        {
+            return &aList;
+        }
+    };
+    class theSfxFilterArray : public rtl::Static<SfxFilterArray, theSfxFilterArray > {};
 }
 
 static SfxFilterList_Impl* pFilterArr = 0;
-static sal_Bool bFirstRead = sal_True;
+static bool bFirstRead = true;
 
 static void CreateFilterArr()
 {
-    pFilterArr = &theSfxFilterArray::get();
+    pFilterArr = theSfxFilterArray::get().getList();
     theSfxFilterListener::get();
 }
 
-//----------------------------------------------------------------
 inline OUString ToUpper_Impl( const OUString &rStr )
 {
     return SvtSysLocale().GetCharClass().uppercase( rStr );
 }
 
-//----------------------------------------------------------------
 class SfxFilterContainer_Impl
 {
 public:
@@ -162,21 +177,21 @@ const SfxFilter* SfxFilterContainer::GetAnyFilter( SfxFilterFlags nMust, SfxFilt
     return aMatch.GetAnyFilter( nMust, nDont );
 }
 
-//----------------------------------------------------------------
+
 
 SfxFilterContainer::SfxFilterContainer( const OUString& rName )
 {
     pImpl = new SfxFilterContainer_Impl( rName );
 }
 
-//----------------------------------------------------------------
+
 
 SfxFilterContainer::~SfxFilterContainer()
 {
     delete pImpl;
 }
 
-//----------------------------------------------------------------
+
 
 const OUString SfxFilterContainer::GetName() const
 {
@@ -237,7 +252,7 @@ const SfxFilter* SfxFilterContainer::GetDefaultFilter_Impl( const OUString& rNam
 }
 
 
-//----------------------------------------------------------------
+
 
 // Impl-Data is shared between all FilterMatchers of the same factory
 class SfxFilterMatcher_Impl
@@ -376,7 +391,7 @@ const SfxFilter* SfxFilterMatcher::GetAnyFilter( SfxFilterFlags nMust, SfxFilter
     return NULL;
 }
 
-//----------------------------------------------------------------
+
 
 sal_uInt32  SfxFilterMatcher::GuessFilterIgnoringContent(
     SfxMedium& rMedium,
@@ -407,16 +422,16 @@ sal_uInt32  SfxFilterMatcher::GuessFilterIgnoringContent(
     return *ppFilter ? ERRCODE_NONE : ERRCODE_ABORT;
 }
 
-//----------------------------------------------------------------
+
 
 sal_uInt32  SfxFilterMatcher::GuessFilter( SfxMedium& rMedium, const SfxFilter**ppFilter, SfxFilterFlags nMust, SfxFilterFlags nDont ) const
 {
-    return GuessFilterControlDefaultUI( rMedium, ppFilter, nMust, nDont, sal_True );
+    return GuessFilterControlDefaultUI( rMedium, ppFilter, nMust, nDont, true );
 }
 
-//----------------------------------------------------------------
 
-sal_uInt32  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, const SfxFilter** ppFilter, SfxFilterFlags nMust, SfxFilterFlags nDont, sal_Bool /*bDefUI*/ ) const
+
+sal_uInt32  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, const SfxFilter** ppFilter, SfxFilterFlags nMust, SfxFilterFlags nDont, bool /*bDefUI*/ ) const
 {
     const SfxFilter* pOldFilter = *ppFilter;
 
@@ -511,8 +526,8 @@ sal_uInt32  SfxFilterMatcher::GuessFilterControlDefaultUI( SfxMedium& rMedium, c
     return ERRCODE_ABORT;
 }
 
-//----------------------------------------------------------------
-sal_Bool SfxFilterMatcher::IsFilterInstalled_Impl( const SfxFilter* pFilter )
+
+bool SfxFilterMatcher::IsFilterInstalled_Impl( const SfxFilter* pFilter )
 {
     if ( pFilter->GetFilterFlags() & SFX_FILTER_MUSTINSTALL )
     {
@@ -538,14 +553,14 @@ sal_Bool SfxFilterMatcher::IsFilterInstalled_Impl( const SfxFilter* pFilter )
         OUString aText( SfxResId(STR_FILTER_CONSULT_SERVICE).toString() );
         aText = aText.replaceFirst( "$(FILTER)", pFilter->GetUIName() );
         InfoBox ( NULL, aText ).Execute();
-        return sal_False;
+        return false;
     }
     else
-        return sal_True;
+        return true;
 }
 
 
-sal_uInt32 SfxFilterMatcher::DetectFilter( SfxMedium& rMedium, const SfxFilter**ppFilter, sal_Bool /*bPlugIn*/, sal_Bool bAPI ) const
+sal_uInt32 SfxFilterMatcher::DetectFilter( SfxMedium& rMedium, const SfxFilter**ppFilter, bool /*bPlugIn*/, bool bAPI ) const
 /*  [Description]
 
     Here the Filter selection box is pulled up. Otherwise GuessFilter
@@ -559,7 +574,7 @@ sal_uInt32 SfxFilterMatcher::DetectFilter( SfxMedium& rMedium, const SfxFilter**
             pOldFilter = 0;
         else
         {
-            SFX_ITEMSET_ARG( rMedium.GetItemSet(), pSalvageItem, SfxStringItem, SID_DOC_SALVAGE, sal_False);
+            SFX_ITEMSET_ARG( rMedium.GetItemSet(), pSalvageItem, SfxStringItem, SID_DOC_SALVAGE, false);
             if ( ( pOldFilter->GetFilterFlags() & SFX_FILTER_PACKED ) && pSalvageItem )
                 // Salvage is always done without packing
                 pOldFilter = 0;
@@ -568,8 +583,8 @@ sal_uInt32 SfxFilterMatcher::DetectFilter( SfxMedium& rMedium, const SfxFilter**
 
     const SfxFilter* pFilter = pOldFilter;
 
-    sal_Bool bPreview = rMedium.IsPreview_Impl();
-    SFX_ITEMSET_ARG(rMedium.GetItemSet(), pReferer, SfxStringItem, SID_REFERER, sal_False);
+    bool bPreview = rMedium.IsPreview_Impl();
+    SFX_ITEMSET_ARG(rMedium.GetItemSet(), pReferer, SfxStringItem, SID_REFERER, false);
     if ( bPreview && rMedium.IsRemote() && ( !pReferer || !pReferer->GetValue().match("private:searchfolder:") ) )
         return ERRCODE_ABORT;
 
@@ -605,14 +620,14 @@ sal_uInt32 SfxFilterMatcher::DetectFilter( SfxMedium& rMedium, const SfxFilter**
         }
     }
 
-    sal_Bool bHidden = bPreview;
-    SFX_ITEMSET_ARG( rMedium.GetItemSet(), pFlags, SfxStringItem, SID_OPTIONS, sal_False);
+    bool bHidden = bPreview;
+    SFX_ITEMSET_ARG( rMedium.GetItemSet(), pFlags, SfxStringItem, SID_OPTIONS, false);
     if ( !bHidden && pFlags )
     {
         OUString aFlags( pFlags->GetValue() );
         aFlags = aFlags.toAsciiUpperCase();
         if( -1 != aFlags.indexOf( 'H' ) )
-            bHidden = sal_True;
+            bHidden = true;
     }
     *ppFilter = pFilter;
 
@@ -625,7 +640,7 @@ const SfxFilter* SfxFilterMatcher::GetFilterForProps( const com::sun::star::uno:
 {
     uno::Reference< lang::XMultiServiceFactory > xServiceManager = ::comphelper::getProcessServiceFactory();
     uno::Reference< container::XContainerQuery > xTypeCFG;
-    if( xServiceManager.is() == sal_True )
+    if( xServiceManager.is() )
         xTypeCFG   = uno::Reference < com::sun::star::container::XContainerQuery >( xServiceManager->createInstance( "com.sun.star.document.TypeDetection" ), uno::UNO_QUERY );
     if ( xTypeCFG.is() )
     {
@@ -749,7 +764,7 @@ const SfxFilter* SfxFilterMatcher::GetFilter4Extension( const OUString& rExt, Sf
 
     // Use extension without dot!
     OUString sExt( rExt );
-    if ( !sExt.isEmpty() && ( sExt[0] == (sal_Unicode)'.' ))
+    if ( sExt.startsWith(".") )
         sExt = sExt.copy(1);
 
     com::sun::star::uno::Sequence < com::sun::star::beans::NamedValue > aSeq(1);
@@ -807,7 +822,7 @@ const SfxFilter* SfxFilterMatcher::GetFilter4FilterName( const OUString& rName,
         uno::Reference< lang::XMultiServiceFactory > xServiceManager = ::comphelper::getProcessServiceFactory();
         uno::Reference< container::XNameAccess >     xFilterCFG                                                ;
         uno::Reference< container::XNameAccess >     xTypeCFG                                                  ;
-        if( xServiceManager.is() == sal_True )
+        if( xServiceManager.is() )
         {
             xFilterCFG = uno::Reference< container::XNameAccess >( xServiceManager->createInstance(  "com.sun.star.document.FilterFactory" ), uno::UNO_QUERY );
             xTypeCFG   = uno::Reference< container::XNameAccess >( xServiceManager->createInstance(  "com.sun.star.document.TypeDetection" ), uno::UNO_QUERY );
@@ -828,7 +843,7 @@ const SfxFilter* SfxFilterMatcher::GetFilter4FilterName( const OUString& rName,
                 }
             }
 
-            SfxFilterContainer::ReadSingleFilter_Impl( rName, xTypeCFG, xFilterCFG, sal_False );
+            SfxFilterContainer::ReadSingleFilter_Impl( rName, xTypeCFG, xFilterCFG, false );
         }
     }
 
@@ -860,7 +875,7 @@ IMPL_STATIC_LINK( SfxFilterMatcher, MaybeFileHdl_Impl, OUString*, pString )
     return sal_False;
 }
 
-//----------------------------------------------------------------
+
 
 SfxFilterMatcherIter::SfxFilterMatcherIter(
     const SfxFilterMatcher& rMatcher,
@@ -873,7 +888,7 @@ SfxFilterMatcherIter::SfxFilterMatcherIter(
     m_rMatch.InitForIterating();
 }
 
-//----------------------------------------------------------------
+
 
 const SfxFilter* SfxFilterMatcherIter::Find_Impl()
 {
@@ -896,7 +911,7 @@ const SfxFilter* SfxFilterMatcherIter::First()
     return Find_Impl();
 }
 
-//----------------------------------------------------------------
+
 
 const SfxFilter* SfxFilterMatcherIter::Next()
 {
@@ -934,7 +949,7 @@ void SfxFilterContainer::ReadSingleFilter_Impl(
     const OUString& rName,
     const uno::Reference< container::XNameAccess >& xTypeCFG,
     const uno::Reference< container::XNameAccess >& xFilterCFG,
-    sal_Bool bUpdate
+    bool bUpdate
     )
 {
     OUString sFilterName( rName );
@@ -1127,13 +1142,12 @@ void SfxFilterContainer::ReadSingleFilter_Impl(
     }
 }
 
-void SfxFilterContainer::ReadFilters_Impl( sal_Bool bUpdate )
+void SfxFilterContainer::ReadFilters_Impl( bool bUpdate )
 {
-    SAL_INFO( "sfx.bastyp", "sfx2 (as96863) ::SfxFilterContainer::ReadFilters" );
     if ( !pFilterArr )
         CreateFilterArr();
 
-    bFirstRead = sal_False;
+    bFirstRead = false;
     SfxFilterList_Impl& rList = *pFilterArr;
 
     try
@@ -1142,16 +1156,13 @@ void SfxFilterContainer::ReadFilters_Impl( sal_Bool bUpdate )
         uno::Reference< lang::XMultiServiceFactory > xServiceManager = ::comphelper::getProcessServiceFactory();
         uno::Reference< container::XNameAccess >     xFilterCFG                                                ;
         uno::Reference< container::XNameAccess >     xTypeCFG                                                  ;
-        if( xServiceManager.is() == sal_True )
+        if( xServiceManager.is() )
         {
             xFilterCFG = uno::Reference< container::XNameAccess >( xServiceManager->createInstance(  "com.sun.star.document.FilterFactory" ), uno::UNO_QUERY );
             xTypeCFG   = uno::Reference< container::XNameAccess >( xServiceManager->createInstance(  "com.sun.star.document.TypeDetection" ), uno::UNO_QUERY );
         }
 
-        if(
-            ( xFilterCFG.is() == sal_True ) &&
-            ( xTypeCFG.is()   == sal_True )
-          )
+        if( xFilterCFG.is() && xTypeCFG.is() )
         {
             // select right query to get right set of filters for search modul
             uno::Sequence< OUString > lFilterNames = xFilterCFG->getElementNames();
@@ -1159,11 +1170,11 @@ void SfxFilterContainer::ReadFilters_Impl( sal_Bool bUpdate )
             {
                 // If list of filters already exist ...
                 // ReadExternalFilters must work in update mode.
-                // Best way seams to mark all filters NOT_INSTALLED
+                // Best way seems to mark all filters NOT_INSTALLED
                 // and change it back for all valid filters afterwards.
                 if( !rList.empty() )
                 {
-                    bUpdate = sal_True;
+                    bUpdate = true;
                     SfxFilter* pFilter;
                     for ( size_t i = 0, n = rList.size(); i < n; ++i )
                     {
