@@ -121,7 +121,7 @@ using namespace ::com::sun::star;
 using namespace css::system;
 
 namespace {
-//-------------------------------------------------------------------------
+
 static sal_uInt16 getSlotIDFromMode( sal_Int8 nStoreMode )
 {
     // This is a temporary hardcoded solution must be removed when
@@ -137,13 +137,13 @@ static sal_uInt16 getSlotIDFromMode( sal_Int8 nStoreMode )
     else if ( nStoreMode == SAVEAS_REQUESTED || nStoreMode == ( EXPORT_REQUESTED | WIDEEXPORT_REQUESTED ) )
         nResult = SID_SAVEASDOC;
     else {
-        DBG_ASSERT( sal_False, "Unacceptable slot name is provided!\n" );
+        DBG_ASSERT( false, "Unacceptable slot name is provided!\n" );
     }
 
     return nResult;
 }
 
-//-------------------------------------------------------------------------
+
 static sal_uInt8 getStoreModeFromSlotName( const OUString& aSlotName )
 {
     sal_uInt8 nResult = 0;
@@ -166,14 +166,14 @@ static sal_uInt8 getStoreModeFromSlotName( const OUString& aSlotName )
     return nResult;
 }
 
-//-------------------------------------------------------------------------
+
 static sal_Int32 getMustFlags( sal_Int8 nStoreMode )
 {
     return ( SFX_FILTER_EXPORT
             | ( ( ( nStoreMode & EXPORT_REQUESTED ) && !( nStoreMode & WIDEEXPORT_REQUESTED ) ) ? 0 : SFX_FILTER_IMPORT ) );
 }
 
-//-------------------------------------------------------------------------
+
 static sal_Int32 getDontFlags( sal_Int8 nStoreMode )
 {
     return ( SFX_FILTER_INTERNAL
@@ -181,21 +181,21 @@ static sal_Int32 getDontFlags( sal_Int8 nStoreMode )
             | ( ( ( nStoreMode & EXPORT_REQUESTED ) && !( nStoreMode & WIDEEXPORT_REQUESTED ) ) ? SFX_FILTER_IMPORT : 0 ) );
 }
 
-//=========================================================================
+
 // class DocumentSettingsGuard
-//=========================================================================
+
 
 class DocumentSettingsGuard
 {
     uno::Reference< beans::XPropertySet > m_xDocumentSettings;
-    sal_Bool m_bPreserveReadOnly;
-    sal_Bool m_bReadOnlySupported;
+    bool m_bPreserveReadOnly;
+    bool m_bReadOnlySupported;
 
-    sal_Bool m_bRestoreSettings;
+    bool m_bRestoreSettings;
 public:
-    DocumentSettingsGuard( const uno::Reference< frame::XModel >& xModel, sal_Bool bReadOnly, sal_Bool bRestore )
-    : m_bPreserveReadOnly( sal_False )
-    , m_bReadOnlySupported( sal_False )
+    DocumentSettingsGuard( const uno::Reference< frame::XModel >& xModel, bool bReadOnly, bool bRestore )
+    : m_bPreserveReadOnly( false )
+    , m_bReadOnlySupported( false )
     , m_bRestoreSettings( bRestore )
     {
         try
@@ -212,7 +212,7 @@ public:
             {
                 m_xDocumentSettings->getPropertyValue( aLoadReadonlyString ) >>= m_bPreserveReadOnly;
                 m_xDocumentSettings->setPropertyValue( aLoadReadonlyString, uno::makeAny( bReadOnly ) );
-                m_bReadOnlySupported = sal_True;
+                m_bReadOnlySupported = true;
             }
             catch( const uno::Exception& )
             {}
@@ -244,9 +244,9 @@ public:
 };
 } // anonymous namespace
 
-//=========================================================================
+
 // class ModelData_Impl
-//=========================================================================
+
 class ModelData_Impl
 {
     SfxStoringHelper* m_pOwner;
@@ -261,7 +261,7 @@ class ModelData_Impl
 
     ::comphelper::SequenceAsHashMap m_aMediaDescrHM;
 
-    sal_Bool m_bRecommendReadOnly;
+    bool m_bRecommendReadOnly;
 
 public:
     ModelData_Impl( SfxStoringHelper& aOwner,
@@ -279,7 +279,7 @@ public:
 
     ::comphelper::SequenceAsHashMap& GetMediaDescr() { return m_aMediaDescrHM; }
 
-    sal_Bool IsRecommendReadOnly() const { return m_bRecommendReadOnly; }
+    bool IsRecommendReadOnly() const { return m_bRecommendReadOnly; }
 
     const ::comphelper::SequenceAsHashMap& GetDocProps();
 
@@ -295,27 +295,27 @@ public:
     uno::Sequence< beans::PropertyValue > GetPreselectedFilter_Impl( sal_Int8 nStoreMode );
     uno::Sequence< beans::PropertyValue > GetDocServiceDefaultFilter();
 
-    sal_Bool ExecuteFilterDialog_Impl( const OUString& aFilterName );
+    bool ExecuteFilterDialog_Impl( const OUString& aFilterName );
 
     sal_Int8 CheckSaveAcceptable( sal_Int8 nCurStatus );
     sal_Int8 CheckStateForSave();
 
     sal_Int8 CheckFilter( const OUString& );
 
-    sal_Bool CheckFilterOptionsDialogExistence();
+    bool CheckFilterOptionsDialogExistence();
 
-    sal_Bool OutputFileDialog( sal_Int8 nStoreMode,
+    bool OutputFileDialog( sal_Int8 nStoreMode,
                                 const ::comphelper::SequenceAsHashMap& aPreselectedFilterPropsHM,
-                                sal_Bool bSetStandardName,
+                                bool bSetStandardName,
                                 OUString& aSuggestedName,
-                                sal_Bool bPreselectPassword,
+                                bool bPreselectPassword,
                                 OUString& aSuggestedDir,
                                 sal_Int16 nDialog,
                                 const OUString& rStandardDir,
                                 const ::com::sun::star::uno::Sequence< OUString >& rBlackList
                                 );
 
-    sal_Bool ShowDocumentInfoDialog();
+    bool ShowDocumentInfoDialog();
 
     OUString GetRecommendedDir( const OUString& aSuggestedDir );
     OUString GetRecommendedName( const OUString& aSuggestedName,
@@ -323,7 +323,7 @@ public:
 
 };
 
-//-------------------------------------------------------------------------
+
 ModelData_Impl::ModelData_Impl( SfxStoringHelper& aOwner,
                                 const uno::Reference< frame::XModel >& xModel,
                                 const uno::Sequence< beans::PropertyValue >& aMediaDescr )
@@ -332,7 +332,7 @@ ModelData_Impl::ModelData_Impl( SfxStoringHelper& aOwner,
 , m_pDocumentPropsHM( NULL )
 , m_pModulePropsHM( NULL )
 , m_aMediaDescrHM( aMediaDescr )
-, m_bRecommendReadOnly( sal_False )
+, m_bRecommendReadOnly( false )
 {
     CheckInteractionHandler();
     OUString sModuleName;
@@ -360,7 +360,7 @@ ModelData_Impl::ModelData_Impl( SfxStoringHelper& aOwner,
     }
 }
 
-//-------------------------------------------------------------------------
+
 ModelData_Impl::~ModelData_Impl()
 {
     FreeDocumentProps();
@@ -371,7 +371,7 @@ ModelData_Impl::~ModelData_Impl()
         delete m_pModulePropsHM;
 }
 
-//-------------------------------------------------------------------------
+
 void ModelData_Impl::FreeDocumentProps()
 {
     if ( m_pDocumentPropsHM )
@@ -381,7 +381,7 @@ void ModelData_Impl::FreeDocumentProps()
     }
 }
 
-//-------------------------------------------------------------------------
+
 uno::Reference< frame::XModel > ModelData_Impl::GetModel()
 {
     if ( !m_xModel.is() )
@@ -390,7 +390,7 @@ uno::Reference< frame::XModel > ModelData_Impl::GetModel()
     return m_xModel;
 }
 
-//-------------------------------------------------------------------------
+
 uno::Reference< frame::XStorable > ModelData_Impl::GetStorable()
 {
     if ( !m_xStorable.is() )
@@ -403,7 +403,7 @@ uno::Reference< frame::XStorable > ModelData_Impl::GetStorable()
     return m_xStorable;
 }
 
-//-------------------------------------------------------------------------
+
 uno::Reference< frame::XStorable2 > ModelData_Impl::GetStorable2()
 {
     if ( !m_xStorable2.is() )
@@ -416,7 +416,7 @@ uno::Reference< frame::XStorable2 > ModelData_Impl::GetStorable2()
     return m_xStorable2;
 }
 
-//-------------------------------------------------------------------------
+
 uno::Reference< util::XModifiable > ModelData_Impl::GetModifiable()
 {
     if ( !m_xModifiable.is() )
@@ -429,7 +429,7 @@ uno::Reference< util::XModifiable > ModelData_Impl::GetModifiable()
     return m_xModifiable;
 }
 
-//-------------------------------------------------------------------------
+
 const ::comphelper::SequenceAsHashMap& ModelData_Impl::GetDocProps()
 {
     if ( !m_pDocumentPropsHM )
@@ -438,7 +438,7 @@ const ::comphelper::SequenceAsHashMap& ModelData_Impl::GetDocProps()
     return *m_pDocumentPropsHM;
 }
 
-//-------------------------------------------------------------------------
+
 OUString ModelData_Impl::GetModuleName()
 {
     if ( m_aModuleName.isEmpty() )
@@ -451,7 +451,7 @@ OUString ModelData_Impl::GetModuleName()
     return m_aModuleName;
 }
 
-//-------------------------------------------------------------------------
+
 const ::comphelper::SequenceAsHashMap& ModelData_Impl::GetModuleProps()
 {
     if ( !m_pModulePropsHM )
@@ -466,13 +466,13 @@ const ::comphelper::SequenceAsHashMap& ModelData_Impl::GetModuleProps()
     return *m_pModulePropsHM;
 }
 
-//-------------------------------------------------------------------------
+
 OUString ModelData_Impl::GetDocServiceName()
 {
     return GetModuleProps().getUnpackedValueOrDefault("ooSetupFactoryDocumentService", OUString());
 }
 
-//-------------------------------------------------------------------------
+
 void ModelData_Impl::CheckInteractionHandler()
 {
     ::comphelper::SequenceAsHashMap::const_iterator aInteractIter =
@@ -495,7 +495,7 @@ void ModelData_Impl::CheckInteractionHandler()
     }
 }
 
-//-------------------------------------------------------------------------
+
 uno::Sequence< beans::PropertyValue > ModelData_Impl::GetDocServiceDefaultFilter()
 {
     uno::Sequence< beans::PropertyValue > aProps;
@@ -509,7 +509,7 @@ uno::Sequence< beans::PropertyValue > ModelData_Impl::GetDocServiceDefaultFilter
     return aProps;
 }
 
-//-------------------------------------------------------------------------
+
 uno::Sequence< beans::PropertyValue > ModelData_Impl::GetDocServiceDefaultFilterCheckFlags( sal_Int32 nMust,
                                                                                                 sal_Int32 nDont )
 {
@@ -528,7 +528,7 @@ uno::Sequence< beans::PropertyValue > ModelData_Impl::GetDocServiceDefaultFilter
 }
 
 
-//-------------------------------------------------------------------------
+
 uno::Sequence< beans::PropertyValue > ModelData_Impl::GetDocServiceAnyFilter( sal_Int32 nMust, sal_Int32 nDont )
 {
     uno::Sequence< beans::NamedValue > aSearchRequest( 1 );
@@ -538,7 +538,7 @@ uno::Sequence< beans::PropertyValue > ModelData_Impl::GetDocServiceAnyFilter( sa
     return ::comphelper::MimeConfigurationHelper::SearchForFilter( m_pOwner->GetFilterQuery(), aSearchRequest, nMust, nDont );
 }
 
-//-------------------------------------------------------------------------
+
 uno::Sequence< beans::PropertyValue > ModelData_Impl::GetPreselectedFilter_Impl( sal_Int8 nStoreMode )
 {
     uno::Sequence< beans::PropertyValue > aFilterProps;
@@ -571,10 +571,10 @@ uno::Sequence< beans::PropertyValue > ModelData_Impl::GetPreselectedFilter_Impl(
     return aFilterProps;
 }
 
-//-------------------------------------------------------------------------
-sal_Bool ModelData_Impl::ExecuteFilterDialog_Impl( const OUString& aFilterName )
+
+bool ModelData_Impl::ExecuteFilterDialog_Impl( const OUString& aFilterName )
 {
-    sal_Bool bDialogUsed = sal_False;
+    bool bDialogUsed = false;
 
     try {
         uno::Sequence < beans::PropertyValue > aProps;
@@ -596,7 +596,7 @@ sal_Bool ModelData_Impl::ExecuteFilterDialog_Impl( const OUString& aFilterName )
 
                         if( xFilterDialog.is() && xFilterProperties.is() )
                         {
-                            bDialogUsed = sal_True;
+                            bDialogUsed = true;
 
                             uno::Reference< document::XExporter > xExporter( xFilterDialog, uno::UNO_QUERY );
                             if( xExporter.is() )
@@ -650,7 +650,7 @@ sal_Bool ModelData_Impl::ExecuteFilterDialog_Impl( const OUString& aFilterName )
     return bDialogUsed;
 }
 
-//-------------------------------------------------------------------------
+
 sal_Int8 ModelData_Impl::CheckSaveAcceptable( sal_Int8 nCurStatus )
 {
     sal_Int8 nResult = nCurStatus;
@@ -677,7 +677,7 @@ sal_Int8 ModelData_Impl::CheckSaveAcceptable( sal_Int8 nCurStatus )
     return nResult;
 }
 
-//-------------------------------------------------------------------------
+
 sal_Int8 ModelData_Impl::CheckStateForSave()
 {
     // if the document is readonly or a new one a SaveAs operation must be used
@@ -685,7 +685,7 @@ sal_Int8 ModelData_Impl::CheckStateForSave()
         return STATUS_SAVEAS;
 
     // check acceptable entries for media descriptor
-    sal_Bool bVersInfoNeedsStore = sal_False;
+    bool bVersInfoNeedsStore = false;
     ::comphelper::SequenceAsHashMap aAcceptedArgs;
 
     OUString aVersionCommentString("VersionComment");
@@ -696,7 +696,7 @@ sal_Int8 ModelData_Impl::CheckStateForSave()
 
     if ( GetMediaDescr().find( aVersionCommentString ) != GetMediaDescr().end() )
     {
-        bVersInfoNeedsStore = sal_True;
+        bVersInfoNeedsStore = true;
         aAcceptedArgs[ aVersionCommentString ] = GetMediaDescr()[ aVersionCommentString ];
     }
     if ( GetMediaDescr().find( aAuthorString ) != GetMediaDescr().end() )
@@ -716,7 +716,7 @@ sal_Int8 ModelData_Impl::CheckStateForSave()
 
     // the document must be modified unless the always-save flag is set.
     SvtMiscOptions aMiscOptions;
-    sal_Bool bAlwaysAllowSave = aMiscOptions.IsSaveAlwaysAllowed();
+    bool bAlwaysAllowSave = aMiscOptions.IsSaveAlwaysAllowed();
     if (!bAlwaysAllowSave)
     {
         if ( !GetModifiable()->isModified() && !bVersInfoNeedsStore )
@@ -732,9 +732,9 @@ sal_Int8 ModelData_Impl::CheckStateForSave()
     return nResult;
 }
 
-sal_Bool hasMacros( const uno::Reference< frame::XModel >& xModel  )
+bool hasMacros( const uno::Reference< frame::XModel >& xModel  )
 {
-    sal_Bool bHasMacros = sal_False;
+    bool bHasMacros = false;
     uno::Reference< script::XLibraryContainer > xContainer;
     uno::Reference< beans::XPropertySet > xProps( xModel, uno::UNO_QUERY );
     if ( xProps.is() )
@@ -781,7 +781,7 @@ sal_Int8 ModelData_Impl::CheckFilter( const OUString& aFilterName )
            && aDefFiltPropsHM.size()
            && ( nDefFiltFlags & SFX_FILTER_EXPORT ) && !( nDefFiltFlags & SFX_FILTER_INTERNAL ))
     {
-        // the default filter is acceptable and the old filter is alian one
+        // the default filter is acceptable and the old filter is alien one
         // so ask to make a saveAs operation
         OUString aUIName = aFiltPropsHM.getUnpackedValueOrDefault("UIName",
                                                                                 OUString() );
@@ -827,7 +827,7 @@ sal_Int8 ModelData_Impl::CheckFilter( const OUString& aFilterName )
                         return STATUS_SAVEAS;
                 }
             }
-            if ( !SfxStoringHelper::WarnUnacceptableFormat( GetModel(), aUIName, aDefUIName, sal_True ) )
+            if ( !SfxStoringHelper::WarnUnacceptableFormat( GetModel(), aUIName, aDefUIName, true ) )
                 return STATUS_SAVEAS_STANDARDNAME;
         }
     }
@@ -835,8 +835,8 @@ sal_Int8 ModelData_Impl::CheckFilter( const OUString& aFilterName )
     return STATUS_SAVE;
 }
 
-//-------------------------------------------------------------------------
-sal_Bool ModelData_Impl::CheckFilterOptionsDialogExistence()
+
+bool ModelData_Impl::CheckFilterOptionsDialogExistence()
 {
     uno::Sequence< beans::NamedValue > aSearchRequest( 1 );
     aSearchRequest[0].Name = "DocumentService";
@@ -855,25 +855,25 @@ sal_Bool ModelData_Impl::CheckFilterOptionsDialogExistence()
                                             OUString("UIComponent"),
                                             OUString() );
             if ( !aUIServName.isEmpty() )
-                return sal_True;
+                return true;
         }
     }
 
-    return sal_False;
+    return false;
 }
 
-//-------------------------------------------------------------------------
-sal_Bool ModelData_Impl::OutputFileDialog( sal_Int8 nStoreMode,
+
+bool ModelData_Impl::OutputFileDialog( sal_Int8 nStoreMode,
                                             const ::comphelper::SequenceAsHashMap& aPreselectedFilterPropsHM,
-                                            sal_Bool bSetStandardName,
+                                            bool bSetStandardName,
                                             OUString& aSuggestedName,
-                                            sal_Bool bPreselectPassword,
+                                            bool bPreselectPassword,
                                             OUString& aSuggestedDir,
                                             sal_Int16 nDialog,
                                             const OUString& rStandardDir,
                                             const ::com::sun::star::uno::Sequence< OUString >& rBlackList)
 {
-    sal_Bool bUseFilterOptions = sal_False;
+    bool bUseFilterOptions = false;
 
     ::comphelper::SequenceAsHashMap::const_iterator aOverwriteIter =
                 GetMediaDescr().find( OUString("Overwrite") );
@@ -889,7 +889,7 @@ sal_Bool ModelData_Impl::OutputFileDialog( sal_Int8 nStoreMode,
     // we need to show the file dialog
 
     // check if we have a filter which allows for filter options, so we need a corresponding checkbox in the dialog
-    sal_Bool bAllowOptions = sal_False;
+    bool bAllowOptions = false;
 
     // in case of Export, filter options dialog is used if available
     if( !( nStoreMode & EXPORT_REQUESTED ) || ( nStoreMode & WIDEEXPORT_REQUESTED ) )
@@ -1056,11 +1056,11 @@ sal_Bool ModelData_Impl::OutputFileDialog( sal_Int8 nStoreMode,
                          NULL );
 
     const SfxPoolItem* pItem = NULL;
-    if ( bPreselectPassword && aDialogParams.GetItemState( SID_ENCRYPTIONDATA, sal_True, &pItem ) != SFX_ITEM_SET )
+    if ( bPreselectPassword && aDialogParams.GetItemState( SID_ENCRYPTIONDATA, true, &pItem ) != SFX_ITEM_SET )
     {
         // the file dialog preselects the password checkbox if the provided mediadescriptor has encryption data entry
         // after dialog execution the password interaction flag will be either removed or not
-        aDialogParams.Put( SfxBoolItem( SID_PASSWORDINTERACTION, sal_True ) );
+        aDialogParams.Put( SfxBoolItem( SID_PASSWORDINTERACTION, true ) );
     }
 
     // aStringTypeFN is a pure output parameter, pDialogParams is an in/out parameter
@@ -1076,7 +1076,7 @@ sal_Bool ModelData_Impl::OutputFileDialog( sal_Int8 nStoreMode,
 
     // the following two arguments can not be converted in MediaDescriptor,
     // so they should be removed from the ItemSet after retrieving
-    SFX_ITEMSET_ARG( pDialogParams, pRecommendReadOnly, SfxBoolItem, SID_RECOMMENDREADONLY, sal_False );
+    SFX_ITEMSET_ARG( pDialogParams, pRecommendReadOnly, SfxBoolItem, SID_RECOMMENDREADONLY, false );
     m_bRecommendReadOnly = ( pRecommendReadOnly && pRecommendReadOnly->GetValue() );
     pDialogParams->ClearItem( SID_RECOMMENDREADONLY );
 
@@ -1146,7 +1146,7 @@ sal_Bool ModelData_Impl::OutputFileDialog( sal_Int8 nStoreMode,
     if ( xExtFileDlg.is() )
     {
         if ( SfxStoringHelper::CheckFilterOptionsAppearence( m_pOwner->GetFilterConfiguration(), aFilterName ) )
-            bUseFilterOptions = sal_True;
+            bUseFilterOptions = true;
 
         if ( ( !( nStoreMode & EXPORT_REQUESTED ) || ( nStoreMode & WIDEEXPORT_REQUESTED ) ) && bUseFilterOptions )
         {
@@ -1176,10 +1176,10 @@ sal_Bool ModelData_Impl::OutputFileDialog( sal_Int8 nStoreMode,
     return bUseFilterOptions;
 }
 
-//-------------------------------------------------------------------------
-sal_Bool ModelData_Impl::ShowDocumentInfoDialog()
+
+bool ModelData_Impl::ShowDocumentInfoDialog()
 {
-    sal_Bool bDialogUsed = sal_False;
+    bool bDialogUsed = false;
 
     try {
         uno::Reference< frame::XController > xController = GetModel()->getCurrentController();
@@ -1201,7 +1201,7 @@ sal_Bool ModelData_Impl::ShowDocumentInfoDialog()
                     if ( xDispatch.is() )
                     {
                         xDispatch->dispatch( aURL, uno::Sequence< beans::PropertyValue >() );
-                        bDialogUsed = sal_True;
+                        bDialogUsed = true;
                     }
                 }
             }
@@ -1214,7 +1214,7 @@ sal_Bool ModelData_Impl::ShowDocumentInfoDialog()
     return bDialogUsed;
 }
 
-//-------------------------------------------------------------------------
+
 OUString ModelData_Impl::GetRecommendedDir( const OUString& aSuggestedDir )
 {
     OUString aRecommendedDir;
@@ -1252,7 +1252,7 @@ OUString ModelData_Impl::GetRecommendedDir( const OUString& aSuggestedDir )
     return aRecommendedDir;
 }
 
-//-------------------------------------------------------------------------
+
 OUString ModelData_Impl::GetRecommendedName( const OUString& aSuggestedName, const OUString& aTypeName )
 {
     // the last used name might be provided by aSuggestedName from the old selection, or from the MediaDescriptor
@@ -1302,15 +1302,15 @@ OUString ModelData_Impl::GetRecommendedName( const OUString& aSuggestedName, con
 }
 
 
-//=========================================================================
+
 // class SfxStoringHelper
-//=========================================================================
-//-------------------------------------------------------------------------
+
+
 SfxStoringHelper::SfxStoringHelper()
 {
 }
 
-//-------------------------------------------------------------------------
+
 uno::Reference< container::XNameAccess > SfxStoringHelper::GetFilterConfiguration()
 {
     if ( !m_xFilterCFG.is() )
@@ -1326,7 +1326,7 @@ uno::Reference< container::XNameAccess > SfxStoringHelper::GetFilterConfiguratio
     return m_xFilterCFG;
 }
 
-//-------------------------------------------------------------------------
+
 uno::Reference< container::XContainerQuery > SfxStoringHelper::GetFilterQuery()
 {
     if ( !m_xFilterQuery.is() )
@@ -1339,7 +1339,7 @@ uno::Reference< container::XContainerQuery > SfxStoringHelper::GetFilterQuery()
     return m_xFilterQuery;
 }
 
-//-------------------------------------------------------------------------
+
 uno::Reference< ::com::sun::star::frame::XModuleManager2 > SfxStoringHelper::GetModuleManager()
 {
     if ( !m_xModuleManager.is() )
@@ -1351,21 +1351,22 @@ uno::Reference< ::com::sun::star::frame::XModuleManager2 > SfxStoringHelper::Get
     return m_xModuleManager;
 }
 
-//-------------------------------------------------------------------------
-sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel,
+
+bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel,
                                             const OUString& aSlotName,
                                             uno::Sequence< beans::PropertyValue >& aArgsSequence,
-                                            sal_Bool bPreselectPassword,
-                                            OUString aSuggestedName,
+                                            bool bPreselectPassword,
+                                            const OUString& _aSuggestedName,
                                             sal_uInt16 nDocumentSignatureState )
 {
+    OUString aSuggestedName = _aSuggestedName;
     ModelData_Impl aModelData( *this, xModel, aArgsSequence );
 
-    sal_Bool bDialogUsed = sal_False;
+    bool bDialogUsed = false;
 
     INetURLObject aURL;
 
-    sal_Bool bSetStandardName = sal_False; // can be set only for SaveAs
+    bool bSetStandardName = false; // can be set only for SaveAs
 
     // parse the slot name
     sal_Int8 nStoreMode = getStoreModeFromSlotName( aSlotName );
@@ -1375,7 +1376,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
                         aModelData.GetMediaDescr().find( ::rtl::OUString("SaveACopy") );
     if ( aSaveACopyIter != aModelData.GetMediaDescr().end() )
     {
-        sal_Bool bSaveACopy = sal_False;
+        bool bSaveACopy = false;
         aSaveACopyIter->second >>= bSaveACopy;
         if ( bSaveACopy )
             nStoreMode = EXPORT_REQUESTED | SAVEACOPY_REQUESTED | WIDEEXPORT_REQUESTED;
@@ -1387,7 +1388,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
                         aModelData.GetMediaDescr().find( OUString("SaveTo") );
         if ( aSaveToIter != aModelData.GetMediaDescr().end() )
         {
-            sal_Bool bWideExport = sal_False;
+            bool bWideExport = false;
             aSaveToIter->second >>= bWideExport;
             if ( bWideExport )
                 nStoreMode = EXPORT_REQUESTED | WIDEEXPORT_REQUESTED;
@@ -1425,7 +1426,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
             // this should be a usual SaveAs operation
             nStoreMode = SAVEAS_REQUESTED;
             if ( nStatusSave == STATUS_SAVEAS_STANDARDNAME )
-                bSetStandardName = sal_True;
+                bSetStandardName = true;
         }
     }
 
@@ -1471,7 +1472,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
             aModelData.GetStorable()->store();
         }
 
-        return sal_False;
+        return false;
     }
 
     // preselect a filter for the storing process
@@ -1497,7 +1498,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
                                                     sFilterNameString,
                                                     OUString() );
 
-    sal_Bool bUseFilterOptions = sal_False;
+    bool bUseFilterOptions = false;
     ::comphelper::SequenceAsHashMap::const_iterator aFileNameIter = aModelData.GetMediaDescr().find( OUString("URL") );
 
     const OUString sFilterOptionsString(aFilterOptionsString);
@@ -1514,7 +1515,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
         {
             // execute filter options dialog since no options are set in the media descriptor
             if ( aModelData.ExecuteFilterDialog_Impl( aFilterName ) )
-                bDialogUsed = sal_True;
+                bDialogUsed = true;
         }
     }
 
@@ -1525,7 +1526,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
             aModelData.GetMediaDescr().find( OUString("UseSystemDialog") );
         if ( aDlgIter != aModelData.GetMediaDescr().end() )
         {
-            sal_Bool bUseSystemDialog = sal_True;
+            bool bUseSystemDialog = true;
             if ( aDlgIter->second >>= bUseSystemDialog )
             {
                 if ( bUseSystemDialog )
@@ -1561,7 +1562,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
         if ( aBlackListIter != aModelData.GetMediaDescr().end() )
             aBlackListIter->second >>= aBlackList;
 
-        sal_Bool bExit = sal_False;
+        bool bExit = false;
         while ( !bExit )
         {
             // in case the dialog is opened a second time the folder should be the same as previously navigated to by the user, not what was handed over by initial parameters
@@ -1576,19 +1577,19 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
                 if ( nStatusFilterSave == STATUS_SAVEAS_STANDARDNAME )
                 {
                     // switch to best filter
-                    bSetStandardName = sal_True;
+                    bSetStandardName = true;
                 }
                 else if ( nStatusFilterSave == STATUS_SAVE )
                 {
                     // user confirmed alien filter or "good" filter is used
-                    bExit = sal_True;
+                    bExit = true;
                 }
             }
             else
-                bExit = sal_True;
+                bExit = true;
         }
 
-        bDialogUsed = sal_True;
+        bDialogUsed = true;
         aFileNameIter = aModelData.GetMediaDescr().find( OUString("URL") );
     }
     else
@@ -1629,7 +1630,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
     }
     else
     {
-        DBG_ASSERT( sal_False, "This code must be unreachable!\n" );
+        DBG_ASSERT( false, "This code must be unreachable!\n" );
         throw task::ErrorCodeIOException(
             "SfxStoringHelper::GUIStoreModel: ERRCODE_IO_INVALIDPARAMETER",
             uno::Reference< uno::XInterface >(), ERRCODE_IO_INVALIDPARAMETER);
@@ -1637,14 +1638,14 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
 
     ::comphelper::SequenceAsHashMap::const_iterator aIter =
                             aModelData.GetMediaDescr().find( OUString("FilterFlags") );
-    sal_Bool bFilterFlagsSet = ( aIter != aModelData.GetMediaDescr().end() );
+    bool bFilterFlagsSet = ( aIter != aModelData.GetMediaDescr().end() );
 
     if( !( nStoreMode & PDFEXPORT_REQUESTED ) && !bFilterFlagsSet
         && ( ( nStoreMode & EXPORT_REQUESTED ) || bUseFilterOptions ) )
     {
         // execute filter options dialog
         if ( aModelData.ExecuteFilterDialog_Impl( aFilterName ) )
-            bDialogUsed = sal_True;
+            bDialogUsed = true;
     }
 
     // so the arguments will not change any more and can be stored to the main location
@@ -1673,7 +1674,7 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
 
         // use dispatch API to show document info dialog
         if ( aModelData.ShowDocumentInfoDialog() )
-            bDialogUsed = sal_True;
+            bDialogUsed = true;
         else
         {
             OSL_FAIL( "Can't execute document info dialog!\n" );
@@ -1691,14 +1692,14 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
         {
             if ( nStoreMode & EXPORT_REQUESTED )
             {
-                SetDocInfoState(aModelData.GetModel(), xOldDocProps, sal_True);
+                SetDocInfoState(aModelData.GetModel(), xOldDocProps, true);
             }
             throw;
         }
 
         if ( nStoreMode & EXPORT_REQUESTED )
         {
-            SetDocInfoState(aModelData.GetModel(), xOldDocProps, sal_True);
+            SetDocInfoState(aModelData.GetModel(), xOldDocProps, true);
         }
     }
     else
@@ -1715,11 +1716,13 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
     }
 
     // Launch PDF viewer
-    if ( nStoreMode & PDFEXPORT_REQUESTED ) {
+    if ( nStoreMode & PDFEXPORT_REQUESTED )
+    {
         FilterConfigItem aItem( "Office.Common/Filter/PDF/Export/" );
-        sal_Bool aViewPDF = aItem.ReadBool( "ViewPDFAfterExport", sal_False );
+        bool aViewPDF = aItem.ReadBool( "ViewPDFAfterExport", false );
 
-        if ( aViewPDF==sal_True ) {
+        if ( aViewPDF )
+        {
             uno::Reference<XSystemShellExecute> xSystemShellExecute(SystemShellExecute::create( ::comphelper::getProcessComponentContext() ) );
             xSystemShellExecute->execute( aURL.GetMainURL( INetURLObject::NO_DECODE ), "", SystemShellExecuteFlags::URIS_ONLY );
         }
@@ -1728,13 +1731,13 @@ sal_Bool SfxStoringHelper::GUIStoreModel( uno::Reference< frame::XModel > xModel
     return bDialogUsed;
 }
 
-//-------------------------------------------------------------------------
+
 // static
-sal_Bool SfxStoringHelper::CheckFilterOptionsAppearence(
+bool SfxStoringHelper::CheckFilterOptionsAppearence(
                                                     const uno::Reference< container::XNameAccess >& xFilterCFG,
                                                     const OUString& aFilterName )
 {
-    sal_Bool bUseFilterOptions = sal_False;
+    bool bUseFilterOptions = false;
 
     DBG_ASSERT( xFilterCFG.is(), "No filter configuration!\n" );
     if( xFilterCFG.is() )
@@ -1749,7 +1752,7 @@ sal_Bool SfxStoringHelper::CheckFilterOptionsAppearence(
                                                     OUString("UIComponent"),
                                                     OUString() );
                 if( !aServiceName.isEmpty() )
-                       bUseFilterOptions = sal_True;
+                       bUseFilterOptions = true;
             }
         }
         catch( const uno::Exception& )
@@ -1760,12 +1763,12 @@ sal_Bool SfxStoringHelper::CheckFilterOptionsAppearence(
     return bUseFilterOptions;
 }
 
-//-------------------------------------------------------------------------
+
 // static
 void SfxStoringHelper::SetDocInfoState(
         const uno::Reference< frame::XModel >& xModel,
         const uno::Reference< document::XDocumentProperties>& i_xOldDocProps,
-        sal_Bool bNoModify )
+        bool bNoModify )
 {
     uno::Reference<document::XDocumentPropertiesSupplier> const
         xModelDocPropsSupplier(xModel, uno::UNO_QUERY_THROW);
@@ -1778,7 +1781,7 @@ void SfxStoringHelper::SetDocInfoState(
     if ( bNoModify && !xModifiable.is() )
         throw uno::RuntimeException();
 
-    sal_Bool bIsModified = bNoModify && xModifiable->isModified();
+    bool bIsModified = bNoModify && xModifiable->isModified();
 
     try
     {
@@ -1836,19 +1839,19 @@ void SfxStoringHelper::SetDocInfoState(
     }
 
     // set the modified flag back if required
-    if ( bNoModify && bIsModified != xModifiable->isModified() )
+    if ( ((bNoModify && bIsModified) ? 1 : 0) != xModifiable->isModified() )
         xModifiable->setModified( bIsModified );
 }
 
-//-------------------------------------------------------------------------
+
 // static
-sal_Bool SfxStoringHelper::WarnUnacceptableFormat( const uno::Reference< frame::XModel >& xModel,
-                                                    OUString aOldUIName,
-                                                    OUString /*aDefUIName*/,
-                                                    sal_Bool /*bCanProceedFurther*/ )
+bool SfxStoringHelper::WarnUnacceptableFormat( const uno::Reference< frame::XModel >& xModel,
+                                                    const OUString& aOldUIName,
+                                                    const OUString& /*aDefUIName*/,
+                                                    bool /*bCanProceedFurther*/ )
 {
     if ( !SvtSaveOptions().IsWarnAlienFormat() )
-        return sal_True;
+        return true;
 
     Window* pWin = SfxStoringHelper::GetModelWindow( xModel );
     SfxAlienWarningDialog aDlg( pWin, aOldUIName );
