@@ -110,67 +110,44 @@ using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::document;
 using namespace ::com::sun::star::task;
 
-//====================================================================
-
-class SfxSaveAsContext_Impl
-{
-    OUString&     _rNewNameVar;
-    OUString      _aNewName;
-
-public:
-                SfxSaveAsContext_Impl( OUString &rNewNameVar,
-                                       const OUString &rNewName )
-                :   _rNewNameVar( rNewNameVar ),
-                    _aNewName( rNewName )
-                { rNewNameVar = rNewName; }
-                ~SfxSaveAsContext_Impl()
-                { _rNewNameVar = ""; }
-};
-
-//====================================================================
-
 #define SfxObjectShell
 #include "sfxslots.hxx"
 
-//=========================================================================
+SFX_IMPL_INTERFACE(SfxObjectShell, SfxShell, SfxResId(0))
 
-
-
-SFX_IMPL_INTERFACE(SfxObjectShell,SfxShell,SfxResId(0))
+void SfxObjectShell::InitInterface_Impl()
 {
 }
 
-//=========================================================================
-
 class SfxClosePreventer_Impl : public ::cppu::WeakImplHelper1< ::com::sun::star::util::XCloseListener >
 {
-    sal_Bool m_bGotOwnership;
-    sal_Bool m_bPreventClose;
+    bool m_bGotOwnership;
+    bool m_bPreventClose;
 
 public:
     SfxClosePreventer_Impl();
 
-    sal_Bool HasOwnership() { return m_bGotOwnership; }
+    bool HasOwnership() { return m_bGotOwnership; }
 
-    void SetPreventClose( sal_Bool bPrevent ) { m_bPreventClose = bPrevent; }
+    void SetPreventClose( bool bPrevent ) { m_bPreventClose = bPrevent; }
 
     virtual void SAL_CALL queryClosing( const lang::EventObject& aEvent, sal_Bool bDeliverOwnership )
-        throw ( uno::RuntimeException, util::CloseVetoException );
+        throw ( uno::RuntimeException, util::CloseVetoException, std::exception ) SAL_OVERRIDE;
 
-    virtual void SAL_CALL notifyClosing( const lang::EventObject& aEvent ) throw ( uno::RuntimeException ) ;
+    virtual void SAL_CALL notifyClosing( const lang::EventObject& aEvent ) throw ( uno::RuntimeException, std::exception ) SAL_OVERRIDE ;
 
-    virtual void SAL_CALL disposing( const lang::EventObject& aEvent ) throw ( uno::RuntimeException ) ;
+    virtual void SAL_CALL disposing( const lang::EventObject& aEvent ) throw ( uno::RuntimeException, std::exception ) SAL_OVERRIDE ;
 
 } ;
 
 SfxClosePreventer_Impl::SfxClosePreventer_Impl()
-: m_bGotOwnership( sal_False )
-, m_bPreventClose( sal_True )
+: m_bGotOwnership( false )
+, m_bPreventClose( true )
 {
 }
 
 void SAL_CALL SfxClosePreventer_Impl::queryClosing( const lang::EventObject&, sal_Bool bDeliverOwnership )
-        throw ( uno::RuntimeException, util::CloseVetoException )
+        throw ( uno::RuntimeException, util::CloseVetoException, std::exception )
 {
     if ( m_bPreventClose )
     {
@@ -181,13 +158,13 @@ void SAL_CALL SfxClosePreventer_Impl::queryClosing( const lang::EventObject&, sa
     }
 }
 
-void SAL_CALL SfxClosePreventer_Impl::notifyClosing( const lang::EventObject& ) throw ( uno::RuntimeException )
+void SAL_CALL SfxClosePreventer_Impl::notifyClosing( const lang::EventObject& ) throw ( uno::RuntimeException, std::exception )
 {}
 
-void SAL_CALL SfxClosePreventer_Impl::disposing( const lang::EventObject& ) throw ( uno::RuntimeException )
+void SAL_CALL SfxClosePreventer_Impl::disposing( const lang::EventObject& ) throw ( uno::RuntimeException, std::exception )
 {}
 
-//=========================================================================
+
 class SfxInstanceCloseGuard_Impl
 {
     SfxClosePreventer_Impl* m_pPreventer;
@@ -201,12 +178,12 @@ public:
 
     ~SfxInstanceCloseGuard_Impl();
 
-    sal_Bool Init_Impl( const uno::Reference< util::XCloseable >& xCloseable );
+    bool Init_Impl( const uno::Reference< util::XCloseable >& xCloseable );
 };
 
-sal_Bool SfxInstanceCloseGuard_Impl::Init_Impl( const uno::Reference< util::XCloseable >& xCloseable )
+bool SfxInstanceCloseGuard_Impl::Init_Impl( const uno::Reference< util::XCloseable >& xCloseable )
 {
-    sal_Bool bResult = sal_False;
+    bool bResult = false;
 
     // do not allow reinit after the successful init
     if ( xCloseable.is() && !m_xCloseable.is() )
@@ -217,7 +194,7 @@ sal_Bool SfxInstanceCloseGuard_Impl::Init_Impl( const uno::Reference< util::XClo
             m_xPreventer = uno::Reference< util::XCloseListener >( m_pPreventer );
             xCloseable->addCloseListener( m_xPreventer );
             m_xCloseable = xCloseable;
-            bResult = sal_True;
+            bResult = true;
         }
         catch( uno::Exception& )
         {
@@ -244,7 +221,7 @@ SfxInstanceCloseGuard_Impl::~SfxInstanceCloseGuard_Impl()
         {
             if ( m_pPreventer )
             {
-                m_pPreventer->SetPreventClose( sal_False );
+                m_pPreventer->SetPreventClose( false );
 
                 if ( m_pPreventer->HasOwnership() )
                     m_xCloseable->close( sal_True ); // TODO: do it asynchronously
@@ -256,7 +233,7 @@ SfxInstanceCloseGuard_Impl::~SfxInstanceCloseGuard_Impl()
     }
 }
 
-//=========================================================================
+
 
 void SfxObjectShell::PrintExec_Impl(SfxRequest &rReq)
 {
@@ -268,7 +245,7 @@ void SfxObjectShell::PrintExec_Impl(SfxRequest &rReq)
     }
 }
 
-//--------------------------------------------------------------------
+
 
 void SfxObjectShell::PrintState_Impl(SfxItemSet &rSet)
 {
@@ -282,29 +259,28 @@ void SfxObjectShell::PrintState_Impl(SfxItemSet &rSet)
     rSet.Put( SfxBoolItem( SID_PRINTOUT, bPrinting ) );
 }
 
-//--------------------------------------------------------------------
 
-sal_Bool SfxObjectShell::APISaveAs_Impl
+
+bool SfxObjectShell::APISaveAs_Impl
 (
     const OUString& aFileName,
     SfxItemSet*   aParams
 )
 {
-    sal_Bool bOk = sal_False;
+    bool bOk = false;
 
-    {DBG_CHKTHIS(SfxObjectShell, 0);}
 
     if ( GetMedium() )
     {
         OUString aFilterName;
-        SFX_ITEMSET_ARG( aParams, pFilterNameItem, SfxStringItem, SID_FILTER_NAME, sal_False );
+        SFX_ITEMSET_ARG( aParams, pFilterNameItem, SfxStringItem, SID_FILTER_NAME, false );
         if( pFilterNameItem )
         {
             aFilterName = pFilterNameItem->GetValue();
         }
         else
         {
-            SFX_ITEMSET_ARG( aParams, pContentTypeItem, SfxStringItem, SID_CONTENTTYPE, sal_False );
+            SFX_ITEMSET_ARG( aParams, pContentTypeItem, SfxStringItem, SID_CONTENTTYPE, false );
             if ( pContentTypeItem )
             {
                 const SfxFilter* pFilter = SfxFilterMatcher( OUString::createFromAscii(GetFactory().GetShortName()) ).GetFilter4Mime( pContentTypeItem->GetValue(), SFX_FILTER_EXPORT );
@@ -330,7 +306,7 @@ sal_Bool SfxObjectShell::APISaveAs_Impl
             SfxObjectShellRef xLock( this ); // ???
 
             // use the title that is provided in the media descriptor
-            SFX_ITEMSET_ARG( aParams, pDocTitleItem, SfxStringItem, SID_DOCINFO_TITLE, sal_False );
+            SFX_ITEMSET_ARG( aParams, pDocTitleItem, SfxStringItem, SID_DOCINFO_TITLE, false );
             if ( pDocTitleItem )
                 getDocProperties()->setTitle( pDocTitleItem->GetValue() );
 
@@ -391,7 +367,7 @@ void SfxObjectShell::CheckIn( )
         if ( checkinDlg.Execute( ) == RET_OK )
         {
             OUString sComment = checkinDlg.GetComment( );
-            sal_Bool bMajor = checkinDlg.IsMajor( );
+            bool bMajor = checkinDlg.IsMajor( );
             xCmisDoc->checkIn( bMajor, sComment );
             uno::Reference< util::XModifiable > xModifiable( GetModel( ), uno::UNO_QUERY );
             if ( xModifiable.is( ) )
@@ -421,11 +397,10 @@ uno::Sequence< document::CmisVersion > SfxObjectShell::GetCmisVersions( )
     }
     return uno::Sequence< document::CmisVersion > ( );
 }
-//--------------------------------------------------------------------
+
 
 void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 {
-    {DBG_CHKTHIS(SfxObjectShell, 0);}
 
     sal_uInt16 nId = rReq.GetSlot();
 
@@ -445,7 +420,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
     // this guard is created here to have it destruction at the end of the method
     SfxInstanceCloseGuard_Impl aModelGuard;
 
-    sal_Bool bIsPDFExport = sal_False;
+    bool bIsPDFExport = false;
     switch(nId)
     {
         case SID_VERSION:
@@ -476,7 +451,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
         // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
         case SID_DOCINFO:
         {
-            SFX_REQUEST_ARG(rReq, pDocInfItem, SfxDocumentInfoItem, SID_DOCINFO, sal_False);
+            SFX_REQUEST_ARG(rReq, pDocInfItem, SfxDocumentInfoItem, SID_DOCINFO, false);
             if ( pDocInfItem )
             {
                 // parameter, e.g. from replayed macro
@@ -486,8 +461,8 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
             else
             {
                 // no argument containing DocInfo; check optional arguments
-                sal_Bool bReadOnly = IsReadOnly();
-                SFX_REQUEST_ARG(rReq, pROItem, SfxBoolItem, SID_DOC_READONLY, sal_False);
+                bool bReadOnly = IsReadOnly();
+                SFX_REQUEST_ARG(rReq, pROItem, SfxBoolItem, SID_DOC_READONLY, false);
                 if ( pROItem )
                     // override readonly attribute of document
                     // e.g. if a readonly document is saved elsewhere and user asks for editing DocInfo before
@@ -514,7 +489,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                     IsUseUserData() );
                 if ( !GetSlotState( SID_DOCTEMPLATE ) )
                     // templates not supported
-                    aDocInfoItem.SetTemplate(sal_False);
+                    aDocInfoItem.SetTemplate(false);
 
                 SfxItemSet aSet(GetPool(), SID_DOCINFO, SID_DOCINFO, SID_DOC_READONLY, SID_DOC_READONLY,
                                 SID_EXPLORER_PROPS_START, SID_EXPLORER_PROPS_START, SID_BASEURL, SID_BASEURL,
@@ -529,7 +504,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                 SfxDocumentInfoDialog *pDlg = CreateDocumentInfoDialog(0, aSet);
                 if ( RET_OK == pDlg->Execute() )
                 {
-                    SFX_ITEMSET_ARG( pDlg->GetOutputItemSet(), pDocInfoItem, SfxDocumentInfoItem, SID_DOCINFO, sal_False);
+                    SFX_ITEMSET_ARG( pDlg->GetOutputItemSet(), pDocInfoItem, SfxDocumentInfoItem, SID_DOCINFO, false);
                     if ( pDocInfoItem )
                     {
                         // user has done some changes to DocumentInfo
@@ -560,7 +535,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 
         case SID_EXPORTDOCASPDF:
         case SID_DIRECTEXPORTDOCASPDF:
-            bIsPDFExport = sal_True;
+            bIsPDFExport = true;
         case SID_EXPORTDOC:
         case SID_SAVEASDOC:
         case SID_SAVEDOC:
@@ -568,7 +543,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
             // derived class may decide to abort this
             if( !QuerySlotExecutable( nId ) )
             {
-                rReq.SetReturnValue( SfxBoolItem( 0, sal_False ) );
+                rReq.SetReturnValue( SfxBoolItem( 0, false ) );
                 return;
             }
 
@@ -592,15 +567,15 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                 if ( nId == SID_SAVEASDOC )
                 {
                     // in case of plugin mode the SaveAs operation means SaveTo
-                    SFX_ITEMSET_ARG( GetMedium()->GetItemSet(), pViewOnlyItem, SfxBoolItem, SID_VIEWONLY, sal_False );
+                    SFX_ITEMSET_ARG( GetMedium()->GetItemSet(), pViewOnlyItem, SfxBoolItem, SID_VIEWONLY, false );
                     if ( pViewOnlyItem && pViewOnlyItem->GetValue() )
-                        rReq.AppendItem( SfxBoolItem( SID_SAVETO, sal_True ) );
+                        rReq.AppendItem( SfxBoolItem( SID_SAVETO, true ) );
                 }
 
                 // TODO/LATER: do the following GUI related actions in standalown method
-                // ========================================================================================================
+
                 // Introduce a status indicator for GUI operation
-                SFX_REQUEST_ARG( rReq, pStatusIndicatorItem, SfxUnoAnyItem, SID_PROGRESS_STATUSBAR_CONTROL, sal_False );
+                SFX_REQUEST_ARG( rReq, pStatusIndicatorItem, SfxUnoAnyItem, SID_PROGRESS_STATUSBAR_CONTROL, false );
                 if ( !pStatusIndicatorItem )
                 {
                     // get statusindicator
@@ -637,7 +612,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                 }
 
                 // Introduce an interaction handler for GUI operation
-                SFX_REQUEST_ARG( rReq, pInteractionHandlerItem, SfxUnoAnyItem, SID_INTERACTIONHANDLER, sal_False );
+                SFX_REQUEST_ARG( rReq, pInteractionHandlerItem, SfxUnoAnyItem, SID_INTERACTIONHANDLER, false );
                 if ( !pInteractionHandlerItem )
                 {
                     uno::Reference< uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
@@ -660,13 +635,13 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                     // but it is not clear here whether the saving will be done or saveAs operation
                     GetMedium()->GetItemSet()->Put( *pInteractionHandlerItem );
                 }
-                // ========================================================================================================
 
-                sal_Bool bPreselectPassword = sal_False;
-                SFX_ITEMSET_ARG( GetMedium()->GetItemSet(), pOldEncryptionDataItem, SfxUnoAnyItem, SID_ENCRYPTIONDATA, sal_False );
-                SFX_ITEMSET_ARG( GetMedium()->GetItemSet(), pOldPasswordItem, SfxStringItem, SID_PASSWORD, sal_False );
+
+                bool bPreselectPassword = false;
+                SFX_ITEMSET_ARG( GetMedium()->GetItemSet(), pOldEncryptionDataItem, SfxUnoAnyItem, SID_ENCRYPTIONDATA, false );
+                SFX_ITEMSET_ARG( GetMedium()->GetItemSet(), pOldPasswordItem, SfxStringItem, SID_PASSWORD, false );
                 if ( pOldEncryptionDataItem || pOldPasswordItem )
-                    bPreselectPassword = sal_True;
+                    bPreselectPassword = true;
 
                 uno::Sequence< beans::PropertyValue > aDispatchArgs;
                 if ( rReq.GetArgs() )
@@ -708,7 +683,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 
                 // the StoreAsURL/StoreToURL method have called this method with false
                 // so it has to be restored to true here since it is a call from GUI
-                GetMedium()->SetUpdatePickList( sal_True );
+                GetMedium()->SetUpdatePickList( true );
 
                 // TODO: in future it must be done in followind way
                 // if document is opened from GUI it is immediatelly appears in the picklist
@@ -726,7 +701,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 
             // by default versions should be preserved always except in case of an explicit
             // SaveAs via GUI, so the flag must be reset to guarantee this
-            pImp->bPreserveVersions = sal_True;
+            pImp->bPreserveVersions = true;
             sal_uIntPtr lErr=GetErrorCode();
 
             if ( !lErr && nErrorCode )
@@ -734,7 +709,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 
             if ( lErr && nErrorCode == ERRCODE_NONE )
             {
-                SFX_REQUEST_ARG( rReq, pWarnItem, SfxBoolItem, SID_FAIL_ON_WARNING, sal_False );
+                SFX_REQUEST_ARG( rReq, pWarnItem, SfxBoolItem, SID_FAIL_ON_WARNING, false );
                 if ( pWarnItem && pWarnItem->GetValue() )
                     nErrorCode = lErr;
             }
@@ -770,7 +745,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
         case SID_SAVEACOPY:
         {
             SfxAllItemSet aArgs( GetPool() );
-            aArgs.Put( SfxBoolItem( SID_SAVEACOPYITEM, sal_True ) );
+            aArgs.Put( SfxBoolItem( SID_SAVEACOPYITEM, true ) );
             SfxRequest aSaveACopyReq( SID_EXPORTDOC, SFX_CALLMODE_API, aArgs );
             ExecFile_Impl( aSaveACopyReq );
             if ( !aSaveACopyReq.IsDone() )
@@ -796,7 +771,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                 return;
             }
 
-            sal_Bool bInFrameSet = sal_False;
+            bool bInFrameSet = false;
             sal_uInt16 nFrames=0;
             pFrame = SfxViewFrame::GetFirst( this );
             while ( pFrame )
@@ -806,7 +781,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                     // In this document there still exists a view that is
                     // in a FrameSet , which of course may not be closed
                     // geclosed werden
-                    bInFrameSet = sal_True;
+                    bInFrameSet = true;
                 }
                 else
                     nFrames++;
@@ -827,8 +802,8 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
             }
 
             // Evaluate Parameter
-            SFX_REQUEST_ARG(rReq, pSaveItem, SfxBoolItem, SID_CLOSEDOC_SAVE, sal_False);
-            SFX_REQUEST_ARG(rReq, pNameItem, SfxStringItem, SID_CLOSEDOC_FILENAME, sal_False);
+            SFX_REQUEST_ARG(rReq, pSaveItem, SfxBoolItem, SID_CLOSEDOC_SAVE, false);
+            SFX_REQUEST_ARG(rReq, pNameItem, SfxStringItem, SID_CLOSEDOC_FILENAME, false);
             if ( pSaveItem )
             {
                 if ( pSaveItem->GetValue() )
@@ -853,22 +828,22 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
                     }
                 }
                 else
-                    SetModified(sal_False);
+                    SetModified(false);
             }
 
             // Cancelled by the user?
-            if ( !PrepareClose( 2 ) )
+            if (!PrepareClose(true))
             {
-                rReq.SetReturnValue( SfxBoolItem(0, sal_False) );
+                rReq.SetReturnValue( SfxBoolItem(0, false) );
                 rReq.Done();
                 return;
             }
 
-            SetModified( sal_False );
+            SetModified( false );
             sal_uIntPtr lErr = GetErrorCode();
             ErrorHandler::HandleError(lErr);
 
-            rReq.SetReturnValue( SfxBoolItem(0, sal_True) );
+            rReq.SetReturnValue( SfxBoolItem(0, true) );
             rReq.Done();
             rReq.ReleaseArgs(); // because the pool is destroyed in Close
             DoClose();
@@ -881,7 +856,7 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
             // save as document templates
             SfxTemplateManagerDlg aDlg;
             aDlg.setDocumentModel(GetModel());
-            aDlg.setSaveMode(true);
+            aDlg.setSaveMode();
             aDlg.Execute();
 
             break;
@@ -914,10 +889,10 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
 
     // Prevent entry in the Pick-lists
     if ( rReq.IsAPI() )
-        GetMedium()->SetUpdatePickList( sal_False );
+        GetMedium()->SetUpdatePickList( false );
     else if ( rReq.GetArgs() )
     {
-        SFX_ITEMSET_GET( *rReq.GetArgs(), pPicklistItem, SfxBoolItem, SID_PICKLIST, sal_False );
+        SFX_ITEMSET_GET( *rReq.GetArgs(), pPicklistItem, SfxBoolItem, SID_PICKLIST, false );
         if ( pPicklistItem )
             GetMedium()->SetUpdatePickList( pPicklistItem->GetValue() );
     }
@@ -926,11 +901,10 @@ void SfxObjectShell::ExecFile_Impl(SfxRequest &rReq)
     rReq.Done();
 }
 
-//-------------------------------------------------------------------------
+
 
 void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
 {
-    DBG_CHKTHIS(SfxObjectShell, 0);
     SfxWhichIter aIter( rSet );
 
     for ( sal_uInt16 nWhich = aIter.FirstWhich(); nWhich; nWhich = aIter.NextWhich() )
@@ -954,7 +928,7 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
                     {
                         // Loop over the CMIS Properties to find cmis:isVersionSeriesCheckedOut
                         bool bIsGoogleFile = false;
-                        sal_Bool bCheckedOut = sal_False;
+                        bool bCheckedOut = false;
                         for ( sal_Int32 i = 0; i < aCmisProperties.getLength(); ++i )
                         {
                             if ( aCmisProperties[i].Id == "cmis:isVersionSeriesCheckedOut" )
@@ -974,7 +948,7 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
                     if ( !bShow )
                     {
                         rSet.DisableItem( nWhich );
-                        rSet.Put( SfxVisibilityItem( nWhich, sal_False ) );
+                        rSet.Put( SfxVisibilityItem( nWhich, false ) );
                     }
                 }
                 break;
@@ -990,7 +964,7 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
                     {
                         // Loop over the CMIS Properties to find cmis:isVersionSeriesCheckedOut
                         bool bFoundCheckedout = false;
-                        sal_Bool bCheckedOut = sal_False;
+                        bool bCheckedOut = false;
                         for ( sal_Int32 i = 0; i < aCmisProperties.getLength() && !bFoundCheckedout; ++i )
                         {
                             if ( aCmisProperties[i].Id == "cmis:isVersionSeriesCheckedOut" )
@@ -1007,7 +981,7 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
                     if ( !bShow )
                     {
                         rSet.DisableItem( nWhich );
-                        rSet.Put( SfxVisibilityItem( nWhich, sal_False ) );
+                        rSet.Put( SfxVisibilityItem( nWhich, false ) );
                     }
                 }
                 break;
@@ -1148,7 +1122,7 @@ void SfxObjectShell::GetState_Impl(SfxItemSet &rSet)
     }
 }
 
-//--------------------------------------------------------------------
+
 
 void SfxObjectShell::ExecProps_Impl(SfxRequest &rReq)
 {
@@ -1190,7 +1164,7 @@ void SfxObjectShell::ExecProps_Impl(SfxRequest &rReq)
     }
 }
 
-//--------------------------------------------------------------------
+
 
 void SfxObjectShell::StateProps_Impl(SfxItemSet &rSet)
 {
@@ -1269,7 +1243,7 @@ void SfxObjectShell::StateProps_Impl(SfxItemSet &rSet)
     }
 }
 
-//--------------------------------------------------------------------
+
 
 void SfxObjectShell::ExecView_Impl(SfxRequest &rReq)
 {
@@ -1277,7 +1251,7 @@ void SfxObjectShell::ExecView_Impl(SfxRequest &rReq)
     {
         case SID_ACTIVATE:
         {
-            SfxViewFrame *pFrame = SfxViewFrame::GetFirst( this, sal_True );
+            SfxViewFrame *pFrame = SfxViewFrame::GetFirst( this, true );
             if ( pFrame )
                 pFrame->GetFrame().Appear();
             rReq.SetReturnValue( SfxObjectItem( 0, pFrame ) );
@@ -1296,7 +1270,7 @@ void SfxObjectShell::ExecView_Impl(SfxRequest &rReq)
                 if ( !aFileName.isEmpty() )
                 {
                     SfxStringItem aName( SID_FILE_NAME, aFileName );
-                    SfxBoolItem aCreateView( SID_OPEN_NEW_VIEW, sal_True );
+                    SfxBoolItem aCreateView( SID_OPEN_NEW_VIEW, true );
                     SFX_APP()->GetAppDispatcher_Impl()->Execute(
                         SID_OPENDOC, SFX_CALLMODE_ASYNCHRON, &aName,
                         &aCreateView, 0L);
@@ -1306,7 +1280,7 @@ void SfxObjectShell::ExecView_Impl(SfxRequest &rReq)
     }
 }
 
-//--------------------------------------------------------------------
+
 
 void SfxObjectShell::StateView_Impl(SfxItemSet& /*rSet*/)
 {
@@ -1314,7 +1288,7 @@ void SfxObjectShell::StateView_Impl(SfxItemSet& /*rSet*/)
 
 sal_uInt16 SfxObjectShell::ImplCheckSignaturesInformation( const uno::Sequence< security::DocumentSignatureInformation >& aInfos )
 {
-    sal_Bool bCertValid = sal_True;
+    bool bCertValid = true;
     sal_uInt16 nResult = SIGNATURESTATE_NOSIGNATURES;
     int nInfos = aInfos.getLength();
     bool bCompleteSignature = true;
@@ -1349,7 +1323,7 @@ sal_uInt16 SfxObjectShell::ImplCheckSignaturesInformation( const uno::Sequence<
     return nResult;
 }
 
-uno::Sequence< security::DocumentSignatureInformation > SfxObjectShell::ImplAnalyzeSignature( sal_Bool bScriptingContent, const uno::Reference< security::XDocumentDigitalSignatures >& xSigner )
+uno::Sequence< security::DocumentSignatureInformation > SfxObjectShell::ImplAnalyzeSignature( bool bScriptingContent, const uno::Reference< security::XDocumentDigitalSignatures >& xSigner )
 {
     uno::Sequence< security::DocumentSignatureInformation > aResult;
     uno::Reference< security::XDocumentDigitalSignatures > xLocSigner = xSigner;
@@ -1389,7 +1363,7 @@ uno::Sequence< security::DocumentSignatureInformation > SfxObjectShell::ImplAnal
     return aResult;
 }
 
-sal_uInt16 SfxObjectShell::ImplGetSignatureState( sal_Bool bScriptingContent )
+sal_uInt16 SfxObjectShell::ImplGetSignatureState( bool bScriptingContent )
 {
     sal_Int16* pState = bScriptingContent ? &pImp->nScriptingSignatureState : &pImp->nDocumentSignatureState;
 
@@ -1411,7 +1385,7 @@ sal_uInt16 SfxObjectShell::ImplGetSignatureState( sal_Bool bScriptingContent )
     return (sal_uInt16)*pState;
 }
 
-void SfxObjectShell::ImplSign( sal_Bool bScriptingContent )
+void SfxObjectShell::ImplSign( bool bScriptingContent )
 {
     // Check if it is stored in OASIS format...
     if  (   GetMedium()
@@ -1428,9 +1402,9 @@ void SfxObjectShell::ImplSign( sal_Bool bScriptingContent )
     }
 
     // check whether the document is signed
-    ImplGetSignatureState( sal_False ); // document signature
-    ImplGetSignatureState( sal_True ); // script signature
-    sal_Bool bHasSign = ( pImp->nScriptingSignatureState != SIGNATURESTATE_NOSIGNATURES || pImp->nDocumentSignatureState != SIGNATURESTATE_NOSIGNATURES );
+    ImplGetSignatureState( false ); // document signature
+    ImplGetSignatureState( true ); // script signature
+    bool bHasSign = ( pImp->nScriptingSignatureState != SIGNATURESTATE_NOSIGNATURES || pImp->nDocumentSignatureState != SIGNATURESTATE_NOSIGNATURES );
 
     // the target ODF version on saving
     SvtSaveOptions aSaveOpt;
@@ -1465,7 +1439,7 @@ void SfxObjectShell::ImplSign( sal_Bool bScriptingContent )
                     nId = SID_SAVEASDOC;
                 SfxRequest aSaveRequest( nId, 0, GetPool() );
                 //ToDo: Review. We needed to call SetModified, otherwise the document would not be saved.
-                SetModified(sal_True);
+                SetModified(true);
                 ExecFile_Impl( aSaveRequest );
 
                 // Check if it is stored in OASIS format...
@@ -1498,11 +1472,11 @@ void SfxObjectShell::ImplSign( sal_Bool bScriptingContent )
     }
 
     // the document is not modified currently, so it can not become modified after signing
-    sal_Bool bAllowModifiedBack = sal_False;
+    bool bAllowModifiedBack = false;
     if ( IsEnableSetModified() )
     {
-        EnableSetModified( sal_False );
-        bAllowModifiedBack = sal_True;
+        EnableSetModified( false );
+        bAllowModifiedBack = true;
     }
 
     // we have to store to the original document, the original medium should be closed for this time
@@ -1514,7 +1488,7 @@ void SfxObjectShell::ImplSign( sal_Bool bScriptingContent )
         // We sign only ODF1.2, that means that if this point has been reached,
         // the ODF1.2 signing process should be used.
         // This code still might be called to show the signature of ODF1.1 document.
-        sal_Bool bSigned = GetMedium()->SignContents_Impl(
+        bool bSigned = GetMedium()->SignContents_Impl(
             bScriptingContent,
             aODFVersion,
             pImp->nDocumentSignatureState == SIGNATURESTATE_SIGNATURES_OK
@@ -1535,7 +1509,7 @@ void SfxObjectShell::ImplSign( sal_Bool bScriptingContent )
             else
                 pImp->nDocumentSignatureState = SIGNATURESTATE_UNKNOWN;// Re-Check
 
-            pImp->bSignatureErrorIsShown = sal_False;
+            pImp->bSignatureErrorIsShown = false;
 
             Invalidate( SID_SIGNATURE );
             Invalidate( SID_MACRO_SIGNATURE );
@@ -1544,27 +1518,27 @@ void SfxObjectShell::ImplSign( sal_Bool bScriptingContent )
     }
 
     if ( bAllowModifiedBack )
-        EnableSetModified( sal_True );
+        EnableSetModified( true );
 }
 
 sal_uInt16 SfxObjectShell::GetDocumentSignatureState()
 {
-    return ImplGetSignatureState( sal_False );
+    return ImplGetSignatureState( false );
 }
 
 void SfxObjectShell::SignDocumentContent()
 {
-    ImplSign( sal_False );
+    ImplSign( false );
 }
 
 sal_uInt16 SfxObjectShell::GetScriptingSignatureState()
 {
-    return ImplGetSignatureState( sal_True );
+    return ImplGetSignatureState( true );
 }
 
 void SfxObjectShell::SignScriptingContent()
 {
-    ImplSign( sal_True );
+    ImplSign( true );
 }
 
 namespace
