@@ -63,12 +63,10 @@
 #include <vcl/outdev.hxx>
 #include <osl/mutex.hxx>
 
-#include <memory>
 
-//........................................................................
 namespace svx
 {
-//........................................................................
+
 
     using namespace ::com::sun::star;
     using namespace ::com::sun::star::uno;
@@ -81,10 +79,10 @@ namespace svx
     using namespace ::com::sun::star::beans;
     using namespace ::com::sun::star::container;
 
-    //====================================================================
+
     typedef sal_uInt16 WhichId;
 
-    //====================================================================
+
     static SfxSlotId pTextControlSlots[] =
     {
         SID_CLIPBOARD_FORMAT_ITEMS,
@@ -160,9 +158,9 @@ namespace svx
         0
     };
 
-    //====================================================================
+
     //= FmFocusListenerAdapter
-    //====================================================================
+
     typedef ::cppu::WeakImplHelper1 <   XFocusListener
                                     >   FmFocusListenerAdapter_Base;
     class FmFocusListenerAdapter : public FmFocusListenerAdapter_Base
@@ -178,22 +176,20 @@ namespace svx
         void    dispose();
 
     protected:
-        ~FmFocusListenerAdapter();
+        virtual ~FmFocusListenerAdapter();
 
     protected:
-        virtual void SAL_CALL focusGained( const FocusEvent& e ) throw (RuntimeException);
-        virtual void SAL_CALL focusLost( const FocusEvent& e ) throw (RuntimeException);
-        virtual void SAL_CALL disposing( const EventObject& Source ) throw (RuntimeException);
+        virtual void SAL_CALL focusGained( const FocusEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL focusLost( const FocusEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL disposing( const EventObject& Source ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
     };
 
-    //--------------------------------------------------------------------
-    DBG_NAME( FmFocusListenerAdapter )
-    //--------------------------------------------------------------------
+
+
     FmFocusListenerAdapter::FmFocusListenerAdapter( const Reference< XControl >& _rxControl, IFocusObserver* _pObserver )
         :m_pObserver( _pObserver )
         ,m_xWindow( _rxControl, UNO_QUERY )
     {
-        DBG_CTOR( FmFocusListenerAdapter, NULL );
 
         DBG_ASSERT( m_xWindow.is(), "FmFocusListenerAdapter::FmFocusListenerAdapter: invalid control!" );
         osl_atomic_increment( &m_refCount );
@@ -211,16 +207,15 @@ namespace svx
         osl_atomic_decrement( &m_refCount );
     }
 
-    //--------------------------------------------------------------------
+
     FmFocusListenerAdapter::~FmFocusListenerAdapter()
     {
         acquire();
         dispose();
 
-        DBG_DTOR( FmFocusListenerAdapter, NULL );
     }
 
-    //--------------------------------------------------------------------
+
     void FmFocusListenerAdapter::dispose()
     {
         if ( m_xWindow.is() )
@@ -230,31 +225,31 @@ namespace svx
         }
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmFocusListenerAdapter::focusGained( const FocusEvent& e ) throw (RuntimeException)
+
+    void SAL_CALL FmFocusListenerAdapter::focusGained( const FocusEvent& e ) throw (RuntimeException, std::exception)
     {
         if ( m_pObserver )
             m_pObserver->focusGained( e );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmFocusListenerAdapter::focusLost( const FocusEvent& e ) throw (RuntimeException)
+
+    void SAL_CALL FmFocusListenerAdapter::focusLost( const FocusEvent& e ) throw (RuntimeException, std::exception)
     {
         if ( m_pObserver )
             m_pObserver->focusLost( e );
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmFocusListenerAdapter::disposing( const EventObject& Source ) throw (RuntimeException)
+
+    void SAL_CALL FmFocusListenerAdapter::disposing( const EventObject& Source ) throw (RuntimeException, std::exception)
     {
         (void)Source;
         DBG_ASSERT( Source.Source == m_xWindow, "FmFocusListenerAdapter::disposing: where did this come from?" );
         m_xWindow.clear();
     }
 
-    //====================================================================
+
     //= FmMouseListenerAdapter
-    //====================================================================
+
     typedef ::cppu::WeakImplHelper1 <   XMouseListener
                                     >   FmMouseListenerAdapter_Base;
     class FmMouseListenerAdapter : public FmMouseListenerAdapter_Base
@@ -270,27 +265,25 @@ namespace svx
         void    dispose();
 
     protected:
-        ~FmMouseListenerAdapter();
+        virtual ~FmMouseListenerAdapter();
 
     protected:
-        virtual void SAL_CALL mousePressed( const awt::MouseEvent& e ) throw (RuntimeException);
-        virtual void SAL_CALL mouseReleased( const awt::MouseEvent& e ) throw (RuntimeException);
-        virtual void SAL_CALL mouseEntered( const awt::MouseEvent& e ) throw (RuntimeException);
-        virtual void SAL_CALL mouseExited( const awt::MouseEvent& e ) throw (RuntimeException);
-        virtual void SAL_CALL disposing( const EventObject& Source ) throw (RuntimeException);
+        virtual void SAL_CALL mousePressed( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL mouseReleased( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL mouseEntered( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL mouseExited( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL disposing( const EventObject& Source ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
     };
 
-    //====================================================================
+
     //= FmMouseListenerAdapter
-    //====================================================================
-    //--------------------------------------------------------------------
-    DBG_NAME( FmMouseListenerAdapter )
-    //--------------------------------------------------------------------
+
+
+
     FmMouseListenerAdapter::FmMouseListenerAdapter( const Reference< XControl >& _rxControl, IContextRequestObserver* _pObserver )
         :m_pObserver( _pObserver )
         ,m_xWindow( _rxControl, UNO_QUERY )
     {
-        DBG_CTOR( FmMouseListenerAdapter, NULL );
 
         DBG_ASSERT( m_xWindow.is(), "FmMouseListenerAdapter::FmMouseListenerAdapter: invalid control!" );
         osl_atomic_increment( &m_refCount );
@@ -308,16 +301,15 @@ namespace svx
         osl_atomic_decrement( &m_refCount );
     }
 
-    //--------------------------------------------------------------------
+
     FmMouseListenerAdapter::~FmMouseListenerAdapter()
     {
         acquire();
         dispose();
 
-        DBG_DTOR( FmMouseListenerAdapter, NULL );
     }
 
-    //--------------------------------------------------------------------
+
     void FmMouseListenerAdapter::dispose()
     {
         if ( m_xWindow.is() )
@@ -327,8 +319,8 @@ namespace svx
         }
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmMouseListenerAdapter::mousePressed( const awt::MouseEvent& _rEvent ) throw (::com::sun::star::uno::RuntimeException)
+
+    void SAL_CALL FmMouseListenerAdapter::mousePressed( const awt::MouseEvent& _rEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception)
     {
         SolarMutexGuard aGuard;
         // is this a request for a context menu?
@@ -339,39 +331,39 @@ namespace svx
         }
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmMouseListenerAdapter::mouseReleased( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException)
+
+    void SAL_CALL FmMouseListenerAdapter::mouseReleased( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
     {
         // not interested in
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmMouseListenerAdapter::mouseEntered( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException)
+
+    void SAL_CALL FmMouseListenerAdapter::mouseEntered( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
     {
         // not interested in
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmMouseListenerAdapter::mouseExited( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException)
+
+    void SAL_CALL FmMouseListenerAdapter::mouseExited( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
     {
         // not interested in
     }
 
-    //--------------------------------------------------------------------
-    void SAL_CALL FmMouseListenerAdapter::disposing( const EventObject& Source ) throw (RuntimeException)
+
+    void SAL_CALL FmMouseListenerAdapter::disposing( const EventObject& Source ) throw (RuntimeException, std::exception)
     {
         (void)Source;
         DBG_ASSERT( Source.Source == m_xWindow, "FmMouseListenerAdapter::disposing: where did this come from?" );
         m_xWindow.clear();
     }
 
-    //====================================================================
+
     //= FmTextControlShell
-    //====================================================================
-    //------------------------------------------------------------------------
+
+
     namespace
     {
-        //....................................................................
+
         void lcl_translateUnoStateToItem( SfxSlotId _nSlot, const Any& _rUnoState, SfxItemSet& _rSet )
         {
             WhichId nWhich = _rSet.GetPool()->GetWhich( _nSlot );
@@ -391,7 +383,7 @@ namespace svx
                 {
                 case TypeClass_BOOLEAN:
                 {
-                    sal_Bool bState = sal_False;
+                    bool bState = false;
                     _rUnoState >>= bState;
                     if ( _nSlot == SID_ATTR_PARA_SCRIPTSPACE )
                         _rSet.Put( SvxScriptSpaceItem( bState, nWhich ) );
@@ -428,7 +420,7 @@ namespace svx
             }
         }
 
-        //....................................................................
+
         OUString lcl_getUnoSlotName( SfxApplication&, SfxSlotId _nSlotId )
         {
             OUString sSlotUnoName;
@@ -471,7 +463,7 @@ namespace svx
             return sSlotUnoName;
         }
 
-        //....................................................................
+
         bool lcl_determineReadOnly( const Reference< XControl >& _rxControl )
         {
             bool bIsReadOnlyModel = true;
@@ -488,7 +480,7 @@ namespace svx
                     bIsReadOnlyModel = true;
                 else
                 {
-                    sal_Bool bReadOnly = sal_True;
+                    bool bReadOnly = true;
                     xModelProps->getPropertyValue( FM_PROP_READONLY ) >>= bReadOnly;
                     bIsReadOnlyModel = bReadOnly;
                 }
@@ -500,7 +492,7 @@ namespace svx
             return bIsReadOnlyModel;
         }
 
-        //....................................................................
+
         static Window* lcl_getWindow( const Reference< XControl >& _rxControl )
         {
             Window* pWindow = NULL;
@@ -520,7 +512,7 @@ namespace svx
             return pWindow;
         }
 
-        //....................................................................
+
         bool lcl_isRichText( const Reference< XControl >& _rxControl )
         {
             if ( !_rxControl.is() )
@@ -547,7 +539,7 @@ namespace svx
         }
     }
 
-    //------------------------------------------------------------------------
+
     FmTextControlShell::FmTextControlShell( SfxViewFrame* _pFrame )
         :m_bActiveControl( false )
         ,m_bActiveControlIsReadOnly( true )
@@ -560,13 +552,13 @@ namespace svx
         m_aClipboardInvalidation.SetTimeout( 200 );
     }
 
-    //------------------------------------------------------------------------
+
     FmTextControlShell::~FmTextControlShell()
     {
         dispose();
     }
 
-    //------------------------------------------------------------------------
+
     IMPL_LINK( FmTextControlShell, OnInvalidateClipboard, void*, /*_pNotInterestedIn*/ )
     {
         if ( m_bNeedClipboardInvalidation )
@@ -580,7 +572,7 @@ namespace svx
         return 0L;
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::transferFeatureStatesToItemSet( ControlFeatures& _rDispatchers, SfxAllItemSet& _rSet, bool _bTranslateLatin )
     {
         SfxItemPool& rPool = *_rSet.GetPool();
@@ -652,7 +644,7 @@ namespace svx
         }
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::executeAttributeDialog( AttributeSet _eSet, SfxRequest& _rReq )
     {
         const SvxFontListItem* pFontList = PTR_CAST( SvxFontListItem, m_pViewFrame->GetObjectShell()->GetItem( SID_ATTR_CHAR_FONTLIST ) );
@@ -662,24 +654,24 @@ namespace svx
 
         SfxItemPool* pPool = EditEngine::CreatePool();
         pPool->FreezeIdRanges();
-        ::std::auto_ptr< SfxItemSet > pPureItems( new SfxItemSet( *pPool ) );
+        boost::scoped_ptr< SfxItemSet > xPureItems( new SfxItemSet( *pPool ) );
 
         // put the current states of the items into the set
-        ::std::auto_ptr< SfxAllItemSet > pCurrentItems( new SfxAllItemSet( *pPureItems ) );
-        transferFeatureStatesToItemSet( m_aControlFeatures, *pCurrentItems );
+        boost::scoped_ptr<SfxAllItemSet> xCurrentItems( new SfxAllItemSet( *xPureItems ) );
+        transferFeatureStatesToItemSet( m_aControlFeatures, *xCurrentItems );
 
         // additional items, which we are not responsible for at the SfxShell level,
         // but which need to be forwarded to the dialog, anyway
         ControlFeatures aAdditionalFestures;
         fillFeatureDispatchers( m_xActiveControl, pDialogSlots, aAdditionalFestures );
-        transferFeatureStatesToItemSet( aAdditionalFestures, *pCurrentItems, true );
+        transferFeatureStatesToItemSet( aAdditionalFestures, *xCurrentItems, true );
 
-        ::std::auto_ptr< SfxTabDialog > pDialog ( _eSet == eCharAttribs
-                                                ? static_cast< SfxTabDialog* >( new TextControlCharAttribDialog( NULL, *pCurrentItems, *pFontList ) )
-                                                : static_cast< SfxTabDialog* >( new TextControlParaAttribDialog( NULL, *pCurrentItems ) ) );
-        if ( RET_OK == pDialog->Execute() )
+        boost::scoped_ptr<SfxTabDialog> xDialog ( _eSet == eCharAttribs
+                                                ? static_cast< SfxTabDialog* >( new TextControlCharAttribDialog( NULL, *xCurrentItems, *pFontList ) )
+                                                : static_cast< SfxTabDialog* >( new TextControlParaAttribDialog( NULL, *xCurrentItems ) ) );
+        if ( RET_OK == xDialog->Execute() )
         {
-            const SfxItemSet& rModifiedItems = *pDialog->GetOutputItemSet();
+            const SfxItemSet& rModifiedItems = *xDialog->GetOutputItemSet();
             for ( WhichId nWhich = pPool->GetFirstWhich(); nWhich <= pPool->GetLastWhich(); ++nWhich )
             {
                 if ( rModifiedItems.GetItemState( nWhich ) == SFX_ITEM_SET )
@@ -713,9 +705,9 @@ namespace svx
                         Sequence< PropertyValue > aArgs;
                         // temporarily put the modified item into a "clean" set,
                         // and let TransformItems calc the respective UNO parameters
-                        pPureItems->Put( *pModifiedItem );
-                        TransformItems( nSlotForItemSet, *pPureItems, aArgs );
-                        pPureItems->ClearItem( nWhich );
+                        xPureItems->Put( *pModifiedItem );
+                        TransformItems( nSlotForItemSet, *xPureItems, aArgs );
+                        xPureItems->ClearItem( nWhich );
 
                         if  (   ( nSlotForItemSet == SID_ATTR_PARA_HANGPUNCTUATION )
                             ||  ( nSlotForItemSet == SID_ATTR_PARA_FORBIDDEN_RULES )
@@ -732,7 +724,7 @@ namespace svx
                             {
                                 aArgs.realloc( 1 );
                                 aArgs[ 0 ].Name = "Enable";
-                                aArgs[ 0 ].Value <<= (sal_Bool)pBoolItem->GetValue();
+                                aArgs[ 0 ].Value <<= pBoolItem->GetValue();
                             }
                         }
 
@@ -760,13 +752,13 @@ namespace svx
             _rReq.Done( rModifiedItems );
         }
 
-        pDialog.reset();
-        pCurrentItems.reset();
-        pPureItems.reset();
+        xDialog.reset();
+        xCurrentItems.reset();
+        xPureItems.reset();
         SfxItemPool::Free(pPool);
     }
 
-    //------------------------------------------------------------------------
+
     bool FmTextControlShell::executeSelectAll( )
     {
         try
@@ -785,7 +777,7 @@ namespace svx
         return false;   // not handled
     }
 
-    //------------------------------------------------------------------------
+
     bool FmTextControlShell::executeClipboardSlot( SfxSlotId _nSlot )
     {
         try
@@ -827,7 +819,7 @@ namespace svx
         return false;   // not handled
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::ExecuteTextAttribute( SfxRequest& _rReq )
     {
         SfxSlotId nSlot = _rReq.GetSlot();
@@ -933,7 +925,7 @@ namespace svx
         _rReq.Done();
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::GetTextAttributeState( SfxItemSet& _rSet )
     {
         SfxWhichIter aIter( _rSet );
@@ -1014,7 +1006,7 @@ namespace svx
                     bDisable |= true;
                     break;
                 }
-                OSL_POSTCOND( !bNeedSelection || bNeedTextComponent, "FmTextControlShell::GetTextAttributeState: bNeedSelection should imply bNeedTextComponent!" );
+                SAL_WARN_IF( bNeedSelection && !bNeedTextComponent, "svx.form", "FmTextControlShell::GetTextAttributeState: bNeedSelection should imply bNeedTextComponent!" );
 
                 if ( !bDisable && bNeedWriteableControl )
                     bDisable |= !IsActiveControl( ) || m_bActiveControlIsReadOnly;
@@ -1036,7 +1028,7 @@ namespace svx
         }
     }
 
-    //------------------------------------------------------------------------
+
     bool FmTextControlShell::IsActiveControl( bool _bCountRichTextOnly ) const
     {
         if ( _bCountRichTextOnly && !m_bActiveControlIsRichText )
@@ -1045,7 +1037,7 @@ namespace svx
         return m_bActiveControl;
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::dispose()
     {
         if ( IsActiveControl() )
@@ -1054,13 +1046,13 @@ namespace svx
             stopControllerListening();
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::designModeChanged( bool /*_bNewDesignMode*/ )
     {
         m_rBindings.Invalidate( pTextControlSlots );
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::formActivated( const Reference< XFormController >& _rxController )
     {
 #if OSL_DEBUG_LEVEL > 0
@@ -1088,7 +1080,7 @@ namespace svx
         }
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::formDeactivated( const Reference< XFormController >& _rxController )
     {
 #if OSL_DEBUG_LEVEL > 0
@@ -1104,7 +1096,7 @@ namespace svx
             stopControllerListening();
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::startControllerListening( const Reference< XFormController >& _rxController )
     {
         OSL_PRECOND( _rxController.is(), "FmTextControlShell::startControllerListening: invalid controller!" );
@@ -1137,7 +1129,7 @@ namespace svx
         m_xActiveController = _rxController;
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::stopControllerListening( )
     {
         OSL_PRECOND( isControllerListening(), "FmTextControlShell::stopControllerListening: inconsistence!" );
@@ -1157,7 +1149,7 @@ namespace svx
         m_xActiveController.clear();
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::implClearActiveControlRef()
     {
         // no more features for this control
@@ -1191,7 +1183,7 @@ namespace svx
         m_bActiveControl = false;
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::controlDeactivated( )
     {
         DBG_ASSERT( IsActiveControl(), "FmTextControlShell::controlDeactivated: no active control!" );
@@ -1201,7 +1193,7 @@ namespace svx
         m_rBindings.Invalidate( pTextControlSlots );
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::controlActivated( const Reference< XControl >& _rxControl )
     {
         // ensure that all knittings with the previously active control are lost
@@ -1268,7 +1260,7 @@ namespace svx
         // Another possibility would be to have dedicated shells for the slots which we might
         // or might not be able to serve. However, this could probably increase the number of
         // shells too much (In theory, nearly every slot could have an own shell then).
-        //
+
         // #i51621# / 2005-08-19 / frank.schoenheit@sun.com
         // bool bHaveAnyServeableSlots = m_xActiveTextComponent.is() || !m_aControlFeatures.empty();
         // LEM: not calling m_aControlActivatonHandler causes fdo#63695, so disable this hack for now.
@@ -1278,7 +1270,7 @@ namespace svx
         m_bNeedClipboardInvalidation = true;
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::fillFeatureDispatchers(  const Reference< XControl > _rxControl, SfxSlotId* _pZeroTerminatedSlots,
             ControlFeatures& _rDispatchers )
     {
@@ -1299,7 +1291,7 @@ namespace svx
         }
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::impl_parseURL_nothrow( URL& _rURL )
     {
         try
@@ -1317,7 +1309,7 @@ namespace svx
         }
     }
 
-    //------------------------------------------------------------------------
+
     FmTextControlFeature* FmTextControlShell::implGetFeatureDispatcher( const Reference< XDispatchProvider >& _rxProvider, SfxApplication* _pApplication, SfxSlotId _nSlot )
     {
         OSL_PRECOND( _rxProvider.is() && _pApplication, "FmTextControlShell::implGetFeatureDispatcher: invalid arg(s)!" );
@@ -1330,7 +1322,7 @@ namespace svx
         return NULL;
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::Invalidate( SfxSlotId _nSlot )
     {
         m_rBindings.Invalidate( _nSlot );
@@ -1339,7 +1331,7 @@ namespace svx
         m_rBindings.Update( _nSlot );
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::focusGained( const ::com::sun::star::awt::FocusEvent& _rEvent )
     {
         Reference< XControl > xControl( _rEvent.Source, UNO_QUERY );
@@ -1355,7 +1347,7 @@ namespace svx
             controlActivated( xControl );
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::focusLost( const ::com::sun::star::awt::FocusEvent& _rEvent )
     {
         Reference< XControl > xControl( _rEvent.Source, UNO_QUERY );
@@ -1369,20 +1361,20 @@ namespace svx
         m_bActiveControl = false;
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::ForgetActiveControl()
     {
         implClearActiveControlRef();
     }
 
-    //------------------------------------------------------------------------
+
     void FmTextControlShell::contextMenuRequested( const awt::MouseEvent& /*_rEvent*/ )
     {
         m_rBindings.GetDispatcher()->ExecutePopup( SVX_RES( RID_FM_TEXTATTRIBUTE_MENU ) );
     }
 
-//........................................................................
+
 } // namespace svx
-//........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
