@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  * This file is part of the LibreOffice project.
  *
@@ -202,7 +203,7 @@ LinePropertyPanel::LinePropertyPanel(
     get(mpLBCapStyle, "linecapstyle");
 
     const sal_uInt16 nIdColor = mpTBColor->GetItemId(UNO_SELECTCOLOR);
-    mpColorUpdater.reset(new ::svx::ToolboxButtonColorUpdater(SID_ATTR_LINE_COLOR, nIdColor, mpTBColor)),
+    mpColorUpdater.reset(new ::svx::ToolboxButtonColorUpdater(0 /* not defined, default is transparent */, nIdColor, mpTBColor)),
     Initialize();
 }
 
@@ -500,7 +501,7 @@ void LinePropertyPanel::NotifyItemUpdate(
 
                 if(pItem)
                 {
-                    mpStartItem.reset(pItem ? (XLineStartItem*)pItem->Clone() : 0);
+                    mpStartItem.reset((XLineStartItem*)pItem->Clone());
                     SelectEndStyle(true);
                     break;
                 }
@@ -529,7 +530,7 @@ void LinePropertyPanel::NotifyItemUpdate(
 
                 if(pItem)
                 {
-                    mpEndItem.reset(pItem ? (XLineEndItem*)pItem->Clone() : 0);
+                    mpEndItem.reset((XLineEndItem*)pItem->Clone());
                     SelectEndStyle(false);
                     break;
                 }
@@ -571,7 +572,7 @@ void LinePropertyPanel::NotifyItemUpdate(
 
                 if(pItem)
                 {
-                    sal_uInt16 nEntryPos(0);
+                    sal_Int32 nEntryPos(0);
 
                     switch(pItem->GetValue())
                     {
@@ -631,7 +632,7 @@ void LinePropertyPanel::NotifyItemUpdate(
 
                 if(pItem)
                 {
-                    sal_uInt16 nEntryPos(0);
+                    sal_Int32 nEntryPos(0);
 
                     switch(pItem->GetValue())
                     {
@@ -696,9 +697,9 @@ IMPL_LINK(LinePropertyPanel, ToolboxColorSelectHdl,ToolBox*, pToolBox)
 
 IMPL_LINK_NOARG(LinePropertyPanel, ChangeLineStyleHdl)
 {
-    const sal_uInt16 nPos(mpLBStyle->GetSelectEntryPos());
+    const sal_Int32 nPos(mpLBStyle->GetSelectEntryPos());
 
-    if(LISTBOX_ENTRY_NOTFOUND != nPos && nPos != mpLBStyle->GetSavedValue())
+    if(LISTBOX_ENTRY_NOTFOUND != nPos && mpLBStyle->IsValueChangedFromSaved())
     {
         if(0 == nPos)
         {
@@ -736,8 +737,8 @@ IMPL_LINK_NOARG(LinePropertyPanel, ChangeLineStyleHdl)
 
 IMPL_LINK(LinePropertyPanel, ChangeStartHdl, void*, EMPTYARG)
 {
-    sal_uInt16  nPos = mpLBStart->GetSelectEntryPos();
-    if( nPos != LISTBOX_ENTRY_NOTFOUND && nPos != mpLBStart->GetSavedValue() )
+    sal_Int32  nPos = mpLBStart->GetSelectEntryPos();
+    if( nPos != LISTBOX_ENTRY_NOTFOUND && mpLBStart->IsValueChangedFromSaved() )
     {
         XLineStartItem* pItem = NULL;
         if( nPos == 0 )
@@ -755,8 +756,8 @@ IMPL_LINK(LinePropertyPanel, ChangeStartHdl, void*, EMPTYARG)
 
 IMPL_LINK(LinePropertyPanel, ChangeEndHdl, void*, EMPTYARG)
 {
-    sal_uInt16  nPos = mpLBEnd->GetSelectEntryPos();
-    if( nPos != LISTBOX_ENTRY_NOTFOUND && nPos != mpLBEnd->GetSavedValue() )
+    sal_Int32  nPos = mpLBEnd->GetSelectEntryPos();
+    if( nPos != LISTBOX_ENTRY_NOTFOUND && mpLBEnd->IsValueChangedFromSaved() )
     {
         XLineEndItem* pItem = NULL;
         if( nPos == 0 )
@@ -774,9 +775,9 @@ IMPL_LINK(LinePropertyPanel, ChangeEndHdl, void*, EMPTYARG)
 
 IMPL_LINK(LinePropertyPanel, ChangeEdgeStyleHdl, void*, EMPTYARG)
 {
-    const sal_uInt16 nPos(mpLBEdgeStyle->GetSelectEntryPos());
+    const sal_Int32 nPos(mpLBEdgeStyle->GetSelectEntryPos());
 
-    if(LISTBOX_ENTRY_NOTFOUND != nPos && nPos != mpLBEdgeStyle->GetSavedValue())
+    if(LISTBOX_ENTRY_NOTFOUND != nPos && mpLBEdgeStyle->IsValueChangedFromSaved())
     {
         XLineJointItem* pItem = 0;
 
@@ -815,9 +816,9 @@ IMPL_LINK(LinePropertyPanel, ChangeEdgeStyleHdl, void*, EMPTYARG)
 
 IMPL_LINK(LinePropertyPanel, ChangeCapStyleHdl, void*, EMPTYARG)
 {
-    const sal_uInt16 nPos(mpLBCapStyle->GetSelectEntryPos());
+    const sal_Int32 nPos(mpLBCapStyle->GetSelectEntryPos());
 
-    if(LISTBOX_ENTRY_NOTFOUND != nPos && nPos != mpLBCapStyle->GetSavedValue())
+    if(LISTBOX_ENTRY_NOTFOUND != nPos && mpLBCapStyle->IsValueChangedFromSaved())
     {
         XLineCapItem* pItem = 0;
 
@@ -1057,7 +1058,7 @@ void LinePropertyPanel::SelectLineStyle()
                     const XDash& rEntry = pEntry->GetDash();
                     if(rDash == rEntry)
                     {
-                        mpLBStyle->SelectEntryPos((sal_uInt16)a + 2);
+                        mpLBStyle->SelectEntryPos(a + 2);
                         bSelected = true;
                     }
                 }
@@ -1071,7 +1072,7 @@ void LinePropertyPanel::SelectLineStyle()
 
 void LinePropertyPanel::SelectEndStyle(bool bStart)
 {
-    sal_Bool bSelected(false);
+    bool bSelected(false);
 
     if(bStart)
     {
@@ -1091,7 +1092,7 @@ void LinePropertyPanel::SelectEndStyle(bool bStart)
                 const basegfx::B2DPolyPolygon& rEntryPolygon = pEntry->GetLineEnd();
                 if(rItemPolygon == rEntryPolygon)
                 {
-                    mpLBStart->SelectEntryPos((sal_uInt16)a + 1);
+                    mpLBStart->SelectEntryPos(a + 1);
                     bSelected = true;
                 }
             }
@@ -1120,7 +1121,7 @@ void LinePropertyPanel::SelectEndStyle(bool bStart)
                 const basegfx::B2DPolyPolygon& rEntryPolygon = pEntry->GetLineEnd();
                 if(rItemPolygon == rEntryPolygon)
                 {
-                    mpLBEnd->SelectEntryPos((sal_uInt16)a + 1);
+                    mpLBEnd->SelectEntryPos(a + 1);
                     bSelected = true;
                 }
             }
@@ -1136,4 +1137,4 @@ void LinePropertyPanel::SelectEndStyle(bool bStart)
 
 } } // end of namespace svx::sidebar
 
-// eof
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
