@@ -17,11 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-/******************************************************************************
-Attention : "In this file C++ style // comments are not allowed as it will be
-included in c-context files, so c++ style stuff will cause problems.
-******************************************************************************/
-
 #ifndef INCLUDED_SW_INC_CMDID_H
 #define INCLUDED_SW_INC_CMDID_H
 
@@ -204,8 +199,7 @@ included in c-context files, so c++ style stuff will cause problems.
 #define FN_DROP_REGION_LINK     (FN_VIEW + 38)  /**/
 #define FN_DROP_REGION_COPY     (FN_VIEW + 39)  /**/
 
-#define FN_SCROLL_NAVIGATION    (FN_VIEW + 40)  /* Navigation Controller in the scrollbar */
-#define FN_SCROLL_NEXT_PREV     (FN_VIEW + 41)  /* processes MoveType */
+#define FN_SCROLL_NAVIGATION    (FN_VIEW + 40)  /* Navigation Controller */
 
 #define FN_VIEW_HIDDEN_PARA     (FN_VIEW + 42)  /* View hidden paragraphs */
 #define FN_VIEW_SMOOTH_SCROLL   (FN_VIEW + 43)
@@ -223,6 +217,10 @@ included in c-context files, so c++ style stuff will cause problems.
 #define FN_VSCROLL_METRIC        (FN_VIEW + 54) /* Metric vertical scrollbar */
 #define FN_VIEW_NOTES            (FN_VIEW + 55)
 
+#define FN_NAVIGATION_POPUP     (FN_VIEW + 56)  /* Navigation Popup */
+#define FN_SCROLL_PREV          (FN_VIEW + 57)  /* uno:ScrollToPrevious */
+#define FN_SCROLL_NEXT          (FN_VIEW + 58)  /* uno:ScrollToNext */
+
 /*--------------------------------------------------------------------
     Region: Insert
  --------------------------------------------------------------------*/
@@ -780,7 +778,7 @@ included in c-context files, so c++ style stuff will cause problems.
 
 #define FN_DELETE_COMMENT           (FN_NOTES+6)
 #define FN_REPLY                    (FN_NOTES+7)
-
+#define FN_FORMAT_ALL_NOTES         (FN_NOTES+8)
 
 #define FN_HEADERFOOTER_EDIT        (FN_HEADERFOOTER+1)
 #define FN_HEADERFOOTER_DELETE      (FN_HEADERFOOTER+2)
@@ -932,17 +930,17 @@ included in c-context files, so c++ style stuff will cause problems.
 #define         MID_13          0xfa
 
 // defines for Event-assignments per Macro
-#define MAC_EVENT_MOUSEOVER         0x01            //
-#define MAC_EVENT_MOUSECLICK        0x02            //
-#define MAC_EVENT_MOUSEOUT          0x03            //
-#define MAC_EVENT_OBJECT_SELECT     0x04            //
-#define MAC_EVENT_KEYINPUT_ALPHA    0x05            //
-#define MAC_EVENT_KEYINPUT_NOALPHA  0x06            //
-#define MAC_EVENT_FRM_RESIZE        0x07            //
-#define MAC_EVENT_FRM_MOVE          0x08            //
-#define MAC_EVENT_IMAGE_LOAD        0x09            //
-#define MAC_EVENT_IMAGE_ABORT       0x0a            //
-#define MAC_EVENT_IMAGE_ERROR       0x0b            //
+#define MAC_EVENT_MOUSEOVER         0x01
+#define MAC_EVENT_MOUSECLICK        0x02
+#define MAC_EVENT_MOUSEOUT          0x03
+#define MAC_EVENT_OBJECT_SELECT     0x04
+#define MAC_EVENT_KEYINPUT_ALPHA    0x05
+#define MAC_EVENT_KEYINPUT_NOALPHA  0x06
+#define MAC_EVENT_FRM_RESIZE        0x07
+#define MAC_EVENT_FRM_MOVE          0x08
+#define MAC_EVENT_IMAGE_LOAD        0x09
+#define MAC_EVENT_IMAGE_ABORT       0x0a
+#define MAC_EVENT_IMAGE_ERROR       0x0b
 
 #endif // INCLUDED_SW_INC_CMDID_H
 
