@@ -45,26 +45,23 @@
 #include "swfntcch.hxx"
 #include "flyfrm.hxx"
 
-
 #define MIN_OFFSET_STEP 10
 
 using namespace ::com::sun::star;
 
-
 /*
  * - SurvivalKit: For how long do we get past the last char of the line.
  * - RightMargin abstains from adjusting position with -1
  * - GetCharRect returns a GetEndCharRect for MV_RIGHTMARGIN
- * - GetEndCharRect sets bRightMargin to sal_True
- * - SwTxtCursor::bRightMargin is set to sal_False by CharCrsrToLine
+ * - GetEndCharRect sets bRightMargin to true
+ * - SwTxtCursor::bRightMargin is set to false by CharCrsrToLine
  */
 
-/*************************************************************************
- *                      GetAdjFrmAtPos()
- *************************************************************************/
+namespace
+{
 
 SwTxtFrm *GetAdjFrmAtPos( SwTxtFrm *pFrm, const SwPosition &rPos,
-                          const sal_Bool bRightMargin, const sal_Bool bNoScroll = sal_True )
+                          const bool bRightMargin, const bool bNoScroll = true )
 {
     // RightMargin in the last master line
     const sal_Int32 nOffset = rPos.nContent.GetIndex();
@@ -103,7 +100,9 @@ SwTxtFrm *GetAdjFrmAtPos( SwTxtFrm *pFrm, const SwPosition &rPos,
     return pFrmAtPos ? pFrmAtPos : pFrm;
 }
 
-bool sw_ChangeOffset( SwTxtFrm* pFrm, xub_StrLen nNew )
+}
+
+bool sw_ChangeOffset( SwTxtFrm* pFrm, sal_Int32 nNew )
 {
     // Do not scroll in areas and outside of flies
     OSL_ENSURE( !pFrm->IsFollow(), "Illegal Scrolling by Follow!" );
@@ -138,11 +137,7 @@ bool sw_ChangeOffset( SwTxtFrm* pFrm, xub_StrLen nNew )
     return false;
 }
 
-/*************************************************************************
- *                      GetFrmAtOfst(), GetFrmAtPos()
- *************************************************************************/
-
-SwTxtFrm& SwTxtFrm::GetFrmAtOfst( const xub_StrLen nWhere )
+SwTxtFrm& SwTxtFrm::GetFrmAtOfst( const sal_Int32 nWhere )
 {
     SwTxtFrm* pRet = this;
     while( pRet->HasFollow() && nWhere >= pRet->GetFollow()->GetOfst() )
@@ -169,10 +164,6 @@ SwTxtFrm *SwTxtFrm::GetFrmAtPos( const SwPosition &rPos )
     return pFoll;
 }
 
-/*************************************************************************
- *                      SwTxtFrm::GetCharRect()
- *************************************************************************/
-
 /*
  * GetCharRect() returns the char's char line described by aPos.
  * GetCrsrOfst() does the reverse: It goes from a document coordinate to
@@ -180,13 +171,13 @@ SwTxtFrm *SwTxtFrm::GetFrmAtPos( const SwPosition &rPos )
  * Both are virtual in the frame base class and thus are redefined here.
  */
 
-sal_Bool SwTxtFrm::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
+bool SwTxtFrm::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
                             SwCrsrMoveState *pCMS ) const
 {
     OSL_ENSURE( ! IsVertical() || ! IsSwapped(),"SwTxtFrm::GetCharRect with swapped frame" );
 
     if( IsLocked() || IsHiddenNow() )
-        return sal_False;
+        return false;
 
     // Find the right frame first. We need to keep in mind that:
     // - the cached information could be invalid  (GetPara() == 0)
@@ -195,8 +186,8 @@ sal_Bool SwTxtFrm::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
     //   needs to be formatted
 
     // Optimisation: reading ahead saves us a GetAdjFrmAtPos
-    const sal_Bool bRightMargin = pCMS && ( MV_RIGHTMARGIN == pCMS->eState );
-    const sal_Bool bNoScroll = pCMS && pCMS->bNoScroll;
+    const bool bRightMargin = pCMS && ( MV_RIGHTMARGIN == pCMS->eState );
+    const bool bNoScroll = pCMS && pCMS->bNoScroll;
     SwTxtFrm *pFrm = GetAdjFrmAtPos( (SwTxtFrm*)this, rPos, bRightMargin,
                                      bNoScroll );
     pFrm->GetFormatted();
@@ -207,12 +198,11 @@ sal_Bool SwTxtFrm::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
     const SwTwips nFrmMaxY = (pFrm->*fnRect->fnGetPrtBottom)();
 
     // nMaxY is an absolute value
-    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
     SwTwips nMaxY = bVert ?
                     ( bVertL2R ? std::min( nFrmMaxY, nUpperMaxY ) : std::max( nFrmMaxY, nUpperMaxY ) ) :
                     std::min( nFrmMaxY, nUpperMaxY );
 
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
 
     if ( pFrm->IsEmpty() || ! (pFrm->Prt().*fnRect->fnGetHeight)() )
     {
@@ -226,7 +216,6 @@ sal_Bool SwTxtFrm::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
         {
             if( nFirstOffset > 0 )
                 aPnt1.Y() += nFirstOffset;
-            //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
             if ( aPnt1.X() < nMaxY && !bVertL2R )
                 aPnt1.X() = nMaxY;
             aPnt2.X() = aPnt1.X() + pFrm->Prt().Width();
@@ -258,14 +247,14 @@ sal_Bool SwTxtFrm::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
         if ( pFrm->IsRightToLeft() )
             pFrm->SwitchLTRtoRTL( rOrig );
 
-        bRet = sal_True;
+        bRet = true;
     }
     else
     {
         if( !pFrm->HasPara() )
-            return sal_False;
+            return false;
 
-        SwFrmSwapper aSwapper( pFrm, sal_True );
+        SwFrmSwapper aSwapper( pFrm, true );
         if ( bVert )
             nMaxY = pFrm->SwitchVerticalToHorizontal( nMaxY );
 
@@ -358,19 +347,15 @@ sal_Bool SwTxtFrm::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
     return bRet;
 }
 
-/*************************************************************************
- *                      SwTxtFrm::GetAutoPos()
- *************************************************************************/
-
 /*
  * GetAutoPos() looks up the char's char line which is described by rPos
  * and is used by the auto-positioned frame.
  */
 
-sal_Bool SwTxtFrm::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
+bool SwTxtFrm::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
 {
     if( IsHiddenNow() )
-        return sal_False;
+        return false;
 
     const sal_Int32 nOffset = rPos.nContent.GetIndex();
     SwTxtFrm* pFrm = &(const_cast<SwTxtFrm*>(this)->GetFrmAtOfst( nOffset ));
@@ -382,7 +367,6 @@ sal_Bool SwTxtFrm::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
     SwTwips nUpperMaxY = (pTmpFrm->*fnRect->fnGetPrtBottom)();
 
     // nMaxY is in absolute value
-    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
     SwTwips nMaxY = bVert ?
                     ( bVertL2R ? std::min( (pFrm->*fnRect->fnGetPrtBottom)(), nUpperMaxY ) : std::max( (pFrm->*fnRect->fnGetPrtBottom)(), nUpperMaxY ) ) :
                     std::min( (pFrm->*fnRect->fnGetPrtBottom)(), nUpperMaxY );
@@ -411,21 +395,21 @@ sal_Bool SwTxtFrm::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
                 aPnt2.Y() = nMaxY;
         }
         rOrig = SwRect( aPnt1, aPnt2 );
-        return sal_True;
+        return true;
     }
     else
     {
         if( !pFrm->HasPara() )
-            return sal_False;
+            return false;
 
-        SwFrmSwapper aSwapper( pFrm, sal_True );
+        SwFrmSwapper aSwapper( pFrm, true );
         if ( bVert )
             nMaxY = pFrm->SwitchVerticalToHorizontal( nMaxY );
 
         SwTxtSizeInfo aInf( pFrm );
         SwTxtCursor aLine( pFrm, &aInf );
         SwCrsrMoveState aTmpState( MV_SETONLYTEXT );
-        aTmpState.bRealHeight = sal_True;
+        aTmpState.bRealHeight = true;
         if( aLine.GetCharRect( &rOrig, nOffset, &aTmpState, nMaxY ) )
         {
             if( aTmpState.aRealHeight.X() >= 0 )
@@ -440,9 +424,9 @@ sal_Bool SwTxtFrm::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
             if ( bVert )
                 pFrm->SwitchHorizontalToVertical( rOrig );
 
-            return sal_True;
+            return true;
         }
-        return sal_False;
+        return false;
     }
 }
 
@@ -451,8 +435,6 @@ sal_Bool SwTxtFrm::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
     - Top of first paragraph line is the top of the printing area of the text frame
     - If a proportional line spacing is applied use top of anchor character as
       top of the line.
-
-    @author OD
 */
 bool SwTxtFrm::GetTopOfLine( SwTwips& _onTopOfLine,
                              const SwPosition& _rPos ) const
@@ -501,7 +483,7 @@ bool SwTxtFrm::GetTopOfLine( SwTwips& _onTopOfLine,
             else
             {
                 // assure that text frame is in a horizontal layout
-                SwFrmSwapper aSwapper( pFrm, sal_True );
+                SwFrmSwapper aSwapper( pFrm, true );
                 // determine text line that contains the requested position
                 SwTxtSizeInfo aInf( pFrm );
                 SwTxtCursor aLine( pFrm, &aInf );
@@ -519,10 +501,6 @@ bool SwTxtFrm::GetTopOfLine( SwTwips& _onTopOfLine,
     return bRet;
 }
 
-/*************************************************************************
- *                      SwTxtFrm::_GetCrsrOfst()
- *************************************************************************/
-
 // Minimum distance of non-empty lines is a little less than 2 cm
 #define FILL_MIN_DIST 1100
 
@@ -547,21 +525,20 @@ struct SwFillData
     long Left() const { return aFrm.Left(); }
     long Right() const { return aFrm.Right(); }
     long Bottom() const { return aFrm.Bottom(); }
-    SwRect& Frm() { return aFrm; }
     SwFillCrsrPos &Fill() const { return *pCMS->pFill; }
     void SetTab( MSHORT nNew ) { pCMS->pFill->nTabCnt = nNew; }
     void SetSpace( MSHORT nNew ) { pCMS->pFill->nSpaceCnt = nNew; }
     void SetOrient( const sal_Int16 eNew ){ pCMS->pFill->eOrient = eNew; }
 };
 
-sal_Bool SwTxtFrm::_GetCrsrOfst(SwPosition* pPos, const Point& rPoint,
-                    const sal_Bool bChgFrm, SwCrsrMoveState* pCMS ) const
+bool SwTxtFrm::_GetCrsrOfst(SwPosition* pPos, const Point& rPoint,
+                    const bool bChgFrm, SwCrsrMoveState* pCMS ) const
 {
     // _GetCrsrOfst is called by GetCrsrOfst and GetKeyCrsrOfst.
-    // Never just a return sal_False.
+    // Never just a return false.
 
     if( IsLocked() || IsHiddenNow() )
-        return sal_False;
+        return false;
 
     ((SwTxtFrm*)this)->GetFormatted();
 
@@ -588,7 +565,7 @@ sal_Bool SwTxtFrm::_GetCrsrOfst(SwPosition* pPos, const Point& rPoint,
         {
             SwTwips nDiff = rPoint.X() - Frm().Left() - Prt().Left();
             if( nDiff > 50 || nDiff < 0 )
-                ((SwCrsrMoveState*)pCMS)->bPosCorr = sal_True;
+                ((SwCrsrMoveState*)pCMS)->bPosCorr = true;
         }
     }
     else
@@ -610,17 +587,17 @@ sal_Bool SwTxtFrm::_GetCrsrOfst(SwPosition* pPos, const Point& rPoint,
             while( aLine.GetLineNr() > 1 )
                 aLine.Prev();
 
-        xub_StrLen nOffset = aLine.GetCrsrOfst( pPos, rPoint, bChgFrm, pCMS );
+        sal_Int32 nOffset = aLine.GetCrsrOfst( pPos, rPoint, bChgFrm, pCMS );
 
         if( pCMS && pCMS->eState == MV_NONE && aLine.GetEnd() == nOffset )
             ((SwCrsrMoveState*)pCMS)->eState = MV_RIGHTMARGIN;
 
     // pPos is a pure IN parameter and must not be evaluated.
-    // pIter->GetCrsrOfst returns from a nesting with STRING_LEN.
+    // pIter->GetCrsrOfst returns from a nesting with COMPLETE_STRING.
     // If SwTxtIter::GetCrsrOfst calls GetCrsrOfst further by itself
     // nNode changes the position.
     // In such cases, pPos must not be calculated.
-        if( STRING_LEN != nOffset )
+        if( COMPLETE_STRING != nOffset )
         {
             SwTxtNode* pTxtNd = ((SwTxtFrm*)this)->GetTxtNode();
             pPos->nNode = *pTxtNd;
@@ -667,14 +644,10 @@ sal_Bool SwTxtFrm::_GetCrsrOfst(SwPosition* pPos, const Point& rPoint,
     (Point&)rPoint = aOldPoint;
     delete pFillData;
 
-    return sal_True;
+    return true;
 }
 
-/*************************************************************************
- *                 virtual SwTxtFrm::GetCrsrOfst()
- *************************************************************************/
-
-sal_Bool SwTxtFrm::GetCrsrOfst(SwPosition* pPos, Point& rPoint,
+bool SwTxtFrm::GetCrsrOfst(SwPosition* pPos, Point& rPoint,
                                SwCrsrMoveState* pCMS, bool ) const
 {
     MSHORT nChgFrm = 2;
@@ -689,15 +662,11 @@ sal_Bool SwTxtFrm::GetCrsrOfst(SwPosition* pPos, Point& rPoint,
     return _GetCrsrOfst( pPos, rPoint, nChgFrm != 0, pCMS );
 }
 
-/*************************************************************************
- *                      SwTxtFrm::LeftMargin()
- *************************************************************************/
-
 /*
  * Layout-oriented cursor movement to the line start.
  */
 
-sal_Bool SwTxtFrm::LeftMargin(SwPaM *pPam) const
+bool SwTxtFrm::LeftMargin(SwPaM *pPam) const
 {
     if( ((const SwNode*)pPam->GetNode()) != GetNode() )
         pPam->GetPoint()->nNode = *((SwTxtFrm*)this)->GetTxtNode();
@@ -705,7 +674,7 @@ sal_Bool SwTxtFrm::LeftMargin(SwPaM *pPam) const
     SwTxtFrm *pFrm = GetAdjFrmAtPos( (SwTxtFrm*)this, *pPam->GetPoint(),
                                      SwTxtCursor::IsRightMargin() );
     pFrm->GetFormatted();
-    xub_StrLen nIndx;
+    sal_Int32 nIndx;
     if ( pFrm->IsEmpty() )
         nIndx = 0;
     else
@@ -722,21 +691,17 @@ sal_Bool SwTxtFrm::LeftMargin(SwPaM *pPam) const
         }
     }
     pPam->GetPoint()->nContent = SwIndex( pFrm->GetTxtNode(), nIndx );
-    SwTxtCursor::SetRightMargin( sal_False );
-    return sal_True;
+    SwTxtCursor::SetRightMargin( false );
+    return true;
 }
 
-/*************************************************************************
- *                      SwTxtFrm::RightMargin()
- *************************************************************************/
-
 /*
  * To the line end: That's the position before the last char of the line.
  * Exception: In the last line, it should be able to place the cursor after
  * the last char in order to append text.
  */
 
-sal_Bool SwTxtFrm::RightMargin(SwPaM *pPam, sal_Bool bAPI) const
+bool SwTxtFrm::RightMargin(SwPaM *pPam, bool bAPI) const
 {
     if( ((const SwNode*)pPam->GetNode()) != GetNode() )
         pPam->GetPoint()->nNode = *((SwTxtFrm*)this)->GetTxtNode();
@@ -744,7 +709,7 @@ sal_Bool SwTxtFrm::RightMargin(SwPaM *pPam, sal_Bool bAPI) const
     SwTxtFrm *pFrm = GetAdjFrmAtPos( (SwTxtFrm*)this, *pPam->GetPoint(),
                                      SwTxtCursor::IsRightMargin() );
     pFrm->GetFormatted();
-    xub_StrLen nRightMargin;
+    sal_Int32 nRightMargin;
     if ( IsEmpty() )
         nRightMargin = 0;
     else
@@ -768,13 +733,9 @@ sal_Bool SwTxtFrm::RightMargin(SwPaM *pPam, sal_Bool bAPI) const
     }
     pPam->GetPoint()->nContent = SwIndex( pFrm->GetTxtNode(), nRightMargin );
     SwTxtCursor::SetRightMargin( !bAPI );
-    return sal_True;
+    return true;
 }
 
-/*************************************************************************
- *                      SwTxtFrm::_UnitUp()
- *************************************************************************/
-
 // The following two methods try to put the Crsr into the next/succsessive
 // line. If we do not have a preceding/successive line we forward the call
 // to the base class.
@@ -782,22 +743,22 @@ sal_Bool SwTxtFrm::RightMargin(SwPaM *pPam, sal_Bool bAPI) const
 
 class SwSetToRightMargin
 {
-    sal_Bool bRight;
+    bool bRight;
 public:
-    inline SwSetToRightMargin() : bRight( sal_False ) { }
+    inline SwSetToRightMargin() : bRight( false ) { }
     inline ~SwSetToRightMargin() { SwTxtCursor::SetRightMargin( bRight ); }
-    inline void SetRight( const sal_Bool bNew ) { bRight = bNew; }
+    inline void SetRight( const bool bNew ) { bRight = bNew; }
 };
 
-sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
-                            sal_Bool bSetInReadOnly ) const
+bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
+                        bool bSetInReadOnly ) const
 {
     // Set the RightMargin if needed
     SwSetToRightMargin aSet;
 
     if( IsInTab() &&
-        pPam->GetNode( sal_True )->StartOfSectionNode() !=
-        pPam->GetNode( sal_False )->StartOfSectionNode() )
+        pPam->GetNode( true )->StartOfSectionNode() !=
+        pPam->GetNode( false )->StartOfSectionNode() )
     {
         // If the PaM is located within different boxes, we have a table selection,
         // which is handled by the base class.
@@ -810,10 +771,10 @@ sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
 
     if( !IsEmpty() && !IsHiddenNow() )
     {
-        xub_StrLen nFormat = STRING_LEN;
+        sal_Int32 nFormat = COMPLETE_STRING;
         do
         {
-            if( nFormat != STRING_LEN && !IsFollow() )
+            if( nFormat != COMPLETE_STRING && !IsFollow() )
                 sw_ChangeOffset( ((SwTxtFrm*)this), nFormat );
 
             SwTxtSizeInfo aInf( (SwTxtFrm*)this );
@@ -826,7 +787,7 @@ sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
                 aLine.Top();
 
             const SwLineLayout *pPrevLine = aLine.GetPrevLine();
-            const xub_StrLen nStart = aLine.GetStart();
+            const sal_Int32 nStart = aLine.GetStart();
             aLine.GetCharRect( &aCharBox, nPos );
 
             bool bSecondOfDouble = ( aInf.IsMulti() && ! aInf.IsFirstMulti() );
@@ -835,7 +796,7 @@ sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
             if( !pPrevLine && !bSecondOfDouble && GetOfst() && !IsFollow() )
             {
                 nFormat = GetOfst();
-                xub_StrLen nDiff = aLine.GetLength();
+                sal_Int32 nDiff = aLine.GetLength();
                 if( !nDiff )
                     nDiff = MIN_OFFSET_STEP;
                 if( nFormat > nDiff )
@@ -866,8 +827,8 @@ sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
                 const sal_uLong nOldNode = pPam->GetPoint()->nNode.GetIndex();
 #endif
                 // The node should not be changed
-                xub_StrLen nTmpOfst = aLine.GetCrsrOfst( pPam->GetPoint(),
-                                                         aCharBox.Pos(), sal_False );
+                sal_Int32 nTmpOfst = aLine.GetCrsrOfst( pPam->GetPoint(),
+                                                         aCharBox.Pos(), false );
 #if OSL_DEBUG_LEVEL > 0
                 OSL_ENSURE( nOldNode == pPam->GetPoint()->nNode.GetIndex(),
                         "SwTxtFrm::UnitUp: illegal node change" );
@@ -877,11 +838,11 @@ sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
                 if( nTmpOfst >= nStart && nStart && !bSecondOfDouble )
                 {
                     nTmpOfst = nStart;
-                    aSet.SetRight( sal_True );
+                    aSet.SetRight( true );
                 }
                 pPam->GetPoint()->nContent =
                       SwIndex( ((SwTxtFrm*)this)->GetTxtNode(), nTmpOfst );
-                return sal_True;
+                return true;
             }
 
             if ( IsFollow() )
@@ -899,11 +860,11 @@ sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
     if ( IsFollow() )
     {
         const SwTxtFrm *pTmpPrev = FindMaster();
-        xub_StrLen nOffs = GetOfst();
+        sal_Int32 nOffs = GetOfst();
         if( pTmpPrev )
         {
             SwViewShell *pSh = getRootFrm()->GetCurrShell();
-            sal_Bool bProtectedAllowed = pSh && pSh->GetViewOptions()->IsCursorInProtectedArea();
+            const bool bProtectedAllowed = pSh && pSh->GetViewOptions()->IsCursorInProtectedArea();
             const SwTxtFrm *pPrevPrev = pTmpPrev;
             // We skip protected frames and frames without content here
             while( pPrevPrev && ( pPrevPrev->GetOfst() == nOffs ||
@@ -925,14 +886,13 @@ sal_Bool SwTxtFrm::_UnitUp( SwPaM *pPam, const SwTwips nOffset,
     return SwCntntFrm::UnitUp( pPam, nOffset, bSetInReadOnly );
 }
 
-//
 // Used for Bidi. nPos is the logical position in the string, bLeft indicates
 // if left arrow or right arrow was pressed. The return values are:
 // nPos: the new visual position
 // bLeft: whether the break iterator has to add or subtract from the
 //        current position
 static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nIdx,
-                              sal_Int32& nPos, sal_Bool& bRight,
+                              sal_Int32& nPos, bool& bRight,
                               sal_uInt8& nCrsrLevel, sal_uInt8 nDefaultDir )
 {
     const SwLinePortion* pPor = rCurrLine.GetFirstPortion();
@@ -948,7 +908,7 @@ static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nI
 
     if ( bRight )
     {
-        sal_Bool bRecurse = pPor && pPor->IsMultiPortion() &&
+        bool bRecurse = pPor && pPor->IsMultiPortion() &&
                            ((SwMultiPortion*)pPor)->IsBidi();
 
         // 1. special case: at beginning of bidi portion
@@ -959,7 +919,7 @@ static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nI
             // leave bidi portion
             if ( nCrsrLevel != nDefaultDir )
             {
-                bRecurse = sal_False;
+                bRecurse = false;
             }
             else
                 // special case:
@@ -976,7 +936,7 @@ static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nI
             // enter bidi portion
             if ( nCrsrLevel != nDefaultDir )
             {
-                bRecurse = sal_True;
+                bRecurse = true;
                 nIdx = nIdx - pLast->GetLen();
                 pPor = pLast;
             }
@@ -987,7 +947,7 @@ static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nI
         {
             const SwLineLayout& rLine = ((SwMultiPortion*)pPor)->GetRoot();
             sal_Int32 nTmpPos = nPos - nIdx;
-            sal_Bool bTmpForward = ! bRight;
+            bool bTmpForward = ! bRight;
             sal_uInt8 nTmpCrsrLevel = nCrsrLevel;
             lcl_VisualMoveRecursion( rLine, 0, nTmpPos, bTmpForward,
                                      nTmpCrsrLevel, nDefaultDir + 1 );
@@ -1000,7 +960,7 @@ static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nI
         // go forward
         else
         {
-            bRight = sal_True;
+            bRight = true;
             nCrsrLevel = nDefaultDir;
         }
 
@@ -1046,7 +1006,7 @@ static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nI
         {
             const SwLineLayout& rLine = ((SwMultiPortion*)pPor)->GetRoot();
             sal_Int32 nTmpPos = nPos - nIdx;
-            sal_Bool bTmpForward = ! bRight;
+            bool bTmpForward = ! bRight;
             sal_uInt8 nTmpCrsrLevel = nCrsrLevel;
             lcl_VisualMoveRecursion( rLine, 0, nTmpPos, bTmpForward,
                                      nTmpCrsrLevel, nDefaultDir + 1 );
@@ -1070,14 +1030,14 @@ static void lcl_VisualMoveRecursion( const SwLineLayout& rCurrLine, sal_Int32 nI
         // go backward
         else
         {
-            bRight = sal_False;
+            bRight = false;
             nCrsrLevel = nDefaultDir;
         }
     }
 }
 
 void SwTxtFrm::PrepareVisualMove( sal_Int32& nPos, sal_uInt8& nCrsrLevel,
-                                  sal_Bool& bForward, sal_Bool bInsertCrsr )
+                                  bool& bForward, bool bInsertCrsr )
 {
     if( IsEmpty() || IsHiddenNow() )
         return;
@@ -1116,9 +1076,8 @@ void SwTxtFrm::PrepareVisualMove( sal_Int32& nPos, sal_uInt8& nCrsrLevel,
     const bool bVisualRight = ( nDefaultDir == UBIDI_LTR && bForward ) ||
                                   ( nDefaultDir == UBIDI_RTL && ! bForward );
 
-    //
     // Bidi functions from icu 2.0
-    //
+
     const sal_Unicode* pLineString = GetTxtNode()->GetTxt().getStr();
 
     UErrorCode nError = U_ZERO_ERROR;
@@ -1180,17 +1139,13 @@ void SwTxtFrm::PrepareVisualMove( sal_Int32& nPos, sal_uInt8& nCrsrLevel,
     ubidi_close( pBidi );
 }
 
-/*************************************************************************
- *                      SwTxtFrm::_UnitDown()
- *************************************************************************/
-
-sal_Bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
-                            sal_Bool bSetInReadOnly ) const
+bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
+                         bool bSetInReadOnly ) const
 {
 
     if ( IsInTab() &&
-        pPam->GetNode( sal_True )->StartOfSectionNode() !=
-        pPam->GetNode( sal_False )->StartOfSectionNode() )
+        pPam->GetNode( true )->StartOfSectionNode() !=
+        pPam->GetNode( false )->StartOfSectionNode() )
     {
         // If the PaM is located within different boxes, we have a table selection,
         // which is handled by the base class.
@@ -1206,10 +1161,10 @@ sal_Bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
 
     if ( !IsEmpty() && !IsHiddenNow() )
     {
-        xub_StrLen nFormat = STRING_LEN;
+        sal_Int32 nFormat = COMPLETE_STRING;
         do
         {
-            if( nFormat != STRING_LEN && !IsFollow() &&
+            if( nFormat != COMPLETE_STRING && !IsFollow() &&
                 !sw_ChangeOffset( ((SwTxtFrm*)this), nFormat ) )
                 break;
 
@@ -1220,7 +1175,7 @@ sal_Bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
             aLine.CharCrsrToLine( nPos );
 
             const SwLineLayout* pNextLine = aLine.GetNextLine();
-            const xub_StrLen nStart = aLine.GetStart();
+            const sal_Int32 nStart = aLine.GetStart();
             aLine.GetCharRect( &aCharBox, nPos );
 
             bool bFirstOfDouble = ( aInf.IsMulti() && aInf.IsFirstMulti() );
@@ -1235,8 +1190,8 @@ sal_Bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
                 if ( pNextLine && ! bFirstOfDouble )
                     aLine.NextLine();
 
-                xub_StrLen nTmpOfst = aLine.GetCrsrOfst( pPam->GetPoint(),
-                                 aCharBox.Pos(), sal_False );
+                sal_Int32 nTmpOfst = aLine.GetCrsrOfst( pPam->GetPoint(),
+                                 aCharBox.Pos(), false );
 #if OSL_DEBUG_LEVEL > 0
                 OSL_ENSURE( nOldNode == pPam->GetPoint()->nNode.GetIndex(),
                     "SwTxtFrm::UnitDown: illegal node change" );
@@ -1251,7 +1206,7 @@ sal_Bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
                 if ( IsVertical() )
                     ((SwTxtFrm*)this)->SwapWidthAndHeight();
 
-                return sal_True;
+                return true;
             }
             if( 0 != ( pTmpFollow = GetFollow() ) )
             {   // Skip protected follows
@@ -1282,8 +1237,8 @@ sal_Bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
                 {
                     if( nFormat <= GetOfst() )
                     {
-                        nFormat = std::min( xub_StrLen( GetOfst() + MIN_OFFSET_STEP ),
-                                       static_cast<xub_StrLen>(nTmpLen) );
+                        nFormat = std::min( sal_Int32( GetOfst() + MIN_OFFSET_STEP ),
+                                       static_cast<sal_Int32>(nTmpLen) );
                         if( nFormat <= GetOfst() )
                             break;
                     }
@@ -1309,12 +1264,8 @@ sal_Bool SwTxtFrm::_UnitDown(SwPaM *pPam, const SwTwips nOffset,
     return SwCntntFrm::UnitDown( pPam, nOffset, bSetInReadOnly );
 }
 
-/*************************************************************************
- *                   virtual SwTxtFrm::UnitUp()
- *************************************************************************/
-
-sal_Bool SwTxtFrm::UnitUp(SwPaM *pPam, const SwTwips nOffset,
-                            sal_Bool bSetInReadOnly ) const
+bool SwTxtFrm::UnitUp(SwPaM *pPam, const SwTwips nOffset,
+                      bool bSetInReadOnly ) const
 {
     /* We call CntntNode::GertFrm() in CrsrSh::Up().
      * This _always returns the master.
@@ -1325,24 +1276,20 @@ sal_Bool SwTxtFrm::UnitUp(SwPaM *pPam, const SwTwips nOffset,
      */
     const SwTxtFrm *pFrm = GetAdjFrmAtPos( (SwTxtFrm*)this, *(pPam->GetPoint()),
                                            SwTxtCursor::IsRightMargin() );
-    const sal_Bool bRet = pFrm->_UnitUp( pPam, nOffset, bSetInReadOnly );
+    const bool bRet = pFrm->_UnitUp( pPam, nOffset, bSetInReadOnly );
 
-    // No SwTxtCursor::SetRightMargin( sal_False );
+    // No SwTxtCursor::SetRightMargin( false );
     // Instead we have a SwSetToRightMargin in _UnitUp
     return bRet;
 }
 
-/*************************************************************************
- *                   virtual SwTxtFrm::UnitDown()
- *************************************************************************/
-
-sal_Bool SwTxtFrm::UnitDown(SwPaM *pPam, const SwTwips nOffset,
-                            sal_Bool bSetInReadOnly ) const
+bool SwTxtFrm::UnitDown(SwPaM *pPam, const SwTwips nOffset,
+                        bool bSetInReadOnly ) const
 {
     const SwTxtFrm *pFrm = GetAdjFrmAtPos((SwTxtFrm*)this, *(pPam->GetPoint()),
                                            SwTxtCursor::IsRightMargin() );
-    const sal_Bool bRet = pFrm->_UnitDown( pPam, nOffset, bSetInReadOnly );
-    SwTxtCursor::SetRightMargin( sal_False );
+    const bool bRet = pFrm->_UnitDown( pPam, nOffset, bSetInReadOnly );
+    SwTxtCursor::SetRightMargin( false );
     return bRet;
 }
 
@@ -1406,7 +1353,6 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
             return;
         }
     }
-    sal_Bool bFill = sal_True;
     SwFont *pFnt;
     SwTxtFmtColl* pColl = GetTxtNode()->GetTxtColl();
     MSHORT nFirst = GetTxtNode()->GetSwAttrSet().GetULSpace().GetLower();
@@ -1435,13 +1381,15 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
     if( !pSh->GetViewOptions()->getBrowseMode() || pSh->GetViewOptions()->IsPrtFormat() )
         pOut = GetTxtNode()->getIDocumentDeviceAccess()->getReferenceDevice( true );
 
-    pFnt->SetFntChg( sal_True );
+    pFnt->SetFntChg( true );
     pFnt->ChgPhysFnt( pSh, *pOut );
 
     SwTwips nLineHeight = pFnt->GetHeight( pSh, *pOut );
 
+    bool bFill = false;
     if( nLineHeight )
     {
+        bFill = true;
         const SvxULSpaceItem &rUL = pSet->GetULSpace();
         SwTwips nDist = std::max( rUL.GetLower(), rUL.GetUpper() );
         if( rFill.Fill().nColumnCnt )
@@ -1470,7 +1418,7 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
         else
             nDiff = -1;
         if( rFill.bInner )
-            bFill = sal_False;
+            bFill = false;
         else
         {
             const SvxTabStopItem &rRuler = pSet->GetTabStops();
@@ -1482,7 +1430,7 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
                 rRect.Top( rRect.Top() + nFirst );
             rRect.Height( nLineHeight );
             SwTwips nLeft = rFill.Left() + rLRSpace.GetLeft() +
-                            GetTxtNode()->GetLeftMarginWithNum( sal_False );
+                            GetTxtNode()->GetLeftMarginWithNum();
             SwTwips nRight = rFill.Right() - rLRSpace.GetRight();
             SwTwips nCenter = ( nLeft + nRight ) / 2;
             rRect.Left( nLeft );
@@ -1511,7 +1459,7 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
                     }
                 }
                 else
-                    bFill = sal_False;
+                    bFill = false;
             }
             else
             {
@@ -1531,13 +1479,13 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
                         rRect.Left( nRight );
                     }
                     else
-                        bFill = sal_False;
+                        bFill = false;
                 }
                 else if( FILL_INDENT == rFill.Mode() )
                 {
                     SwTwips nIndent = rFill.X();
                     if( !rFill.bEmpty || nIndent > nRight )
-                        bFill = sal_False;
+                        bFill = false;
                     else
                     {
                         nIndent -= rFill.Left();
@@ -1549,13 +1497,13 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
                             rRect.Left( nIndent + rFill.Left() );
                         }
                         else
-                            bFill = sal_False;
+                            bFill = false;
                     }
                 }
                 else if( rFill.X() > nLeft )
                 {
                     SwTwips nTxtLeft = rFill.Left() + rLRSpace.GetTxtLeft() +
-                                    GetTxtNode()->GetLeftMarginWithNum( sal_True );
+                                    GetTxtNode()->GetLeftMarginWithNum( true );
                     rFill.nLineWidth += rFill.bFirstLine ? nLeft : nTxtLeft;
                     SwTwips nLeftTab = nLeft;
                     SwTwips nRightTab = nLeft;
@@ -1689,7 +1637,7 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
                         if( !rFill.bEmpty )
                             rFill.nLineWidth += FILL_MIN_DIST;
                         if( rRect.Left() < rFill.nLineWidth )
-                            bFill = sal_False;
+                            bFill = false;
                     }
                 }
             }
@@ -1710,13 +1658,11 @@ void SwTxtFrm::FillCrsrPos( SwFillData& rFill ) const
                 nRectBottom = SwitchHorizontalToVertical( nRectBottom );
 
             if( (*fnRect->fnYDiff)( nLimit, nRectBottom ) < 0 )
-                bFill = sal_False;
+                bFill = false;
             else
                 rRect.Width( 1 );
         }
     }
-    else
-        bFill = sal_False;
     ((SwCrsrMoveState*)rFill.pCMS)->bFillRet = bFill;
     delete pFnt;
 }
