@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "xmlimpit.hxx"
 
 #include <sax/tools/converter.hxx>
@@ -31,7 +30,6 @@
 #include <editeng/xmlcnitm.hxx>
 #include <editeng/memberids.hrc>
 
-
 #include "hintids.hxx"
 #include "unomid.h"
 #include <svx/unomid.hxx>
@@ -75,7 +73,7 @@ SvXMLImportItemMapper::setMapEntries( SvXMLItemMapEntriesRef rMapEntries )
     mrMapEntries = rMapEntries;
 }
 
-/** fills the given itemset with the attributes in the given list */
+// fills the given itemset with the attributes in the given list
 void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
                                       uno::Reference< xml::sax::XAttributeList > xAttrList,
                                       const SvXMLUnitConverter& rUnitConverter,
@@ -107,7 +105,7 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
             {
                 // first get item from itemset
                 const SfxPoolItem* pItem = 0;
-                SfxItemState eState = rSet.GetItemState( pEntry->nWhichId, sal_True,
+                SfxItemState eState = rSet.GetItemState( pEntry->nWhichId, true,
                                                          &pItem );
 
                 // if its not set, try the pool
@@ -155,7 +153,7 @@ void SvXMLImportItemMapper::importXML( SfxItemSet& rSet,
             if( !pUnknownItem )
             {
                 const SfxPoolItem* pItem = 0;
-                if( SFX_ITEM_SET == rSet.GetItemState( nUnknownWhich, sal_True,
+                if( SFX_ITEM_SET == rSet.GetItemState( nUnknownWhich, true,
                                                        &pItem ) )
                 {
                     SfxPoolItem *pNew = pItem->Clone();
@@ -200,7 +198,7 @@ SvXMLImportItemMapper::handleSpecialItem(  const SvXMLItemMapEntry& /*rEntry*/,
                                             const SvXMLUnitConverter& /*rUnitConverter*/,
                                             const SvXMLNamespaceMap& /*rNamespaceMap*/ )
 {
-    OSL_FAIL( "unsuported special item in xml import" );
+    OSL_FAIL( "unsupported special item in xml import" );
     return false;
 }
 
@@ -212,7 +210,7 @@ bool SvXMLImportItemMapper::handleNoItem( const SvXMLItemMapEntry& /*rEntry*/,
                                            const SvXMLUnitConverter& /*rUnitConverter*/,
                                            const SvXMLNamespaceMap& /*rNamespaceMap*/ )
 {
-    OSL_FAIL( "unsuported no item in xml import" );
+    OSL_FAIL( "unsupported no item in xml import" );
     return false;
 }
 
@@ -250,8 +248,6 @@ struct BoxHolder : private boost::noncopyable
     }
 };
 
-
-
 // put an XML-string value into an item
 bool SvXMLImportItemMapper::PutXMLValue(
     SfxPoolItem& rItem,
@@ -295,6 +291,7 @@ bool SvXMLImportItemMapper::PutXMLValue(
                     }
                 }
                 break;
+
                 case MID_FIRST_LINE_INDENT:
                 {
                     sal_Int32 nProp = 100;
@@ -308,6 +305,7 @@ bool SvXMLImportItemMapper::PutXMLValue(
 
                     pLRSpace->SetTxtFirstLineOfst( (short)nAbs, (sal_uInt16)nProp );
                 }
+                break;
 
                 case MID_FIRST_AUTO:
                 {
@@ -437,7 +435,7 @@ bool SvXMLImportItemMapper::PutXMLValue(
             SvxBoxItem* pBox = PTR_CAST(SvxBoxItem, &rItem);
             OSL_ENSURE( pBox != NULL, "Wrong WHich-ID" );
 
-            /** copy SvxBorderLines */
+            // copy SvxBorderLines
             BoxHolder aBoxes(pBox);
 
             sal_Int32 nTemp;
@@ -631,13 +629,13 @@ bool SvXMLImportItemMapper::PutXMLValue(
             if( IsXMLToken( rValue, XML_ALWAYS ) ||
                  IsXMLToken( rValue, XML_TRUE ) )
             {
-                pFmtKeep->SetValue( sal_True );
+                pFmtKeep->SetValue( true );
                 bOk = true;
             }
             else if( IsXMLToken( rValue, XML_AUTO ) ||
                      IsXMLToken( rValue, XML_FALSE ) )
             {
-                pFmtKeep->SetValue( sal_False );
+                pFmtKeep->SetValue( false );
                 bOk = true;
             }
         }
@@ -811,13 +809,13 @@ bool SvXMLImportItemMapper::PutXMLValue(
             if( IsXMLToken( rValue, XML_AUTO ) ||
                  IsXMLToken( rValue, XML_TRUE ) )
             {
-                pSplit->SetValue( sal_True );
+                pSplit->SetValue( true );
                 bOk = true;
             }
             else if( IsXMLToken( rValue, XML_ALWAYS ) ||
                      IsXMLToken( rValue, XML_FALSE ) )
             {
-                pSplit->SetValue( sal_False );
+                pSplit->SetValue( false );
                 bOk = true;
             }
         }
@@ -965,12 +963,12 @@ bool SvXMLImportItemMapper::PutXMLValue(
 
             if( IsXMLToken( rValue, XML_COLLAPSING ) )
             {
-                pBorders->SetValue( sal_True );
+                pBorders->SetValue( true );
                 bOk = true;
             }
             else if( IsXMLToken( rValue, XML_SEPARATING ) )
             {
-                pBorders->SetValue( sal_False );
+                pBorders->SetValue( false );
                 bOk = true;
             }
             else
@@ -986,5 +984,4 @@ bool SvXMLImportItemMapper::PutXMLValue(
     return bOk;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
