@@ -41,8 +41,6 @@
 #include <limits.h>
 #include <cmath>
 
-DBG_NAME( Polygon )
-
 #define EDGE_LEFT       1
 #define EDGE_TOP        2
 #define EDGE_RIGHT      4
@@ -153,10 +151,10 @@ void ImplPolygon::ImplSetSize( sal_uInt16 nNewSize, bool bResize )
 
         if ( bResize )
         {
-            // Alte Punkte kopieren
+            // Copy the old points
             if ( mnPoints < nNewSize )
             {
-                // Neue Punkte mit 0 initialisieren
+                // New points initialized to zero
                 memset( pNewAry+mnPoints, 0, (sal_uIntPtr)(nNewSize-mnPoints)*sizeof(Point) );
                 if ( mpPointAry )
                     memcpy( pNewAry, mpPointAry, mnPoints*sizeof(Point) );
@@ -185,10 +183,10 @@ void ImplPolygon::ImplSetSize( sal_uInt16 nNewSize, bool bResize )
 
             if( bResize )
             {
-                // Alte Flags kopieren
+                // copy the old flags
                 if ( mnPoints < nNewSize )
                 {
-                    // Neue Punkte mit 0 initialisieren
+                    // initialize new flags to zero
                     memset( pNewFlagAry+mnPoints, 0, nNewSize-mnPoints );
                     memcpy( pNewFlagAry, mpFlagAry, mnPoints );
                 }
@@ -279,6 +277,18 @@ void ImplPolygon::ImplCreateFlagArray()
     }
 }
 
+
+Polygon Polygon::SubdivideBezier( const Polygon& rPoly )
+{
+    Polygon aPoly;
+
+    // #100127# Use adaptive subdivide instead of fixed 25 segments
+    rPoly.AdaptiveSubdivide( aPoly );
+
+    return aPoly;
+}
+
+
 inline void Polygon::ImplMakeUnique()
 {
     // copy references if any exist
@@ -300,13 +310,11 @@ inline double ImplGetParameter( const Point& rCenter, const Point& rPt, double f
 
 Polygon::Polygon()
 {
-    DBG_CTOR( Polygon, NULL );
     mpImplPolygon = (ImplPolygon*)(&aStaticImplPolygon);
 }
 
 Polygon::Polygon( sal_uInt16 nSize )
 {
-    DBG_CTOR( Polygon, NULL );
 
     if ( nSize )
         mpImplPolygon = new ImplPolygon( nSize );
@@ -316,7 +324,6 @@ Polygon::Polygon( sal_uInt16 nSize )
 
 Polygon::Polygon( sal_uInt16 nPoints, const Point* pPtAry, const sal_uInt8* pFlagAry )
 {
-    DBG_CTOR( Polygon, NULL );
 
     if( nPoints )
         mpImplPolygon = new ImplPolygon( nPoints, pPtAry, pFlagAry );
@@ -326,8 +333,6 @@ Polygon::Polygon( sal_uInt16 nPoints, const Point* pPtAry, const sal_uInt8* pFla
 
 Polygon::Polygon( const Polygon& rPoly )
 {
-    DBG_CTOR( Polygon, NULL );
-    DBG_CHKOBJ( &rPoly, Polygon, NULL );
     DBG_ASSERT( rPoly.mpImplPolygon->mnRefCount < 0xFFFFFFFE, "Polygon: RefCount overflow" );
 
     mpImplPolygon = rPoly.mpImplPolygon;
@@ -337,7 +342,6 @@ Polygon::Polygon( const Polygon& rPoly )
 
 Polygon::Polygon( const Rectangle& rRect )
 {
-    DBG_CTOR( Polygon, NULL );
 
     if ( rRect.IsEmpty() )
         mpImplPolygon = (ImplPolygon*)(&aStaticImplPolygon);
@@ -354,8 +358,6 @@ Polygon::Polygon( const Rectangle& rRect )
 
 Polygon::Polygon( const Rectangle& rRect, sal_uIntPtr nHorzRound, sal_uIntPtr nVertRound )
 {
-    DBG_CTOR( Polygon, NULL );
-
     if ( rRect.IsEmpty() )
         mpImplPolygon = (ImplPolygon*)(&aStaticImplPolygon);
     else
@@ -409,8 +411,6 @@ Polygon::Polygon( const Rectangle& rRect, sal_uIntPtr nHorzRound, sal_uIntPtr nV
 
 Polygon::Polygon( const Point& rCenter, long nRadX, long nRadY, sal_uInt16 nPoints )
 {
-    DBG_CTOR( Polygon, NULL );
-
     if( nRadX && nRadY )
     {
         // Compute default (depends on size)
@@ -461,8 +461,6 @@ Polygon::Polygon( const Point& rCenter, long nRadX, long nRadY, sal_uInt16 nPoin
 Polygon::Polygon( const Rectangle& rBound, const Point& rStart, const Point& rEnd,
                   PolyStyle eStyle, bool bFullCircle )
 {
-    DBG_CTOR( Polygon, NULL );
-
     const long  nWidth = rBound.GetWidth();
     const long  nHeight = rBound.GetHeight();
 
@@ -539,8 +537,6 @@ Polygon::Polygon( const Point& rBezPt1, const Point& rCtrlPt1,
                   const Point& rBezPt2, const Point& rCtrlPt2,
                   sal_uInt16 nPoints )
 {
-    DBG_CTOR( Polygon, NULL );
-
     nPoints = ( 0 == nPoints ) ? 25 : ( ( nPoints < 2 ) ? 2 : nPoints );
 
     const double    fInc = 1.0 / ( nPoints - 1 );
@@ -572,7 +568,6 @@ Polygon::Polygon( const Point& rBezPt1, const Point& rCtrlPt1,
 
 Polygon::~Polygon()
 {
-    DBG_DTOR( Polygon, NULL );
 
     // Remove if refcount == 0, otherwise decrement refcount
     if ( mpImplPolygon->mnRefCount )
@@ -586,19 +581,16 @@ Polygon::~Polygon()
 
 const Point* Polygon::GetConstPointAry() const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     return (Point*)mpImplPolygon->mpPointAry;
 }
 
 const sal_uInt8* Polygon::GetConstFlagAry() const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     return mpImplPolygon->mpFlagAry;
 }
 
 void Polygon::SetPoint( const Point& rPt, sal_uInt16 nPos )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( nPos < mpImplPolygon->mnPoints,
                 "Polygon::SetPoint(): nPos >= nPoints" );
 
@@ -608,7 +600,6 @@ void Polygon::SetPoint( const Point& rPt, sal_uInt16 nPos )
 
 void Polygon::SetFlags( sal_uInt16 nPos, PolyFlags eFlags )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( nPos < mpImplPolygon->mnPoints,
                 "Polygon::SetFlags(): nPos >= nPoints" );
 
@@ -624,7 +615,6 @@ void Polygon::SetFlags( sal_uInt16 nPos, PolyFlags eFlags )
 
 const Point& Polygon::GetPoint( sal_uInt16 nPos ) const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( nPos < mpImplPolygon->mnPoints,
                 "Polygon::GetPoint(): nPos >= nPoints" );
 
@@ -633,7 +623,6 @@ const Point& Polygon::GetPoint( sal_uInt16 nPos ) const
 
 PolyFlags Polygon::GetFlags( sal_uInt16 nPos ) const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( nPos < mpImplPolygon->mnPoints,
                 "Polygon::GetFlags(): nPos >= nPoints" );
     return( mpImplPolygon->mpFlagAry ?
@@ -666,8 +655,6 @@ bool Polygon::IsRect() const
 
 void Polygon::SetSize( sal_uInt16 nNewSize )
 {
-    DBG_CHKTHIS( Polygon, NULL );
-
     if( nNewSize != mpImplPolygon->mnPoints )
     {
         ImplMakeUnique();
@@ -677,15 +664,11 @@ void Polygon::SetSize( sal_uInt16 nNewSize )
 
 sal_uInt16 Polygon::GetSize() const
 {
-    DBG_CHKTHIS( Polygon, NULL );
-
     return mpImplPolygon->mnPoints;
 }
 
 void Polygon::Clear()
 {
-    DBG_CHKTHIS( Polygon, NULL );
-
     if ( mpImplPolygon->mnRefCount )
     {
         if ( mpImplPolygon->mnRefCount > 1 )
@@ -714,7 +697,6 @@ double Polygon::CalcDistance( sal_uInt16 nP1, sal_uInt16 nP2 )
 
 void Polygon::Optimize( sal_uIntPtr nOptimizeFlags, const PolyOptimizeData* pData )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( !mpImplPolygon->mpFlagAry, "Optimizing could fail with beziers!" );
 
     sal_uInt16 nSize = mpImplPolygon->mnPoints;
@@ -824,10 +806,10 @@ static void ImplAdaptiveSubdivide( ::std::back_insert_iterator< ::std::vector< P
 
     // Perform bezier flatness test (lecture notes from R. Schaback,
     // Mathematics of Computer-Aided Design, Uni Goettingen, 2000)
-    //
+
     // ||P(t) - L(t)|| <= max     ||b_j - b_0 - j/n(b_n - b_0)||
     //                    0<=j<=n
-    //
+
     // What is calculated here is an upper bound to the distance from
     // a line through b_0 and b_3 (P1 and P4 in our notation) and the
     // curve. We can drop 0 and n from the running indices, since the
@@ -1034,8 +1016,6 @@ void Polygon::ImplReduceEdges( Polygon& rPoly, const double& rArea, sal_uInt16 n
 
 void Polygon::Move( long nHorzMove, long nVertMove )
 {
-    DBG_CHKTHIS( Polygon, NULL );
-
     // This check is required for DrawEngine
     if ( !nHorzMove && !nVertMove )
         return;
@@ -1054,7 +1034,6 @@ void Polygon::Move( long nHorzMove, long nVertMove )
 
 void Polygon::Translate(const Point& rTrans)
 {
-    DBG_CHKTHIS( Polygon, NULL );
     ImplMakeUnique();
 
     for ( sal_uInt16 i = 0, nCount = mpImplPolygon->mnPoints; i < nCount; i++ )
@@ -1063,7 +1042,6 @@ void Polygon::Translate(const Point& rTrans)
 
 void Polygon::Scale( double fScaleX, double fScaleY )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     ImplMakeUnique();
 
     for ( sal_uInt16 i = 0, nCount = mpImplPolygon->mnPoints; i < nCount; i++ )
@@ -1076,7 +1054,6 @@ void Polygon::Scale( double fScaleX, double fScaleY )
 
 void Polygon::Rotate( const Point& rCenter, sal_uInt16 nAngle10 )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     nAngle10 %= 3600;
 
     if( nAngle10 )
@@ -1088,7 +1065,6 @@ void Polygon::Rotate( const Point& rCenter, sal_uInt16 nAngle10 )
 
 void Polygon::Rotate( const Point& rCenter, double fSin, double fCos )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     ImplMakeUnique();
 
     long nX, nY;
@@ -1130,8 +1106,8 @@ public:
 
     virtual         ~ImplPolygonPointFilter() {}
 
-    virtual void    LastPoint();
-    virtual void    Input( const Point& rPoint );
+    virtual void    LastPoint() SAL_OVERRIDE;
+    virtual void    Input( const Point& rPoint ) SAL_OVERRIDE;
 };
 
 void ImplPolygonPointFilter::Input( const Point& rPoint )
@@ -1169,6 +1145,7 @@ public:
                             mnLow( nLow ),
                             mnHigh( nHigh ),
                             mnEdge( nEdge ),
+                            mnLastOutside( 0 ),
                             mbFirst( true )
                         {
                         }
@@ -1177,11 +1154,11 @@ public:
 
     Point               EdgeSection( const Point& rPoint, int nEdge ) const;
     int                 VisibleSide( const Point& rPoint ) const;
-    int                 IsPolygon() const
+    bool                IsPolygon() const
                             { return maFirstPoint == maLastPoint; }
 
-    virtual void        Input( const Point& rPoint );
-    virtual void        LastPoint();
+    virtual void        Input( const Point& rPoint ) SAL_OVERRIDE;
+    virtual void        LastPoint() SAL_OVERRIDE;
 };
 
 inline int ImplEdgePointFilter::VisibleSide( const Point& rPoint ) const
@@ -1308,7 +1285,7 @@ void ImplEdgePointFilter::LastPoint()
 
 void Polygon::Clip( const Rectangle& rRect, bool bPolygon )
 {
-    // #105251# Justify rect befor edge filtering
+    // #105251# Justify rect before edge filtering
     Rectangle               aJustifiedRect( rRect );
     aJustifiedRect.Justify();
 
@@ -1339,7 +1316,6 @@ void Polygon::Clip( const Rectangle& rRect, bool bPolygon )
 
 Rectangle Polygon::GetBoundRect() const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     // Removing the assert. Bezier curves have the attribute that each single
     // curve segment defined by four points can not exit the four-point polygon
     // defined by that points. This allows to say that the curve segment can also
@@ -1348,7 +1324,7 @@ Rectangle Polygon::GetBoundRect() const
     // BoundRect of the Polygon (to get that, use basegfx::B2DPolygon classes),
     // but will always create a valid BoundRect, at least as long as this method
     // 'blindly' travels over all points, including control points.
-    //
+
     // DBG_ASSERT( !mpImplPolygon->mpFlagAry, "GetBoundRect could fail with beziers!" );
 
     sal_uInt16  nCount = mpImplPolygon->mnPoints;
@@ -1380,7 +1356,6 @@ Rectangle Polygon::GetBoundRect() const
 
 double Polygon::GetSignedArea() const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( !mpImplPolygon->mpFlagAry, "GetArea could fail with beziers!" );
 
     double fArea = 0.0;
@@ -1406,7 +1381,6 @@ double Polygon::GetSignedArea() const
 
 bool Polygon::IsInside( const Point& rPoint ) const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( !mpImplPolygon->mpFlagAry, "IsInside could fail with beziers!" );
 
     const Rectangle aBound( GetBoundRect() );
@@ -1455,13 +1429,11 @@ bool Polygon::IsInside( const Point& rPoint ) const
 
 bool Polygon::IsRightOrientated() const
 {
-    DBG_CHKTHIS( Polygon, NULL );
     return GetSignedArea() >= 0.0;
 }
 
 void Polygon::Insert( sal_uInt16 nPos, const Point& rPt, PolyFlags eFlags )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     ImplMakeUnique();
 
     if( nPos >= mpImplPolygon->mnPoints )
@@ -1479,7 +1451,6 @@ void Polygon::Insert( sal_uInt16 nPos, const Point& rPt, PolyFlags eFlags )
 
 void Polygon::Insert( sal_uInt16 nPos, const Polygon& rPoly )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     const sal_uInt16 nInsertCount = rPoly.mpImplPolygon->mnPoints;
 
     if( nInsertCount )
@@ -1498,7 +1469,6 @@ void Polygon::Insert( sal_uInt16 nPos, const Polygon& rPoly )
 
 Point& Polygon::operator[]( sal_uInt16 nPos )
 {
-    DBG_CHKTHIS( Polygon, NULL );
     DBG_ASSERT( nPos < mpImplPolygon->mnPoints, "Polygon::[]: nPos >= nPoints" );
 
     ImplMakeUnique();
@@ -1507,8 +1477,6 @@ Point& Polygon::operator[]( sal_uInt16 nPos )
 
 Polygon& Polygon::operator=( const Polygon& rPoly )
 {
-    DBG_CHKTHIS( Polygon, NULL );
-    DBG_CHKOBJ( &rPoly, Polygon, NULL );
     DBG_ASSERT( rPoly.mpImplPolygon->mnRefCount < 0xFFFFFFFE, "Polygon: RefCount overflow" );
 
     // Increase refcounter before assigning
@@ -1531,8 +1499,6 @@ Polygon& Polygon::operator=( const Polygon& rPoly )
 
 bool Polygon::operator==( const Polygon& rPoly ) const
 {
-    DBG_CHKTHIS( Polygon, NULL );
-    DBG_CHKOBJ( &rPoly, Polygon, NULL );
 
     if ( (rPoly.mpImplPolygon == mpImplPolygon) )
         return true;
@@ -1561,16 +1527,15 @@ bool Polygon::IsEqual( const Polygon& rPoly ) const
     return bIsEqual;
 }
 
-SvStream& operator>>( SvStream& rIStream, Polygon& rPoly )
+SvStream& ReadPolygon( SvStream& rIStream, Polygon& rPoly )
 {
-    DBG_CHKOBJ( &rPoly, Polygon, NULL );
     DBG_ASSERTWARNING( rIStream.GetVersion(), "Polygon::>> - Solar-Version not set on rIStream" );
 
     sal_uInt16          i;
     sal_uInt16          nPoints(0);
 
     // read all points and create array
-    rIStream >> nPoints;
+    rIStream.ReadUInt16( nPoints );
     if ( rPoly.mpImplPolygon->mnRefCount != 1 )
     {
         if ( rPoly.mpImplPolygon->mnRefCount )
@@ -1582,67 +1547,62 @@ SvStream& operator>>( SvStream& rIStream, Polygon& rPoly )
 
     {
         // Determine whether we need to write through operators
-#if (SAL_TYPES_SIZEOFLONG) != 4
-        if ( 1 )
-#else
+#if (SAL_TYPES_SIZEOFLONG) == 4
 #ifdef OSL_BIGENDIAN
-        if ( rIStream.GetNumberFormatInt() != NUMBERFORMAT_INT_BIGENDIAN )
+        if ( rIStream.GetNumberFormatInt() == NUMBERFORMAT_INT_BIGENDIAN )
 #else
-        if ( rIStream.GetNumberFormatInt() != NUMBERFORMAT_INT_LITTLEENDIAN )
+        if ( rIStream.GetNumberFormatInt() == NUMBERFORMAT_INT_LITTLEENDIAN )
 #endif
+            rIStream.Read( rPoly.mpImplPolygon->mpPointAry, nPoints*sizeof(Point) );
+        else
 #endif
         {
             for( i = 0; i < nPoints; i++ )
             {
                 //fdo#39428 SvStream no longer supports operator>>(long&)
                 sal_Int32 nTmpX(0), nTmpY(0);
-                rIStream >> nTmpX >> nTmpY;
+                rIStream.ReadInt32( nTmpX ).ReadInt32( nTmpY );
                 rPoly.mpImplPolygon->mpPointAry[i].X() = nTmpX;
                 rPoly.mpImplPolygon->mpPointAry[i].Y() = nTmpY;
             }
         }
-        else
-            rIStream.Read( rPoly.mpImplPolygon->mpPointAry, nPoints*sizeof(Point) );
     }
 
     return rIStream;
 }
 
-SvStream& operator<<( SvStream& rOStream, const Polygon& rPoly )
+SvStream& WritePolygon( SvStream& rOStream, const Polygon& rPoly )
 {
-    DBG_CHKOBJ( &rPoly, Polygon, NULL );
     DBG_ASSERTWARNING( rOStream.GetVersion(), "Polygon::<< - Solar-Version not set on rOStream" );
 
     sal_uInt16          i;
     sal_uInt16          nPoints = rPoly.GetSize();
 
     // Write number of points
-    rOStream << nPoints;
+    rOStream.WriteUInt16( nPoints );
 
     {
         // Determine whether we need to write through operators
-#if (SAL_TYPES_SIZEOFLONG) != 4
-        if ( 1 )
-#else
+#if (SAL_TYPES_SIZEOFLONG) == 4
 #ifdef OSL_BIGENDIAN
-        if ( rOStream.GetNumberFormatInt() != NUMBERFORMAT_INT_BIGENDIAN )
+        if ( rOStream.GetNumberFormatInt() == NUMBERFORMAT_INT_BIGENDIAN )
 #else
-        if ( rOStream.GetNumberFormatInt() != NUMBERFORMAT_INT_LITTLEENDIAN )
+        if ( rOStream.GetNumberFormatInt() == NUMBERFORMAT_INT_LITTLEENDIAN )
 #endif
+        {
+            if ( nPoints )
+                rOStream.Write( rPoly.mpImplPolygon->mpPointAry, nPoints*sizeof(Point) );
+        }
+        else
 #endif
         {
             for( i = 0; i < nPoints; i++ )
             {
                 //fdo#39428 SvStream no longer supports operator<<(long)
-                rOStream << sal::static_int_cast<sal_Int32>( rPoly.mpImplPolygon->mpPointAry[i].X() )
-                         << sal::static_int_cast<sal_Int32>( rPoly.mpImplPolygon->mpPointAry[i].Y() );
+                rOStream.WriteInt32( sal::static_int_cast<sal_Int32>( rPoly.mpImplPolygon->mpPointAry[i].X() ) )
+                        .WriteInt32( sal::static_int_cast<sal_Int32>( rPoly.mpImplPolygon->mpPointAry[i].Y() ) );
             }
         }
-        else
-        {
-            if ( nPoints )
-                rOStream.Write( rPoly.mpImplPolygon->mpPointAry, nPoints*sizeof(Point) );
-        }
     }
 
     return rOStream;
@@ -1652,8 +1612,8 @@ void Polygon::ImplRead( SvStream& rIStream )
 {
     sal_uInt8 bHasPolyFlags(0);
 
-    rIStream >> *this
-             >> bHasPolyFlags;
+    ReadPolygon( rIStream, *this );
+    rIStream.ReadUChar( bHasPolyFlags );
 
     if ( bHasPolyFlags )
     {
@@ -1671,9 +1631,9 @@ void Polygon::Read( SvStream& rIStream )
 
 void Polygon::ImplWrite( SvStream& rOStream ) const
 {
-    sal_uInt8   bHasPolyFlags = mpImplPolygon->mpFlagAry != NULL;
-    rOStream << *this
-             << bHasPolyFlags;
+    bool bHasPolyFlags = mpImplPolygon->mpFlagAry != NULL;
+    WritePolygon( rOStream, *this );
+    rOStream.WriteUChar(sal_uInt8(bHasPolyFlags));
 
     if ( bHasPolyFlags )
         rOStream.Write( mpImplPolygon->mpFlagAry, mpImplPolygon->mnPoints );
@@ -1697,7 +1657,7 @@ void impCorrectContinuity(basegfx::B2DPolygon& roPolygon, sal_uInt32 nIndex, sal
         if(roPolygon.isPrevControlPointUsed(nIndex) && roPolygon.isNextControlPointUsed(nIndex))
         {
             // #i115917# Patch from osnola (modified, thanks for showing the porblem)
-            //
+
             // The correction is needed because an integer polygon with control points
             // is converted to double precision. When C1 or C2 is used the involved vectors
             // may not have the same directions/lengths since these come from integer coordinates
@@ -1705,10 +1665,10 @@ void impCorrectContinuity(basegfx::B2DPolygon& roPolygon, sal_uInt32 nIndex, sal
             // is in the range of +-1 in y and y, thus 0.0 <= error <= sqrt(2.0). Nonetheless,
             // it needs to be corrected to be able to detect the continuity in this points
             // correctly.
-            //
+
             // We only have the integer data here (already in double precision form, but no mantisses
             // used), so the best correction is to use:
-            //
+
             // for C1: The longest vector since it potentially has best preserved the original vector.
             //         Even better the sum of the vectors, weighted by their length. This gives the
             //         normal vector addition to get the vector itself, lengths need to be preserved.
@@ -1842,8 +1802,6 @@ basegfx::B2DPolygon Polygon::getB2DPolygon() const
 Polygon::Polygon(const basegfx::B2DPolygon& rPolygon)
 :   mpImplPolygon(0)
 {
-    DBG_CTOR( Polygon, NULL );
-
     const bool bCurve(rPolygon.areControlPointsUsed());
     const bool bClosed(rPolygon.isClosed());
     sal_uInt32 nB2DLocalCount(rPolygon.count());
