@@ -114,7 +114,6 @@ private:
     boost::shared_ptr<GtkPrintWrapper> m_pWrapper;
 };
 
-
 struct GtkSalPrinter_Impl
 {
     OString m_sSpoolFile;
@@ -126,14 +125,12 @@ struct GtkSalPrinter_Impl
     ~GtkSalPrinter_Impl();
 };
 
-
 GtkSalPrinter_Impl::GtkSalPrinter_Impl()
     : m_pPrinter(0)
     , m_pSettings(0)
 {
 }
 
-
 GtkSalPrinter_Impl::~GtkSalPrinter_Impl()
 {
     if (m_pPrinter)
@@ -173,7 +170,6 @@ GtkSalPrinter::GtkSalPrinter(SalInfoPrinter* const i_pInfoPrinter)
 {
 }
 
-
 bool
 GtkSalPrinter::impl_doJob(
         const OUString* const i_pFileName,
@@ -198,7 +194,7 @@ GtkSalPrinter::impl_doJob(
         for (int nPage(0); nPage != nPages; ++nPage)
         {
             if (nPage == nPages - 1)
-                io_rController.setLastPage(sal_True);
+                io_rController.setLastPage(true);
             io_rController.printFilteredPage(nPage);
         }
         io_rController.setJobState(view::PrintableState_JOB_COMPLETED);
@@ -207,8 +203,7 @@ GtkSalPrinter::impl_doJob(
     return bJobStarted;
 }
 
-
-sal_Bool
+bool
 GtkSalPrinter::StartJob(
         const OUString* const i_pFileName,
         const OUString& i_rJobName,
@@ -232,7 +227,7 @@ GtkSalPrinter::StartJob(
     if (!aDialog.run())
     {
         io_rController.abortJob();
-        return sal_False;
+        return false;
     }
     aDialog.updateControllerPrintRange();
     m_pImpl->m_pPrinter = aDialog.getPrinter();
@@ -266,11 +261,10 @@ GtkSalPrinter::StartJob(
     return impl_doJob(&aFileName, i_rJobName, i_rAppName, io_pSetupData, nCopies, bCollate, io_rController);
 }
 
-
-sal_Bool
+bool
 GtkSalPrinter::EndJob()
 {
-    sal_Bool bRet = PspSalPrinter::EndJob();
+    bool bRet = PspSalPrinter::EndJob();
 
     if (!lcl_useSystemPrintDialog())
         return bRet;
@@ -316,7 +310,6 @@ GtkSalPrinter::EndJob()
     return bRet;
 }
 
-
 namespace
 {
 
@@ -337,7 +330,6 @@ lcl_setHelpText(
 #endif
 }
 
-
 static GtkWidget*
 lcl_makeFrame(
         GtkWidget* const i_pChild,
@@ -415,7 +407,6 @@ GtkPrintDialog::GtkPrintDialog(vcl::PrinterController& io_rController)
     impl_readFromSettings();
 }
 
-
 void
 GtkPrintDialog::impl_initDialog()
 {
@@ -448,7 +439,6 @@ GtkPrintDialog::impl_initDialog()
        ));
 }
 
-
 void
 GtkPrintDialog::impl_initCustomTab()
 {
@@ -478,8 +468,8 @@ GtkPrintDialog::impl_initCustomTab()
         sal_Int32 nCurHelpText = 0;
         OUString aDependsOnName;
         sal_Int32 nDependsOnValue = 0;
-        sal_Bool bUseDependencyRow = sal_False;
-        sal_Bool bIgnore = sal_False;
+        bool bUseDependencyRow = false;
+        bool bIgnore = false;
         GtkWidget* pGroup = NULL;
         bool bGtkInternal = false;
 
@@ -607,7 +597,7 @@ GtkPrintDialog::impl_initCustomTab()
                 lcl_setHelpText(pWidget, aHelpTexts, 0);
                 m_aControlToPropertyMap[pWidget] = aPropertyName;
 
-                sal_Bool bVal = sal_False;
+                bool bVal = false;
                 pVal = m_rController.getValue(aPropertyName);
                 if (pVal)
                     pVal->Value >>= bVal;
@@ -761,7 +751,6 @@ GtkPrintDialog::impl_initCustomTab()
     }
 }
 
-
 void
 GtkPrintDialog::impl_initPrintContent(uno::Sequence<sal_Bool> const& i_rDisabled)
 {
@@ -815,7 +804,6 @@ GtkPrintDialog::impl_initPrintContent(uno::Sequence<sal_Bool> const& i_rDisabled
     }
 }
 
-
 void
 GtkPrintDialog::impl_checkOptionalControlDependencies()
 {
@@ -826,7 +814,6 @@ GtkPrintDialog::impl_checkOptionalControlDependencies()
     }
 }
 
-
 beans::PropertyValue*
 GtkPrintDialog::impl_queryPropertyValue(GtkWidget* const i_pWidget) const
 {
@@ -844,7 +831,6 @@ GtkPrintDialog::impl_queryPropertyValue(GtkWidget* const i_pWidget) const
     return pVal;
 }
 
-
 void
 GtkPrintDialog::impl_UIOption_CheckHdl(GtkWidget* const i_pWidget)
 {
@@ -858,7 +844,6 @@ GtkPrintDialog::impl_UIOption_CheckHdl(GtkWidget* const i_pWidget)
     }
 }
 
-
 void
 GtkPrintDialog::impl_UIOption_RadioHdl(GtkWidget* const i_pWidget)
 {
@@ -877,7 +862,6 @@ GtkPrintDialog::impl_UIOption_RadioHdl(GtkWidget* const i_pWidget)
     }
 }
 
-
 void
 GtkPrintDialog::impl_UIOption_SelectHdl(GtkWidget* const i_pWidget)
 {
@@ -891,7 +875,6 @@ GtkPrintDialog::impl_UIOption_SelectHdl(GtkWidget* const i_pWidget)
     }
 }
 
-
 bool
 GtkPrintDialog::run()
 {
@@ -951,7 +934,6 @@ void GtkPrintDialog::ExportAsPDF(const OUString &rFileURL, GtkPrintSettings *pSe
         aFilterData[1].Name = "FirstPageOnLeft";
         aFilterData[1].Value <<= sal_False;
 
-
         const gchar *pStr = gtk_print_settings_get(pSettings, GTK_PRINT_SETTINGS_PRINT_PAGES);
         if (pStr && !strcmp(pStr, "ranges"))
         {
@@ -1052,7 +1034,6 @@ void GtkPrintDialog::ExportAsPDF(const OUString &rFileURL, GtkPrintSettings *pSe
 }
 #endif
 
-
 void
 GtkPrintDialog::updateControllerPrintRange()
 {
@@ -1104,13 +1085,11 @@ GtkPrintDialog::updateControllerPrintRange()
     g_object_unref(G_OBJECT(pSettings));
 }
 
-
 GtkPrintDialog::~GtkPrintDialog()
 {
     gtk_widget_destroy(m_pDialog);
 }
 
-
 void
 GtkPrintDialog::impl_readFromSettings()
 {
@@ -1133,7 +1112,7 @@ GtkPrintDialog::impl_readFromSettings()
         m_pWrapper->print_settings_set_n_copies(pSettings, sal::static_int_cast<gint>(nCopyCount));
     }
 
-    const gboolean bOldCollate(m_pWrapper->print_settings_get_collate(pSettings));
+    const bool bOldCollate(m_pWrapper->print_settings_get_collate(pSettings));
     const bool bCollate(aCollate.equalsIgnoreAsciiCase("true"));
     if (bOldCollate != bCollate)
     {
@@ -1147,7 +1126,6 @@ GtkPrintDialog::impl_readFromSettings()
     g_object_unref(G_OBJECT(pSettings));
 }
 
-
 void
 GtkPrintDialog::impl_storeToSettings()
 const
@@ -1165,12 +1143,11 @@ const
                 ? OUString("true")
                 : OUString("false"))
         ;
-    // pItem->setValue(aPrintDialog, OUString::createFromAscii("ToFile"), );
+    // pItem->setValue(aPrintDialog, OUString("ToFile"), );
     g_object_unref(G_OBJECT(pSettings));
     pItem->Commit();
 }
 
-
 sal_uLong
 GtkSalInfoPrinter::GetCapabilities(
         const ImplJobSetup* const i_pSetupData,
