@@ -38,6 +38,8 @@
 #include "PropertyActionsOOo.hxx"
 #include "TransformerActions.hxx"
 #include "OOo2Oasis.hxx"
+#include "XMLFilterRegistration.hxx"
+#include <cppuhelper/supportsservice.hxx>
 
 using namespace ::xmloff::token;
 using namespace ::com::sun::star::uno;
@@ -703,7 +705,7 @@ static XMLTransformerActionInit aStyleRefActionTable[] =
 
 // OOO_SHAPE_ACTIONS
 // !!ATTENTION!! If you change something here, please also change
-// aConnectorActionTable if apropriate
+// aConnectorActionTable if appropriate
 static XMLTransformerActionInit aShapeActionTable[] =
 {
     ENTRY0( SVG, X, XML_ATACTION_INCH2IN ),
@@ -1087,7 +1089,7 @@ class XMLDocumentTransformerContext_Impl : public XMLTransformerContext
     OUString m_aOldClass;
 
 public:
-    TYPEINFO();
+    TYPEINFO_OVERRIDE();
 
     XMLDocumentTransformerContext_Impl( XMLTransformerBase& rTransformer,
                            const OUString& rQName );
@@ -1098,8 +1100,8 @@ public:
 
     virtual ~XMLDocumentTransformerContext_Impl();
 
-    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList );
-    virtual void EndElement();
+    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList ) SAL_OVERRIDE;
+    virtual void EndElement() SAL_OVERRIDE;
 };
 
 TYPEINIT1( XMLDocumentTransformerContext_Impl, XMLTransformerContext );
@@ -1236,15 +1238,15 @@ class XMLBodyTransformerContext_Impl : public XMLTransformerContext
     OUString m_aClassQName;
 
 public:
-    TYPEINFO();
+    TYPEINFO_OVERRIDE();
 
     XMLBodyTransformerContext_Impl( XMLTransformerBase& rTransformer,
                            const OUString& rQName );
 
     virtual ~XMLBodyTransformerContext_Impl();
 
-    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList );
-    virtual void EndElement();
+    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList ) SAL_OVERRIDE;
+    virtual void EndElement() SAL_OVERRIDE;
 };
 
 TYPEINIT1( XMLBodyTransformerContext_Impl, XMLTransformerContext );
@@ -1298,14 +1300,14 @@ void XMLBodyTransformerContext_Impl::EndElement()
 class XMLTabStopOOoTContext_Impl : public XMLPersElemContentTContext
 {
 public:
-    TYPEINFO();
+    TYPEINFO_OVERRIDE();
 
     XMLTabStopOOoTContext_Impl( XMLTransformerBase& rTransformer,
                            const OUString& rQName );
 
     virtual ~XMLTabStopOOoTContext_Impl();
 
-    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList );
+    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList ) SAL_OVERRIDE;
 };
 
 TYPEINIT1( XMLTabStopOOoTContext_Impl, XMLPersElemContentTContext );
@@ -1399,7 +1401,7 @@ class XMLTrackedChangesOOoTContext_Impl : public XMLTransformerContext
 
 public:
 
-    TYPEINFO();
+    TYPEINFO_OVERRIDE();
 
     XMLTrackedChangesOOoTContext_Impl( XMLTransformerBase& rTransformer,
                            const OUString& rQName,
@@ -1408,7 +1410,7 @@ public:
 
     virtual ~XMLTrackedChangesOOoTContext_Impl();
 
-    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList );
+    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList ) SAL_OVERRIDE;
 };
 
 TYPEINIT1( XMLTrackedChangesOOoTContext_Impl, XMLTransformerContext );
@@ -1475,15 +1477,15 @@ class XMLTableOOoTransformerContext_Impl : public XMLTransformerContext
     OUString m_aElemQName;
 
 public:
-    TYPEINFO();
+    TYPEINFO_OVERRIDE();
 
     XMLTableOOoTransformerContext_Impl( XMLTransformerBase& rTransformer,
                            const OUString& rQName );
 
     virtual ~XMLTableOOoTransformerContext_Impl();
 
-    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList );
-    virtual void EndElement();
+    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList ) SAL_OVERRIDE;
+    virtual void EndElement() SAL_OVERRIDE;
 };
 
 TYPEINIT1( XMLTableOOoTransformerContext_Impl, XMLTransformerContext );
@@ -1506,7 +1508,7 @@ void XMLTableOOoTransformerContext_Impl::StartElement(
     // Perform OOO_STYLE_REF_ACTIONS for all applications (#i50521#)
     Reference< XAttributeList > xAttrList( rAttrList );
     XMLMutableAttributeList* pMutableAttrList =
-        GetTransformer().ProcessAttrList( xAttrList, OOO_STYLE_REF_ACTIONS, sal_False );
+        GetTransformer().ProcessAttrList( xAttrList, OOO_STYLE_REF_ACTIONS, false );
     if( rAttrList->getLength() && IsXMLToken( GetTransformer().GetClass(), XML_SPREADSHEET  ) )
     {
         bool bPrintRanges(false);
@@ -1744,9 +1746,11 @@ XMLTransformerActions *OOo2OasisTransformer::GetUserDefinedActions(
                 case OOO_DATAPILOT_MEMBER_ACTIONS:
                     m_aActions[OOO_DATAPILOT_MEMBER_ACTIONS] =
                         new XMLTransformerActions( aDataPilotMemberActionTable );
+                    break;
                 case OOO_DATAPILOT_LEVEL_ACTIONS:
                     m_aActions[OOO_DATAPILOT_LEVEL_ACTIONS] =
                         new XMLTransformerActions( aDataPilotLevelActionTable );
+                    break;
                 case OOO_SOURCE_SERVICE_ACTIONS:
                     m_aActions[OOO_SOURCE_SERVICE_ACTIONS] =
                         new XMLTransformerActions( aSourceServiceActionTable );
@@ -1859,15 +1863,15 @@ OOo2OasisTransformer::~OOo2OasisTransformer() throw()
 }
 
 Any OOo2OasisTransformer::queryInterface( const Type& rType )
-    throw (RuntimeException)
+    throw (RuntimeException, std::exception)
 {
     Any aRet;
-    if ( rType == ::getCppuType((Reference<XImporter> *)0) )
+    if ( rType == cppu::UnoType<XImporter>::get())
     {
         Reference<XImporter> xThis( this );
            aRet <<= xThis;
     }
-    else if ( rType == ::getCppuType((Reference<XFilter> *)0) )
+    else if ( rType == cppu::UnoType<XFilter>::get())
     {
         Reference<XFilter> xThis( this );
         aRet <<= xThis;
@@ -1883,7 +1887,7 @@ Any OOo2OasisTransformer::queryInterface( const Type& rType )
 // XImporter
 void SAL_CALL OOo2OasisTransformer::setTargetDocument(
         const Reference< XComponent >& xDoc )
-    throw( IllegalArgumentException, RuntimeException)
+    throw( IllegalArgumentException, RuntimeException, std::exception)
 {
     if( !GetDocHandler().is() )
     {
@@ -1904,7 +1908,7 @@ void SAL_CALL OOo2OasisTransformer::setTargetDocument(
 // XFilter
 sal_Bool SAL_CALL OOo2OasisTransformer::filter(
         const Sequence< PropertyValue >& aDescriptor )
-    throw ( RuntimeException)
+    throw ( RuntimeException, std::exception)
 {
     Reference< XFilter> xFilter( GetDocHandler(), UNO_QUERY );
     OSL_ENSURE( xFilter.is(), "doc handler is not a filter" );
@@ -1915,7 +1919,7 @@ sal_Bool SAL_CALL OOo2OasisTransformer::filter(
 }
 
 void SAL_CALL OOo2OasisTransformer::cancel(  )
-    throw ( RuntimeException)
+    throw ( RuntimeException, std::exception)
 {
     Reference< XFilter> xFilter( GetDocHandler(), UNO_QUERY );
     OSL_ENSURE( xFilter.is(), "doc handler is not a filter" );
@@ -1926,13 +1930,13 @@ void SAL_CALL OOo2OasisTransformer::cancel(  )
 // XInitialize
 void SAL_CALL OOo2OasisTransformer::initialize(
                 const Sequence< Any >& rArguments )
-    throw( Exception, RuntimeException )
+    throw( Exception, RuntimeException, std::exception )
 {
     Initialize( rArguments );
 }
 
 void SAL_CALL OOo2OasisTransformer::startDocument( void )
-    throw( SAXException, RuntimeException )
+    throw( SAXException, RuntimeException, std::exception )
 {
     if( !GetDocHandler().is() )
     {
@@ -1998,7 +2002,7 @@ const Sequence< sal_Int8 > & OOo2OasisTransformer::getUnoTunnelId() throw()
 
 // XUnoTunnel
 sal_Int64 SAL_CALL OOo2OasisTransformer::getSomething( const Sequence< sal_Int8 >& rId )
-    throw(RuntimeException)
+    throw(RuntimeException, std::exception)
 {
     if( rId.getLength() == 16
         && 0 == memcmp( getUnoTunnelId().getConstArray(),
@@ -2014,19 +2018,19 @@ sal_Int64 SAL_CALL OOo2OasisTransformer::getSomething( const Sequence< sal_Int8
 
 // XServiceInfo
 OUString SAL_CALL OOo2OasisTransformer::getImplementationName()
-    throw(RuntimeException)
+    throw(RuntimeException, std::exception)
 {
     return m_aImplName;
 }
 
-sal_Bool SAL_CALL OOo2OasisTransformer::supportsService( const OUString& )
-    throw(RuntimeException)
+sal_Bool SAL_CALL OOo2OasisTransformer::supportsService( const OUString& ServiceName )
+    throw(RuntimeException, std::exception)
 {
-    return sal_False;
+    return cppu::supportsService(this, ServiceName);
 }
 
 Sequence< OUString > SAL_CALL OOo2OasisTransformer::getSupportedServiceNames(  )
-    throw(RuntimeException)
+    throw(RuntimeException, std::exception)
 {
     Sequence<OUString> aSeq(0);
     return aSeq;
@@ -2034,7 +2038,7 @@ Sequence< OUString > SAL_CALL OOo2OasisTransformer::getSupportedServiceNames(  )
 
 // XTypeProvider
 Sequence< ::com::sun::star::uno::Type > SAL_CALL
-    OOo2OasisTransformer::getTypes() throw(RuntimeException)
+    OOo2OasisTransformer::getTypes() throw(RuntimeException, std::exception)
 {
     Sequence< ::com::sun::star::uno::Type > aTypes(
                         XMLTransformerBase::getTypes() );
@@ -2043,8 +2047,8 @@ Sequence< ::com::sun::star::uno::Type > SAL_CALL
     aTypes.realloc( nIndex + 2 );
 
     ::com::sun::star::uno::Type* pTypes = aTypes.getArray();
-    pTypes[nIndex++] = ::getCppuType( static_cast< Reference< XImporter > * >( 0 ) );
-    pTypes[nIndex++] = ::getCppuType( static_cast< Reference< XFilter > * >( 0 ) );
+    pTypes[nIndex++] = cppu::UnoType<XImporter>::get();
+    pTypes[nIndex++] = cppu::UnoType<XFilter>::get();
 
     return aTypes;
 }
