@@ -26,11 +26,13 @@
 
 #include <unotools/localedatawrapper.hxx>
 #include <unotools/datetime.hxx>
-#include "svtools/treelistentry.hxx"
+#include <svtools/treelistentry.hxx>
 
 #include "dialogs.hrc"
 #include "resourcemanager.hxx"
 
+#include <vcl/settings.hxx>
+
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
@@ -46,29 +48,30 @@ CertificateViewer::CertificateViewer(
         Window* _pParent,
         const css::uno::Reference< css::xml::crypto::XSecurityEnvironment >& _rxSecurityEnvironment,
         const css::uno::Reference< css::security::XCertificate >& _rXCert, bool bCheckForPrivateKey )
-    :TabDialog      ( _pParent, XMLSEC_RES( RID_XMLSECDLG_CERTVIEWER ) )
-    ,maTabCtrl      ( this, XMLSEC_RES( 1 ) )
-    ,maOkBtn        ( this, XMLSEC_RES( BTN_OK ) )
-    ,maHelpBtn      ( this, XMLSEC_RES( BTN_HELP ) )
+    : TabDialog(_pParent, "ViewCertDialog", "xmlsec/ui/viewcertdialog.ui" )
 {
-    FreeResource();
+    get(mpTabCtrl, "tabcontrol");
 
     mbCheckForPrivateKey = bCheckForPrivateKey;
 
     mxSecurityEnvironment = _rxSecurityEnvironment;
     mxCert = _rXCert;
 
-    maTabCtrl.SetTabPage( RID_XMLSECTP_GENERAL, new CertificateViewerGeneralTP( &maTabCtrl, this ) );
-    maTabCtrl.SetTabPage( RID_XMLSECTP_DETAILS, new CertificateViewerDetailsTP( &maTabCtrl, this ) );
-    maTabCtrl.SetTabPage( RID_XMLSECTP_CERTPATH, new CertificateViewerCertPathTP( &maTabCtrl, this ) );
-    maTabCtrl.SetCurPageId( RID_XMLSECTP_GENERAL );
+    mnGeneralId = mpTabCtrl->GetPageId("general");
+    mnDetailsId = mpTabCtrl->GetPageId("details");
+    mnPathId = mpTabCtrl->GetPageId("path");
+
+    mpTabCtrl->SetTabPage(mnGeneralId, new CertificateViewerGeneralTP( mpTabCtrl, this));
+    mpTabCtrl->SetTabPage(mnDetailsId, new CertificateViewerDetailsTP( mpTabCtrl, this));
+    mpTabCtrl->SetTabPage(mnPathId, new CertificateViewerCertPathTP( mpTabCtrl, this));
+    mpTabCtrl->SetCurPageId(mnGeneralId);
 }
 
 CertificateViewer::~CertificateViewer()
 {
-    delete maTabCtrl.GetTabPage( RID_XMLSECTP_CERTPATH );
-    delete maTabCtrl.GetTabPage( RID_XMLSECTP_DETAILS );
-    delete maTabCtrl.GetTabPage( RID_XMLSECTP_GENERAL );
+    delete mpTabCtrl->GetTabPage(mnGeneralId);
+    delete mpTabCtrl->GetTabPage(mnDetailsId);
+    delete mpTabCtrl->GetTabPage(mnPathId);
 }
 
 CertificateViewerTP::CertificateViewerTP( Window* _pParent, const ResId& _rResId, CertificateViewer* _pDlg )
@@ -77,6 +80,12 @@ CertificateViewerTP::CertificateViewerTP( Window* _pParent, const ResId& _rResId
 {
 }
 
+CertificateViewerTP::CertificateViewerTP( Window* _pParent, const OString& rID,
+    const OUString& rUIXMLDescription, CertificateViewer* _pDlg )
+    : TabPage(_pParent, rID, rUIXMLDescription)
+    , mpDlg(_pDlg)
+{
+}
 
 CertificateViewerGeneralTP::CertificateViewerGeneralTP( Window* _pParent, CertificateViewer* _pDlg )
     :CertificateViewerTP    ( _pParent, XMLSEC_RES( RID_XMLSECTP_GENERAL ), _pDlg )
@@ -98,7 +107,7 @@ CertificateViewerGeneralTP::CertificateViewerGeneralTP( Window* _pParent, Certif
     sal_Int32 certStatus = mpDlg->mxSecurityEnvironment->verifyCertificate(mpDlg->mxCert,
          Sequence<Reference<css::security::XCertificate> >());
 
-    bool bCertValid = certStatus == css::security::CertificateValidity::VALID ?  true : false;
+    bool bCertValid = certStatus == css::security::CertificateValidity::VALID;
 
     if ( !bCertValid )
     {
@@ -178,7 +187,7 @@ CertificateViewerGeneralTP::CertificateViewerGeneralTP( Window* _pParent, Certif
     XmlSec::AlignAfterImage( maKeyImg, maHintCorrespPrivKeyFI, 12 );
 
     // Check if we have the private key...
-    sal_Bool bHasPrivateKey = sal_False;
+    bool bHasPrivateKey = false;
     // #i41270# Check only if we have that certificate in our security environment
     if ( _pDlg->mbCheckForPrivateKey )
     {
@@ -362,46 +371,29 @@ struct CertPath_UserData
 
 
 CertificateViewerCertPathTP::CertificateViewerCertPathTP( Window* _pParent, CertificateViewer* _pDlg )
-    :CertificateViewerTP    ( _pParent, XMLSEC_RES( RID_XMLSECTP_CERTPATH ), _pDlg  )
-    ,maCertPathFT           ( this, XMLSEC_RES( FT_CERTPATH ) )
-    ,maCertPathLB           ( this, XMLSEC_RES( LB_SIGNATURES ) )
-    ,maViewCertPB           ( this, XMLSEC_RES( BTN_VIEWCERT ) )
-    ,maCertStatusFT         ( this, XMLSEC_RES( FT_CERTSTATUS ) )
-    ,maCertStatusML         ( this, XMLSEC_RES( ML_CERTSTATUS ) )
-    ,mpParent               ( _pDlg )
-    ,mbFirstActivateDone    ( false )
-    ,maCertImage            ( XMLSEC_RES( IMG_CERT_SMALL ) )
-    ,maCertNotValidatedImage( XMLSEC_RES( IMG_CERT_NOTVALIDATED_SMALL ) )
-    ,msCertOK               ( XMLSEC_RES( STR_PATH_CERT_OK ) )
-    ,msCertNotValidated     ( XMLSEC_RES( STR_PATH_CERT_NOT_VALIDATED ) )
-
+    : CertificateViewerTP(_pParent, "CertPage", "xmlsec/ui/certpage.ui", _pDlg)
+    , mpParent(_pDlg)
+    , mbFirstActivateDone(false)
 {
-    FreeResource();
+    get(mpCertPathLB, "signatures");
+    get(mpViewCertPB, "viewcert");
+    get(mpCertStatusML, "status");
 
-    maCertPathLB.SetNodeDefaultImages();
-    maCertPathLB.SetSublistOpenWithLeftRight();
-    maCertPathLB.SetSelectHdl( LINK( this, CertificateViewerCertPathTP, CertSelectHdl ) );
-    maViewCertPB.SetClickHdl( LINK( this, CertificateViewerCertPathTP, ViewCertHdl ) );
+    msCertOK = get<FixedText>("certok")->GetText();
+    msCertNotValidated = get<FixedText>("certnotok")->GetText();
+    maCertImage = get<FixedImage>("imgok")->GetImage();
+    maCertNotValidatedImage = get<FixedImage>("imgnotok")->GetImage();
 
-    // check if buttontext is to wide
-    const long nOffset = 10;
-    OUString sText = maViewCertPB.GetText();
-    long nTxtW = maViewCertPB.GetTextWidth( sText );
-    if ( sText.indexOf( '~' ) == -1 )
-        nTxtW += nOffset;
-    long nBtnW = maViewCertPB.GetSizePixel().Width();
-    if ( nTxtW > nBtnW )
-    {
-        // broaden the button
-        long nDelta = nTxtW - nBtnW;
-        Size aNewSize = maViewCertPB.GetSizePixel();
-        aNewSize.Width() += nDelta;
-        maViewCertPB.SetSizePixel( aNewSize );
-        // and give it a new position
-        Point aNewPos = maViewCertPB.GetPosPixel();
-        aNewPos.X() -= nDelta;
-        maViewCertPB.SetPosPixel( aNewPos );
-    }
+    Size aControlSize(LogicToPixel(Size(251, 45), MAP_APPFONT));
+    mpCertPathLB->set_width_request(aControlSize.Width());
+    mpCertPathLB->set_height_request(aControlSize.Height());
+    mpCertStatusML->set_width_request(aControlSize.Width());
+    mpCertStatusML->set_height_request(aControlSize.Height());
+
+    mpCertPathLB->SetNodeDefaultImages();
+    mpCertPathLB->SetSublistOpenWithLeftRight();
+    mpCertPathLB->SetSelectHdl( LINK( this, CertificateViewerCertPathTP, CertSelectHdl ) );
+    mpViewCertPB->SetClickHdl( LINK( this, CertificateViewerCertPathTP, ViewCertHdl ) );
 }
 
 CertificateViewerCertPathTP::~CertificateViewerCertPathTP()
@@ -427,17 +419,17 @@ void CertificateViewerCertPathTP::ActivatePage()
             //Verify the certificate
             sal_Int32 certStatus = mpDlg->mxSecurityEnvironment->verifyCertificate(rCert,
                  Sequence<Reference<css::security::XCertificate> >());
-            bool bCertValid = certStatus == css::security::CertificateValidity::VALID ? true : false;
+            bool bCertValid = certStatus == css::security::CertificateValidity::VALID;
             pParent = InsertCert( pParent, sName, rCert, bCertValid);
         }
 
-        maCertPathLB.Select( pParent );
-        maViewCertPB.Disable(); // Own certificate selected
+        mpCertPathLB->Select( pParent );
+        mpViewCertPB->Disable(); // Own certificate selected
 
         while( pParent )
         {
-            maCertPathLB.Expand( pParent );
-            pParent = maCertPathLB.GetParent( pParent );
+            mpCertPathLB->Expand( pParent );
+            pParent = mpCertPathLB->GetParent( pParent );
         }
 
         CertSelectHdl( NULL );
@@ -446,7 +438,7 @@ void CertificateViewerCertPathTP::ActivatePage()
 
 IMPL_LINK_NOARG(CertificateViewerCertPathTP, ViewCertHdl)
 {
-    SvTreeListEntry* pEntry = maCertPathLB.FirstSelected();
+    SvTreeListEntry* pEntry = mpCertPathLB->FirstSelected();
     if( pEntry )
     {
         CertificateViewer aViewer( this, mpDlg->mxSecurityEnvironment, ((CertPath_UserData*)pEntry->GetUserData())->mxCert, false );
@@ -459,7 +451,7 @@ IMPL_LINK_NOARG(CertificateViewerCertPathTP, ViewCertHdl)
 IMPL_LINK_NOARG(CertificateViewerCertPathTP, CertSelectHdl)
 {
     OUString sStatus;
-    SvTreeListEntry* pEntry = maCertPathLB.FirstSelected();
+    SvTreeListEntry* pEntry = mpCertPathLB->FirstSelected();
     if( pEntry )
     {
         CertPath_UserData* pData = (CertPath_UserData*) pEntry->GetUserData();
@@ -467,24 +459,24 @@ IMPL_LINK_NOARG(CertificateViewerCertPathTP, CertSelectHdl)
             sStatus = pData->mbValid ? msCertOK : msCertNotValidated;
     }
 
-    maCertStatusML.SetText( sStatus );
-    maViewCertPB.Enable( pEntry && ( pEntry != maCertPathLB.Last() ) );
+    mpCertStatusML->SetText( sStatus );
+    mpViewCertPB->Enable( pEntry && ( pEntry != mpCertPathLB->Last() ) );
     return 0;
 }
 
 void CertificateViewerCertPathTP::Clear( void )
 {
-    maCertStatusML.SetText( OUString() );
+    mpCertStatusML->SetText( OUString() );
     sal_uLong           i = 0;
-    SvTreeListEntry*    pEntry = maCertPathLB.GetEntry( i );
+    SvTreeListEntry*    pEntry = mpCertPathLB->GetEntry( i );
     while( pEntry )
     {
         delete ( CertPath_UserData* ) pEntry->GetUserData();
         ++i;
-        pEntry = maCertPathLB.GetEntry( i );
+        pEntry = mpCertPathLB->GetEntry( i );
     }
 
-    maCertPathLB.Clear();
+    mpCertPathLB->Clear();
 }
 
 SvTreeListEntry* CertificateViewerCertPathTP::InsertCert(
@@ -492,7 +484,7 @@ SvTreeListEntry* CertificateViewerCertPathTP::InsertCert(
     bool bValid)
 {
     Image aImage = bValid ? maCertImage : maCertNotValidatedImage;
-    SvTreeListEntry* pEntry = maCertPathLB.InsertEntry( _rName, aImage, aImage, _pParent );
+    SvTreeListEntry* pEntry = mpCertPathLB->InsertEntry( _rName, aImage, aImage, _pParent );
     pEntry->SetUserData( ( void* ) new CertPath_UserData( rxCert, bValid ) );
 
     return pEntry;
